
# line 2 "pars.yacc"

/* $Id: pars.c,v 1.1 1993/02/07 14:59:06 pturner Exp pturner $
 * 
 * evaluate expressions, commands, parameter files
 * 
 */

#define PARS			/* to overide some defines in defines.h */

#include <stdio.h>
#include <math.h>
#include <ctype.h>

#include "globals.h"

#ifndef M_PI
#     define M_PI  3.14159265358979323846
#endif

#ifndef TRUE
#     define TRUE 1
#endif

#ifndef FALSE
#     define FALSE 0
#endif

double result, resx, resy;	/* return value if expression */
double nonl_parms[10];

double drand48();
long lrand48();

double rnorm(), fx(), normp(), invnorm(), invt();
void yyerror();

static int interr;

static double *freelist[100]; 	/* temporary vectors */
static int fcnt;		/* number allocated */

int naxis = 0;	/* current axis */
int curline, curbox, curstring, curleg, curgrid;

int gotbatch, gotparams, gotread; /* these guys attempt to avoid reentrancy problems */
int readtype, readsrc;
char batchfile[256], paramfile[256], readfile[256];

static char f_string[512];	/* buffer for string to parse */
static int pos = 0;
static double *aa, *bb, *cc, *dd, *xx, *yy;
static int setindex, lxy, ls;
static int setsetno;
static int whichgraph;
static int whichset;

extern int change_gno;
extern int change_type;


# line 63 "pars.yacc"
typedef union  {
    double val;
    int ival;
    double *ptr;
    int func;
    int pset;
    char *str;
} YYSTYPE;
# define ABS 257
# define ACOS 258
# define ASIN 259
# define ATAN 260
# define ATAN2 261
# define CEIL 262
# define COS 263
# define DEG 264
# define DX 265
# define DY 266
# define ERF 267
# define ERFC 268
# define EXP 269
# define FLOOR 270
# define HYPOT 271
# define INDEX 272
# define INT 273
# define INVN 274
# define INVT 275
# define IRAND 276
# define LGAMMA 277
# define LN 278
# define LOG 279
# define LOGISTIC 280
# define MAXP 281
# define MINP 282
# define MOD 283
# define NORM 284
# define NORMP 285
# define PI_XVGR 286
# define RAD 287
# define RAND 288
# define RNORM 289
# define SETNO 290
# define SIN 291
# define SQR 292
# define SQRT 293
# define TAN 294
# define INUM 295
# define VX1 296
# define VX2 297
# define VY1 298
# define VY2 299
# define WX1 300
# define WX2 301
# define WY1 302
# define WY2 303
# define DELAYP 304
# define DOUBLEBUFFER 305
# define DOWN 306
# define ABSOLUTE 307
# define ABORT 308
# define ACTIVATE 309
# define ACTIVE 310
# define ALT 311
# define ALTERNATE 312
# define ALTXAXIS 313
# define ALTYAXIS 314
# define ANGLE 315
# define ANNOTATE 316
# define APPEND 317
# define AREA 318
# define ARROW 319
# define AUTO 320
# define AUTOSCALE 321
# define AUTOTICKS 322
# define AVG 323
# define AXIS 324
# define AXES 325
# define BACKBUFFER 326
# define BACKGROUND 327
# define BAR 328
# define BATCH 329
# define BIN 330
# define BOTH 331
# define BOTTOM 332
# define BOX 333
# define CELLS 334
# define CENTER 335
# define CHAR 336
# define CHRSTR 337
# define CLEAR 338
# define CLICK 339
# define CMAP 340
# define COLOR 341
# define COMMENT 342
# define COPY 343
# define CYCLE 344
# define DECIMAL 345
# define DEF 346
# define DEFAULT 347
# define DELETE 348
# define DEVICE 349
# define DFT 350
# define DIFFERENCE 351
# define DISK 352
# define DRAW2 353
# define DXDX 354
# define DXP 355
# define DYDY 356
# define DYP 357
# define ECHO 358
# define EDIT 359
# define ELSE 360
# define END 361
# define ERRORBAR 362
# define EXIT 363
# define EXPONENTIAL 364
# define FALSEP 365
# define FFT 366
# define FILEP 367
# define FILL 368
# define FIND 369
# define FIXEDPOINT 370
# define FLUSH 371
# define FOCUS 372
# define FOLLOWS 373
# define FONTP 374
# define FOREGROUND 375
# define FORMAT 376
# define FRONTBUFFER 377
# define FRAMEP 378
# define GETP 379
# define GRAPH 380
# define GRAPHNO 381
# define GRAPHS 382
# define GRAPHTYPE 383
# define GRID 384
# define HARDCOPY 385
# define HBAR 386
# define HGAP 387
# define HIDDEN 388
# define HORIZONTAL 389
# define HPGLL 390
# define HPGLP 391
# define HISTO 392
# define IF 393
# define IGNORE 394
# define IHL 395
# define IN 396
# define INIT 397
# define INITGRAPHICS 398
# define INOUT 399
# define INTEGRATE 400
# define INTERP 401
# define INVDFT 402
# define INVFFT 403
# define JUST 404
# define KILL 405
# define LABEL 406
# define LAYOUT 407
# define LEAVE 408
# define LEAVEGRAPHICS 409
# define LEFT 410
# define LEGEND 411
# define LENGTH 412
# define LEVEL 413
# define LEVELS 414
# define LINE 415
# define LINESTYLE 416
# define LINETO 417
# define LINEWIDTH 418
# define LINK 419
# define LOAD 420
# define LOCATOR 421
# define LOCTYPE 422
# define LOGX 423
# define LOGY 424
# define LOGXY 425
# define MAJOR 426
# define MIFL 427
# define MIFP 428
# define MINOR 429
# define MISSINGP 430
# define MOVE 431
# define MOVE2 432
# define MOVETO 433
# define NEGATE 434
# define NO 435
# define NONE 436
# define NORMAL 437
# define NXY 438
# define OFF 439
# define OFFSETX 440
# define OFFSETY 441
# define ON 442
# define OP 443
# define ORIENT 444
# define OUT 445
# define PAGE 446
# define PARA 447
# define PARALLEL 448
# define PARAMETERS 449
# define PARAMS 450
# define PATTERN 451
# define PERIMETER 452
# define PERP 453
# define PERPENDICULAR 454
# define PIE 455
# define PIPE 456
# define PLACE 457
# define POINT 458
# define POLAR 459
# define POWER 460
# define PREC 461
# define PREPEND 462
# define PRINT 463
# define PS 464
# define PSCOLORP 465
# define PSMONOP 466
# define PSCOLORL 467
# define PSMONOL 468
# define PUSH 469
# define POP 470
# define PUTP 471
# define READ 472
# define REDRAW 473
# define REGRESS 474
# define REGNUM 475
# define REGIONS 476
# define RENDER 477
# define REVERSE 478
# define RIGHT 479
# define RISER 480
# define ROT 481
# define RUNAVG 482
# define RUNMED 483
# define RUNSTD 484
# define RUNMIN 485
# define RUNMAX 486
# define SAMPLE 487
# define SCALE 488
# define SCIENTIFIC 489
# define SET 490
# define SETNUM 491
# define SETS 492
# define SIGN 493
# define SIZE 494
# define SKIP 495
# define SLEEP 496
# define SLICE 497
# define SOURCE 498
# define SPEC 499
# define SPECIFIED 500
# define SPECTRUM 501
# define STACK 502
# define STACKEDBAR 503
# define STACKEDHBAR 504
# define STACKEDLINE 505
# define STAGGER 506
# define START 507
# define STARTTYPE 508
# define STATUS 509
# define STOP 510
# define STRING 511
# define SUBTITLE 512
# define SWAPBUFFER 513
# define SYMBOL 514
# define TICK 515
# define TICKLABEL 516
# define TICKMARKS 517
# define TITLE 518
# define TO 519
# define TOP 520
# define TRUEP 521
# define TYPE 522
# define UP 523
# define VELOCITY 524
# define VERTICAL 525
# define VGAP 526
# define VIEW 527
# define WITH 528
# define WORLD 529
# define WRITE 530
# define X1 531
# define X2 532
# define X3 533
# define X4 534
# define X5 535
# define XAXES 536
# define XAXIS 537
# define XCOR 538
# define XMAX 539
# define XMIN 540
# define XY 541
# define XYARC 542
# define XYBOX 543
# define XYFIXED 544
# define XYHILO 545
# define XYRT 546
# define XYSEG 547
# define XYSTRING 548
# define XYDX 549
# define XYDY 550
# define XYDXDX 551
# define XYDYDY 552
# define XYDXDY 553
# define XYX2Y2 554
# define XYXX 555
# define XYYY 556
# define XYZ 557
# define XYZW 558
# define XYUV 559
# define Y1 560
# define Y2 561
# define Y3 562
# define Y4 563
# define Y5 564
# define YAXES 565
# define YAXIS 566
# define YES 567
# define YMAX 568
# define YMIN 569
# define ZEROXAXIS 570
# define ZEROYAXIS 571
# define ABOVE 572
# define BELOW 573
# define POLYI 574
# define POLYO 575
# define GENERAL 576
# define DDMMYY 577
# define MMDDYY 578
# define MMYY 579
# define MMDD 580
# define MONTHDAY 581
# define DAYMONTH 582
# define MONTHS 583
# define MONTHL 584
# define DAYOFWEEKS 585
# define DAYOFWEEKL 586
# define DAYOFYEAR 587
# define HMS 588
# define MMDDHMS 589
# define MMDDYYHMS 590
# define DEGREESLON 591
# define DEGREESMMLON 592
# define DEGREESMMSSLON 593
# define MMSSLON 594
# define DEGREESLAT 595
# define DEGREESMMLAT 596
# define DEGREESMMSSLAT 597
# define MMSSLAT 598
# define DOT 599
# define STAR 600
# define PLUS 601
# define CROSS 602
# define CIRCLE 603
# define SQUARE 604
# define DIAMOND 605
# define TRIANGLE1 606
# define TRIANGLE2 607
# define TRIANGLE3 608
# define TRIANGLE4 609
# define SPLINE 610
# define SVAR 611
# define VAR 612
# define X 613
# define Y 614
# define NUMBER 615
# define FITPARM 616
# define OR 617
# define AND 618
# define GT 619
# define LT 620
# define LE 621
# define GE 622
# define EQ 623
# define NE 624
# define UMINUS 625
# define NOT 626
#define yyclearin yychar = -1
#define yyerrok yyerrflag = 0
extern int yychar;
extern int yyerrflag;
#ifndef YYMAXDEPTH
#define YYMAXDEPTH 150
#endif
YYSTYPE yylval, yyval;
typedef int yytabelem;
# define YYERRCODE 256

# line 3378 "pars.yacc"


void fixupstr(val)
    char *val;
{
    int vl = strlen(val);
    lowtoupper(val);
    val[vl + 1] = 0;
    val[vl] = '\n';
}

void scanner(s, x, y, len, a, b, c, d, lenscr, i, setno, errpos)
    char s[];
    double *x, *y, *a, *b, *c, *d;
    int i, len, lenscr, setno, *errpos;

{
    interr = 0;
    whichgraph = cg;
    whichset = setno;
    if (s[0] == '#') {
	return;
    }
    pos = 0;
    aa = a;
    bb = b;
    cc = c;
    dd = d;
    xx = x;
    yy = y;
    lxy = len;
    ls = lenscr;
    setindex = i + 1;
    curset = setsetno = setno;
    strcpy(f_string, s);
    fcnt = 0;
    yyparse();
    *errpos = interr;
    for (i = 0; i < fcnt; i++) {
	cfree(freelist[i]);
	freelist[i] = NULL;
    }
}

void runbatch(bfile)
char *bfile;
{
    double x, y, a, b, c, d;
    int i, setno, errpos, lcnt = 1;
    char stext[256];
    FILE *fp;
    if (strcmp("stdin", bfile)) {
	fp = fopen(bfile, "r");
    }
    else {
	fp = stdin;
    }
    if (fp == NULL) {
        fprintf(stderr, "Error opening batch file \"%s\"\n", bfile);
        exit(1);
    }
    while(fgets(stext, 255, fp) != NULL) {
        if (stext[0] == '#') {
            continue;
        }
        lowtoupper(stext);
/* TODO check on 0, 0 here for index and setno */
        scanner(stext, &x, &y, 1, ax, bx, cx, dx, 1, 0, 0, &errpos);
        stext[0] = 0;
        if (gotparams && paramfile[0]) {
            if (!getparms(cg, paramfile)) {
            }
            gotparams = 0;
        } else if (gotread && readfile[0]) {
            if (getdata(cg, readfile, readsrc, readtype)) {
                drawgraph();
            }
            gotread = 0;
        }
    }
    if (fp != stdin) {
	fclose(fp);
    }
}

#define MAXFUN 370

int maxparms = MAXFUN;
int maxfunc = MAXFUN;

symtab_entry key[] = {
	"A", VAR,
	"A0", FITPARM,
	"A1", FITPARM,
	"A2", FITPARM,
	"A3", FITPARM,
	"A4", FITPARM,
	"A5", FITPARM,
	"A6", FITPARM,
	"A7", FITPARM,
	"A8", FITPARM,
	"A9", FITPARM,
	"ABORT", ABORT,
	"ABOVE", ABOVE,
	"ABS", ABS,
	"ABSOLUTE", ABSOLUTE,
	"ACOS", ACOS,
	"ACTIVATE", ACTIVATE,
	"ACTIVE", ACTIVE,
	"ALT", ALT,
	"ALTERNATE", ALTERNATE,
	"ALTXAXIS", ALTXAXIS,
	"ALTYAXIS", ALTYAXIS,
	"AND", AND,
	"ANGLE", ANGLE,
	"ANNOTATE", ANNOTATE,
	"APPEND", APPEND,
	"AREA", AREA,
	"ARROW", ARROW,
	"ASIN", ASIN,
	"ATAN", ATAN,
	"ATAN2", ATAN2,
	"AUTO", AUTO,
	"AUTOSCALE", AUTOSCALE,
	"AUTOTICKS", AUTOTICKS,
	"AVG", AVG,
	"AXES", AXES,
	"AXIS", AXIS,
	"B", VAR,
	"BACKBUFFER", BACKBUFFER,
	"BACKGROUND", BACKGROUND,
	"BAR", BAR,
	"BATCH", BATCH,
	"BELOW", BELOW,
	"BIN", BIN,
	"BOTH", BOTH,
	"BOTTOM", BOTTOM,
	"BOX", BOX,
	"C", VAR,
	"CEIL", CEIL,
	"CELLS", CELLS,
	"CENTER", CENTER,
	"CHAR", CHAR,
	"CHRSTR", CHRSTR,
	"CLEAR", CLEAR,
	"CLICK", CLICK,
	"CMAP", CMAP,
	"CO", COLOR,
	"COLOR", COLOR,
	"COMMENT", COMMENT,
	"COPY", COPY,
	"COS", COS,
	"CYCLE", CYCLE,
	"D", VAR,
	"DAYMONTH", DAYMONTH,
	"DAYOFWEEKL", DAYOFWEEKL,
	"DAYOFWEEKS", DAYOFWEEKS,
	"DAYOFYEAR", DAYOFYEAR,
	"DDMMYY", DDMMYY,
	"DECIMAL", DECIMAL,
	"DEF", DEF,
	"DEFAULT", DEFAULT,
	"DEG", DEG,
	"DEGREESLAT", DEGREESLAT,
	"DEGREESLON", DEGREESLON,
	"DEGREESMMLAT", DEGREESMMLAT,
	"DEGREESMMLON", DEGREESMMLON,
	"DEGREESMMSSLAT", DEGREESMMSSLAT,
	"DEGREESMMSSLON", DEGREESMMSSLON,
	"DELAY", DELAYP,
	"DELETE", DELETE,
	"DEVICE", DEVICE,
	"DFT", DFT,
	"DIFF", DIFFERENCE,
	"DIFFERENCE", DIFFERENCE,
	"DISK", DISK,
	"DOUBLEBUFFER", DOUBLEBUFFER,
	"DOWN", DOWN,
	"DRAW2", DRAW2,
	"DX", DX,
	"DXDX", DXDX,
	"DY", DY,
	"DYDY", DYDY,
	"ECHO", ECHO,
	"EDIT", EDIT,
	"ELSE", ELSE,
	"END", END,
	"EQ", EQ,
	"ER", ERRORBAR,
	"ERF", ERF,
	"ERFC", ERFC,
	"ERRORBAR", ERRORBAR,
	"EXIT", EXIT,
	"EXP", EXP,
	"EXPONENTIAL", EXPONENTIAL,
	"FALSE", FALSEP,
	"FFT", FFT,
	"FILE", FILEP,
	"FILL", FILL,
	"FIND", FIND,
	"FIXEDPOINT", FIXEDPOINT,
	"FLOOR", FLOOR,
	"FLUSH", FLUSH,
	"FOCUS", FOCUS,
	"FOLLOWS", FOLLOWS,
	"FONT", FONTP,
	"FOREGROUND", FOREGROUND,
	"FORMAT", FORMAT,
	"FRAME", FRAMEP,
	"FRONTBUFFER", FRONTBUFFER,
	"GE", GE,
	"GENERAL", GENERAL,
	"GETP", GETP,
	"GRAPH", GRAPH,
	"GRAPHS", GRAPHS,
	"GRAPHTYPE", GRAPHTYPE,
	"GRID", GRID,
	"GT", GT,
	"HARDCOPY", HARDCOPY,
	"HBAR", HBAR,
	"HGAP", HGAP,
	"HIDDEN", HIDDEN,
	"HISTO", HISTO,
	"HMS", HMS,
	"HORIZONTAL", HORIZONTAL,
	"HPGLL", HPGLL,
	"HPGLP", HPGLP,
	"HYPOT", HYPOT,
	"IF", IF,
	"IGNORE", IGNORE,
	"IHL", IHL,
	"IN", IN,
	"INDEX", INDEX,
	"INIT", INIT,
	"INITGRAPHICS", INITGRAPHICS,
	"INOUT", INOUT,
	"INT", INT,
	"INTEGRATE", INT,
	"INTERP", INTERP,
	"INUM", INUM,
	"INVDFT", INVDFT,
	"INVFFT", INVFFT,
	"INVN", INVN,
	"INVT", INVT,
	"IRAND", IRAND,
	"JUST", JUST,
	"KILL", KILL,
	"LABEL", LABEL,
	"LAYOUT", LAYOUT,
	"LE", LE,
	"LEAVE", LEAVE,
	"LEAVEGRAPHICS", LEAVEGRAPHICS,
	"LEFT", LEFT,
	"LEGEND", LEGEND,
	"LENGTH", LENGTH,
	"LEVEL", LEVEL,
	"LEVELS", LEVELS,
	"LGAMMA", LGAMMA,
	"LINE", LINE,
	"LINESTYLE", LINESTYLE,
	"LINETO", LINETO,
	"LINEWIDTH", LINEWIDTH,
	"LINK", LINK,
	"LN", LN,
	"LOAD", LOAD,
	"LOCATOR", LOCATOR,
	"LOCTYPE", LOCTYPE,
	"LOG", LOG,
	"LOGISTIC", LOGISTIC,
	"LOGX", LOGX,
	"LOGXY", LOGXY,
	"LOGY", LOGY,
	"LS", LINESTYLE,
	"LT", LT,
	"LW", LINEWIDTH,
	"MAJOR", MAJOR,
	"MAX", MAXP,
	"MIFL", MIFL,
	"MIFP", MIFP,
	"MIN", MINP,
	"MINOR", MINOR,
	"MISSING", MISSINGP,
	"MMDD", MMDD,
	"MMDDHMS", MMDDHMS,
	"MMDDYY", MMDDYY,
	"MMDDYYHMS", MMDDYYHMS,
	"MMSSLAT", MMSSLAT,
	"MMSSLON", MMSSLON,
	"MMYY", MMYY,
	"MOD", MOD,
	"MONTHDAY", MONTHDAY,
	"MONTHL", MONTHL,
	"MONTHS", MONTHS,
	"MOVE", MOVE,
	"MOVE2", MOVE2,
	"MOVETO", MOVETO,
	"NE", NE,
	"NEGATE", NEGATE,
	"NO", NO,
	"NONE", NONE,
	"NORM", NORM,
	"NORMAL", NORMAL,
	"NORMP", NORMP,
	"NOT", NOT,
	"NUMBER", NUMBER,
	"NXY", NXY,
	"OFF", OFF,
	"OFFSETX", OFFSETX,
	"OFFSETY", OFFSETY,
	"ON", ON,
	"OP", OP,
	"OR", OR,
	"ORIENT", ORIENT,
	"OUT", OUT,
	"PAGE", PAGE,
	"PARA", PARA,
	"PARALLEL", PARALLEL,
	"PARAMETERS", PARAMETERS,
	"PARAMS", PARAMS,
	"PATTERN", PATTERN,
	"PERIMETER", PERIMETER,
	"PERP", PERP,
	"PERPENDICULAR", PERPENDICULAR,
	"PI", PI_XVGR,
	"PIE", PIE,
	"PIPE", PIPE,
	"PLACE", PLACE,
	"POINT", POINT,
	"POLAR", POLAR,
	"POLYI", POLYI,
	"POLYO", POLYO,
	"POP", POP,
	"POWER", POWER,
	"PREC", PREC,
	"PREPEND", PREPEND,
	"PRINT", PRINT,
	"PS", PS,
	"PSCOLORL", PSCOLORL,
	"PSCOLORP", PSCOLORP,
	"PSMONOL", PSMONOL,
	"PSMONOP", PSMONOP,
	"PUSH", PUSH,
	"PUTP", PUTP,
	"RAD", RAD,
	"RAND", RAND,
	"READ", READ,
	"REDRAW", REDRAW,
	"REGRESS", REGRESS,
	"RENDER", RENDER,
	"REVERSE", REVERSE,
	"RIGHT", RIGHT,
	"RISER", RISER,
	"RNORM", RNORM,
	"ROT", ROT,
	"RUNAVG", RUNAVG,
	"RUNMAX", RUNMAX,
	"RUNMED", RUNMED,
	"RUNMIN", RUNMIN,
	"RUNSTD", RUNSTD,
	"SAMPLE", SAMPLE,
	"SCALE", SCALE,
	"SCIENTIFIC", SCIENTIFIC,
	"SET", SET,
	"SETNO", SETNO,
	"SETS", SETS,
	"SIGN", SIGN,
	"SIN", SIN,
	"SIZE", SIZE,
	"SKIP", SKIP,
	"SLEEP", SLEEP,
	"SLICE", SLICE,
	"SOURCE", SOURCE,
	"SPEC", SPEC,
	"SPECIFIED", SPECIFIED,
	"SPECTRUM", SPECTRUM,
	"SPLINE", SPLINE,
	"SQR", SQR,
	"SQRT", SQRT,
	"STACK", STACK,
	"STACKEDBAR", STACKEDBAR,
	"STACKEDHBAR", STACKEDHBAR,
	"STACKEDLINE", STACKEDLINE,
	"STAGGER", STAGGER,
	"START", START,
	"STARTTYPE", STARTTYPE,
	"STATUS", STATUS,
	"STOP", STOP,
	"STRING", STRING,
	"SUBTITLE", SUBTITLE,
	"SVAR", SVAR,
	"SWAPBUFFER", SWAPBUFFER,
	"SYMBOL", SYMBOL,
	"TAN", TAN,
	"TICK", TICK,
	"TICKLABEL", TICKLABEL,
	"TICKMARKS", TICKMARKS,
	"TITLE", TITLE,
	"TO", TO,
	"TOP", TOP,
	"TRUE", TRUEP,
	"TYPE", TYPE,
	"UP", UP,
	"VAR", VAR,
	"VELOCITY", VELOCITY,
	"VERTICAL", VERTICAL,
	"VGAP", VGAP,
	"VIEW", VIEW,
	"VX1", VX1,
	"VX2", VX2,
	"VY1", VY1,
	"VY2", VY2,
	"WITH", WITH,
	"WORLD", WORLD,
	"WRITE", WRITE,
	"WX1", WX1,
	"WX2", WX2,
	"WY1", WY1,
	"WY2", WY2,
	"X", SVAR,
	"X1", X1,
	"X2", X2,
	"X3", X3,
	"X4", X4,
	"X5", X5,
	"XAXES", XAXES,
	"XAXIS", XAXIS,
	"XCOR", XCOR,
	"XMAX", XMAX,
	"XMIN", XMIN,
	"XY", XY,
	"XYARC", XYARC,
	"XYBOX", XYBOX,
	"XYDX", XYDX,
	"XYDXDX", XYDXDX,
	"XYDXDY", XYDXDY,
	"XYDY", XYDY,
	"XYDYDY", XYDYDY,
	"XYFIXED", XYFIXED,
	"XYHILO", XYHILO,
	"XYRT", XYRT,
	"XYSEG", XYSEG,
	"XYSTRING", XYSTRING,
	"XYUV", XYUV,
	"XYX2Y2", XYX2Y2,
	"XYXX", XYXX,
	"XYYY", XYYY,
	"XYZ", XYZ,
	"XYZW", XYZW,
	"Y", SVAR,
	"Y1", Y1,
	"Y2", Y2,
	"Y3", Y3,
	"Y4", Y4,
	"Y5", Y5,
	"YAXES", YAXES,
	"YAXIS", YAXIS,
	"YES", YES,
	"YMAX", YMAX,
	"YMIN", YMIN,
	"ZEROXAXIS", ZEROXAXIS,
	"ZEROYAXIS", ZEROYAXIS,
};

int findf(key, s, tlen)
    symtab_entry key[];
    char *s;
    int tlen;
{

    int low, high, mid;

    low = 0;
    high = tlen - 1;
    while (low <= high) {
	mid = (low + high) / 2;
	if (strcmp(s, key[mid].s) < 0) {
	    high = mid - 1;
	} else {
	    if (strcmp(s, key[mid].s) > 0) {
		low = mid + 1;
	    } else {
		return (mid);
	    }
	}
    }
    return (-1);
}

int getcharstr()
{
    if (pos >= strlen(f_string))
	 return EOF;
    return (f_string[pos++]);
}

void ungetchstr()
{
    if (pos > 0)
	pos--;
}

int yylex()
{
    int c, i;
    int found;
    static char s[256];
    char sbuf[256];

    while ((c = getcharstr()) == ' ' || c == '\t');
    if (c == EOF) {
	return (0);
    }
    if (c == '"') {
	i = 0;
	while ((c = getcharstr()) != '"' && c != EOF) {
	    if (c == '\\') {
		int ctmp;
		ctmp = getcharstr();
		if (ctmp != '"') {
		    ungetchstr();
		}
		else {
		    c = ctmp;
		}
	    }
	    s[i] = c;
	    i++;
	}
	if (c == EOF) {
	    sprintf(sbuf, "Nonterminating string\n");
	    yyerror(sbuf);
	    return 0;
	}
	s[i] = '\0';
	yylval.str = s;
	return CHRSTR;
    }
    if (c == '.' || isdigit(c)) {
	char stmp[80];
	double d;
	int i, gotdot = 0;

	i = 0;
	while (c == '.' || isdigit(c)) {
	    if (c == '.') {
		if (gotdot) {
		    yyerror("Reading number, too many dots");
	    	    return 0;
		} else {
		    gotdot = 1;
		}
	    }
	    stmp[i++] = c;
	    c = getcharstr();
	}
	if (c == 'E' || c == 'e') {
	    stmp[i++] = c;
	    c = getcharstr();
	    if (c == '+' || c == '-') {
		stmp[i++] = c;
		c = getcharstr();
	    }
	    while (isdigit(c)) {
		stmp[i++] = c;
		c = getcharstr();
	    }
	}
	if (gotdot && i == 1) {
	    ungetchstr();
	    return '.';
	}
	stmp[i] = '\0';
	ungetchstr();
	sscanf(stmp, "%lf", &d);
	yylval.val = d;
	return NUMBER;
    }
/* graphs, sets, regions resp. */
    if (c == 'G' || c == 'S' || c == 'R') {
	char stmp[80];
	double d;
	int i = 0, ctmp = c, gn, sn, rn;
	c = getcharstr();
	while (isdigit(c)) {
	    stmp[i++] = c;
	    c = getcharstr();
	}
	if (i == 0) {
	    c = ctmp;
	    ungetchstr();
	} else {
	    ungetchstr();
	    if (ctmp == 'G') {
	        stmp[i] = '\0';
		gn = atoi(stmp);
		if (gn >= 0 && gn < maxgraph) {
		    yylval.ival = gn;
		    whichgraph = gn;
		    return GRAPHNO;
		}
	    } else if (ctmp == 'S') {
	        stmp[i] = '\0';
		sn = atoi(stmp);
		if (sn >= 0 && sn < g[cg].maxplot) {
		    lxy = getsetlength(cg, sn);
		    yylval.ival = sn;
		    whichset = sn;
		    return SETNUM;
		}
	    } else if (ctmp == 'R') {
	        stmp[i] = '\0';
		rn = atoi(stmp);
		if (rn >= 0 && rn < MAXREGION) {
		    yylval.ival = rn;
		    return REGNUM;
		}
	    }
	}
    }
    if (isalpha(c)) {
	char *p = sbuf;
	int gno = -1, setno = -1, xy = -1, elno = -1;

	do {
	    *p++ = c;
	} while ((c = getcharstr()) != EOF && isalnum(c));
	ungetchstr();
	*p = '\0';
        if (debuglevel == 2) {
	    printf("->%s<-\n", sbuf);
	}
	if ((found = findf(key, sbuf, MAXFUN)) >= 0) {
	    if (key[found].type == VAR) {
		switch (sbuf[0]) {
		case 'A':
		    yylval.ptr = aa;
		    return VAR;
		case 'B':
		    yylval.ptr = bb;
		    return VAR;
		case 'C':
		    yylval.ptr = cc;
		    return VAR;
		case 'D':
		    yylval.ptr = dd;
		    return VAR;
		}
	    }
	    else if (key[found].type == SVAR) {
		switch (sbuf[0]) {
		case 'X':
		    yylval.ptr = xx;
		    return SVAR;
		case 'Y':
		    yylval.ptr = yy;
		    return SVAR;
		}
	    }
	    else if (key[found].type == FITPARM) {
		int index = sbuf[1] - '0';
		yylval.val = nonl_parms[index];
		return FITPARM;
	    }
	    else { /* set up special cases */
		switch (key[found].type) {
		case XAXIS:
		    naxis = 0;
		    break;
		case YAXIS:
		    naxis = 1;
		    break;
		case ZEROXAXIS:
		    naxis = 2;
		    break;
		case ZEROYAXIS:
		    naxis = 3;
		    break;
		case ALTXAXIS:
		    naxis = 4;
		    break;
		case ALTYAXIS:
		    naxis = 5;
		    break;
		case AXES:
		    naxis = 6;
		    break;
		case XAXES:
		    naxis = 7;
		    break;
		case YAXES:
		    naxis = 8;
		    break;
		case GRAPHS:
		    yylval.ival = -1;
		    whichgraph = -1;
		    return GRAPHS;
		    break;
		case SETS:
		    yylval.ival = -1;
		    whichset = -1;
		    return SETS;
		    break;
		default:
		    break;
		}
	    }
	    yylval.func = key[found].type;
	    return key[found].type;
	} else {
	    strcat(sbuf, ": No such function or variable");
	    yyerror(sbuf);
	    return 0;
	}
    }
    switch (c) {
    case '>':
	return follow('=', GE, GT);
    case '<':
	return follow('=', LE, LT);
    case '=':
	return follow('=', EQ, '=');
    case '!':
	return follow('=', NE, NOT);
    case '|':
	return follow('|', OR, '|');
    case '&':
	return follow('&', AND, '&');
    case '\n':
	return '\n';
    default:
	return c;
    }
}

int follow(expect, ifyes, ifno)
{
    int c = getcharstr();

    if (c == expect) {
	return ifyes;
    }
    ungetchstr();
    return ifno;
}

void yyerror(s)
    char *s;
{
    int i;
    char buf[256];
    sprintf(buf, "Error: %s: %s", s, f_string);
    i = strlen(buf);
    buf[i - 1] = 0;
    errwin(buf);
    interr = 1;
}

#define C1 0.1978977093962766
#define C2 0.1352915131768107

double rnorm(mean, sdev)
    double mean, sdev;
{
    double u = drand48();

    return mean + sdev * (pow(u, C2) - pow(1.0 - u, C2)) / C1;
}

double fx(x)
    double x;
{
    return 1.0 / sqrt(2.0 * M_PI) * exp(-x * x * 0.5);
}

double normp(b, s)
    double b, *s;
{
    double sum, dx, a = -8.0, fx();
    int i, n = 48;

    sum = fx(a) + fx(b);
    dx = (b - a) / n;
    for (i = 1; i <= ((n - 1) / 2); i++)
	sum = sum + 4.0 * fx(a + (2.0 * i - 1.0) * dx) + 2.0 * fx(a + 2.0 * i * dx);
    sum = sum + 4.0 * fx(b - dx);
    *s = fx(b);
    return sum * dx / 3.0;
}

double invnorm(p)
    double p;
{
    double s, x, z, temp, normp();

    if (p > 0.5)
	x = 1.0 - p;
    else
	x = p;
    s = sqrt(-2.0 * log(x));
    x = ((-7.49101 * s - 448.047) * s - 1266.846);
    x = x / (((s + 109.8371) * s + 748.189) * s + 498.003) + s;
    if (p < 0.5)
	x = -x;
    z = p - normp(x, &s);
    z = z / s;
    s = x * x;
    return (((((((((720.0 * s + 2556.0) * s + 1740.0) * s + 127.0) * z / 7.0 +
		 ((120.0 * s + 326.0) * s + 127.0) * x) * z / 6.0 + (24 * s + 46.0) * s + 7.0) * z / 40.0 +
	       (0.75 * s + 0.875) * x) * z + s + 0.5) * z / 3.0 + x * 0.5) * z + 1.0) * z + x + 0.832e-24 * x;
}

double invt(p, n)
    double p;

    int n;
{
    double sign, temp, a, b, c, d, x, y;

    sign = 1.0;
    if (p < 0.5) {
	p = 1.0 - p;
	sign = -1.0;
    }
    p = (1 - p) * 2;
    if (n == 2) {
	temp = sqrt(2.0 / (p * (2.0 - p)) - 2.0);
	temp = sign * temp;
	return temp;
    } else if (n == 1) {
	p = p * M_PI / 2.0;
	return sign * cos(p) / sin(p);
    } else {
	a = 1.0 / (n - 0.5);
	b = 48.0 / (a * a);
	c = ((20700 * a / b - 98.0) * a - 16.0) * a + 96.36;
	d = ((94.5 / (b + c) - 3.0) / b + 1.0) * sqrt(a * M_PI / 2.0) * n;
	x = d * p;
	y = exp((2.0 / n) * log(x));
	if (y > (0.05 + a)) {
	    x = invnorm(p * 0.5);
	    y = x * x;
	    if (n < 5)
		c = c + 0.3 * (n - 4.5) * (x + 0.6);
	    c = (((0.05 * d * x - 5.0) * x - 7.0) * x - 2.0) * x + b + c;
	    y = (((((0.4 * y + 6.3) * y + 36.0) * y + 94.5) / c - y - 3.0) / b + 1.0) * x;
	    y = a * y * y;
	    if (y > 0.002)
		y = exp(y) - 1.0;
	    else
		y = 0.5 * y * y + y;
	} else
	    y = ((1.0 / (((n + 0.6) / (n * y) - 0.089 * d - 0.822) * (n + 2.0) * 3.0) + 0.5 / (n + 4.0)) * y - 1.0) * (n + 1.0) / (n + 2.0) + 1.0 / y;
	return sign * sqrt(n * y);
    }
}
yytabelem yyexca[] ={
-1, 1,
	0, -1,
	-2, 0,
-1, 29,
	37, 590,
	-2, 517,
-1, 30,
	37, 591,
	-2, 518,
-1, 31,
	37, 592,
	-2, 519,
-1, 45,
	37, 614,
	-2, 528,
-1, 46,
	37, 615,
	-2, 529,
-1, 60,
	37, 629,
	-2, 544,
-1, 61,
	37, 630,
	-2, 545,
-1, 62,
	37, 631,
	-2, 546,
-1, 247,
	10, 488,
	44, 488,
	41, 488,
	58, 488,
	-2, 646,
-1, 257,
	10, 488,
	44, 488,
	41, 488,
	58, 488,
	-2, 648,
-1, 527,
	10, 488,
	44, 488,
	41, 488,
	58, 488,
	-2, 489,
-1, 529,
	10, 488,
	44, 488,
	41, 488,
	58, 488,
	-2, 493,
-1, 531,
	37, 579,
	10, 488,
	44, 488,
	41, 488,
	58, 488,
	-2, 497,
-1, 533,
	37, 580,
	10, 488,
	44, 488,
	41, 488,
	58, 488,
	-2, 501,
-1, 535,
	37, 582,
	10, 488,
	44, 488,
	41, 488,
	58, 488,
	-2, 505,
-1, 539,
	619, 0,
	620, 0,
	621, 0,
	622, 0,
	623, 0,
	624, 0,
	-2, 638,
-1, 540,
	619, 0,
	620, 0,
	621, 0,
	622, 0,
	623, 0,
	624, 0,
	-2, 639,
-1, 541,
	619, 0,
	620, 0,
	621, 0,
	622, 0,
	623, 0,
	624, 0,
	-2, 640,
-1, 542,
	619, 0,
	620, 0,
	621, 0,
	622, 0,
	623, 0,
	624, 0,
	-2, 641,
-1, 543,
	619, 0,
	620, 0,
	621, 0,
	622, 0,
	623, 0,
	624, 0,
	-2, 642,
-1, 544,
	619, 0,
	620, 0,
	621, 0,
	622, 0,
	623, 0,
	624, 0,
	-2, 643,
-1, 548,
	10, 488,
	44, 488,
	41, 488,
	58, 488,
	-2, 492,
-1, 550,
	10, 488,
	44, 488,
	41, 488,
	58, 488,
	-2, 496,
-1, 552,
	10, 488,
	44, 488,
	41, 488,
	58, 488,
	-2, 500,
-1, 554,
	10, 488,
	44, 488,
	41, 488,
	58, 488,
	-2, 504,
-1, 555,
	10, 488,
	44, 488,
	41, 488,
	58, 488,
	-2, 507,
-1, 559,
	619, 0,
	620, 0,
	621, 0,
	622, 0,
	623, 0,
	624, 0,
	-2, 556,
-1, 560,
	619, 0,
	620, 0,
	621, 0,
	622, 0,
	623, 0,
	624, 0,
	-2, 557,
-1, 561,
	619, 0,
	620, 0,
	621, 0,
	622, 0,
	623, 0,
	624, 0,
	-2, 558,
-1, 562,
	619, 0,
	620, 0,
	621, 0,
	622, 0,
	623, 0,
	624, 0,
	-2, 559,
-1, 563,
	619, 0,
	620, 0,
	621, 0,
	622, 0,
	623, 0,
	624, 0,
	-2, 560,
-1, 564,
	619, 0,
	620, 0,
	621, 0,
	622, 0,
	623, 0,
	624, 0,
	-2, 561,
-1, 986,
	37, 583,
	-2, 509,
-1, 1017,
	37, 619,
	-2, 534,
-1, 1329,
	37, 597,
	-2, 527,
-1, 1330,
	37, 618,
	-2, 532,
-1, 1343,
	37, 632,
	-2, 550,
	};
# define YYNPROD 649
# define YYLAST 7345
yytabelem yyact[]={

   558,     5,   946,   910,  1152,   273,  1174,   862,   158,   341,
   839,  1198,  1410,   722,   720,  1421,   721,   158,   723,   791,
  1409,   947,   722,   720,  1419,   721,   775,   723,   939,   941,
  1396,  1365,  1360,  1346,   159,  1320,  1312,  1311,  1310,  1307,
   158,  1300,  1299,   159,  1298,   722,   720,  1417,   721,  1297,
   723,  1295,  1294,  1293,   776,  1292,  1291,  1278,  1275,  1274,
  1273,   938,  1252,  1251,  1227,   724,   159,  1221,  1220,   247,
   255,   257,   158,  1218,   724,  1217,  1215,   722,   720,  1214,
   721,  1213,   723,  1211,  1209,  1208,   276,   277,  1207,  1206,
  1205,   280,  1204,  1203,  1194,   340,  1193,   724,   159,  1192,
  1190,  1189,  1179,  1178,  1173,  1165,  1160,  1151,  1150,  1149,
   650,     6,  1147,   348,   401,   410,  1126,   425,   431,  1124,
   158,  1122,   458,  1121,  1120,   722,   720,   158,   721,   724,
   723,   948,   722,   720,  1116,   721,   790,   723,  1113,  1112,
  1111,  1110,  1108,  1107,  1091,  1074,   159,   774,  1073,  1051,
   981,   980,   978,   159,   527,   529,   531,   533,   535,   537,
   538,   539,   540,   541,   542,   543,   544,   545,   546,   576,
   548,   550,   552,   554,   555,   963,  1408,   724,   962,   246,
   254,   256,   961,   960,   724,   959,   949,   940,   942,   943,
  1199,   567,   569,   570,   572,   573,   909,   903,   902,   901,
   899,   835,   834,   833,   832,   592,   593,   831,   945,   830,
   829,   828,   827,   621,   622,   817,   816,   625,   628,   630,
   632,   634,   636,   638,   640,   642,   644,   646,   648,   651,
   653,   654,   815,   658,   660,   662,   664,   666,   668,   670,
   672,   674,   676,   678,   680,   682,   684,   814,   810,   171,
   169,   809,   170,   808,   172,   807,   806,   805,   804,   803,
   802,   801,   800,   799,   528,   530,   532,   534,   536,   788,
   174,   787,   266,   786,   783,   911,   782,   781,   576,   780,
   547,   549,   551,   553,   556,   557,   559,   560,   561,   562,
   563,   564,   565,   566,   912,   944,   578,   577,   576,   779,
   773,   173,   568,   772,   571,   771,  1200,   730,   937,   729,
   728,   707,   702,   701,   700,   699,   696,   694,   656,   620,
   619,   618,   515,   279,   278,   580,   579,   626,   627,   629,
   631,   633,   635,   637,   639,   641,   643,   645,   647,   261,
   652,   655,   717,   657,   659,   661,   663,   665,   667,   669,
   671,   673,   675,   677,   679,   681,   683,   297,  1357,   518,
  1344,  1244,   269,  1237,  1050,   264,   623,   905,  1075,   947,
   727,  1271,   726,   306,  1270,   158,   268,   197,   207,   614,
   722,   720,   950,   721,   275,   723,   953,   705,   952,   703,
   913,   697,  1306,  1170,   343,  1202,  1304,   766,   767,   768,
  1191,   159,   606,   275,   964,   578,   577,   158,   285,   826,
   792,   270,   722,   720,  1401,   721,   789,   723,   304,   784,
   811,   610,  1398,   292,  1397,   578,   577,   794,   795,   796,
   797,   158,   724,   159,   580,   579,   722,   720,  1400,   721,
   505,   723,  1056,   290,  1055,   267,  1054,   305,   615,  1163,
   954,  1053,   713,   712,   580,   579,   283,   159,  1157,  1154,
   824,   825,   307,   309,   724,   206,  1158,   206,   205,   975,
   205,   272,   346,   399,   408,   711,   344,  1049,   514,   948,
   710,   451,   467,   479,   709,   708,   488,   607,   724,   265,
   286,   908,   951,   624,   258,  1210,   513,   574,   288,   955,
   271,   512,   511,  1172,   314,   474,   914,   915,   916,   917,
   918,   919,   920,   921,   922,   923,   924,   925,   926,   927,
   928,   929,   930,   931,   932,   933,   934,   935,   936,  1171,
  1342,   171,   169,   291,   170,  1348,   172,  1155,   510,   509,
   274,   612,   613,   616,   617,  1167,   715,   486,   609,   422,
  1415,   947,   174,   289,   421,  1347,  1118,   974,   590,   274,
   591,   314,   605,   342,   295,   296,   284,   608,   195,   484,
  1197,  1305,   345,  1052,   316,  1303,  1196,   507,   516,   508,
   837,   263,   732,   173,   260,  1177,   287,   423,   167,   166,
   160,   161,   162,   163,   164,   165,   725,   167,   166,   160,
   161,   162,   163,   164,   165,   446,  1156,   158,   315,   979,
   977,   313,   722,   720,  1399,   721,   206,   723,   693,   205,
   167,   166,   160,   161,   162,   163,   164,   165,  1164,   419,
   506,   420,   698,   159,  1308,  1226,   441,   141,   142,   481,
   444,  1169,  1168,  1125,   483,  1159,   482,  1153,   976,   145,
   485,  1064,   167,   166,   160,   161,   162,   163,   164,   165,
  1176,   948,   158,   957,   724,   315,  1394,   722,   720,   956,
   721,  1183,   723,   442,   293,   294,   785,   734,   714,   282,
   397,   339,   281,   259,   159,   398,  1046,  1047,   159,   124,
   651,   123,   733,  1374,   478,  1268,   686,   174,   685,   896,
   167,   166,   160,   161,   162,   163,   164,   165,   166,   160,
   161,   162,   163,   164,   165,   724,   480,   445,   517,   724,
  1067,  1068,  1069,  1070,  1071,  1072,   158,   424,   173,  1175,
  1393,   722,   720,  1378,   721,   159,   723,  1076,  1077,  1078,
  1079,  1080,  1081,  1082,  1083,  1084,  1085,  1086,  1087,  1088,
  1089,  1090,   159,  1092,  1093,  1094,  1095,  1096,  1097,  1098,
  1099,  1100,  1101,  1102,  1103,  1104,  1105,  1377,   174,  1224,
  1106,  1223,   477,   473,   897,  1406,   898,   158,  1109,  1319,
   158,   972,   159,   724,  1366,   722,   720,   471,   721,   193,
   723,   191,   206,   443,  1114,   205,  1231,   206,  1184,  1115,
   205,  1182,  1230,   159,  1280,   206,   159,   479,   205,  1318,
   448,   971,   447,   157,   472,   450,   449,   818,   984,   192,
  1267,   190,  1119,   718,  1123,   181,   175,   176,   177,   178,
   179,   180,   836,   735,   157,   840,   863,   724,   895,   706,
   704,   900,  1129,  1136,  1142,  1143,   690,  1145,  1146,  1127,
   688,   582,   583,   584,   585,   586,   587,   588,   589,   687,
   146,   139,   469,  1376,   470,   525,   526,  1010,   214,  1162,
  1166,  1309,   688,  1269,  1239,  1195,  1161,  1185,  1187,  1180,
  1063,   475,   476,  1062,   965,   206,  1061,  1060,   205,   147,
   140,  1059,  1058,  1057,   143,   144,  1201,   358,   359,   360,
   361,   362,   363,   364,   365,   366,   367,   368,   369,   370,
   371,   372,   373,   375,   376,   377,   378,   379,   380,   381,
   382,   383,   384,   385,   386,   387,   388,   389,   390,   391,
   374,   392,   393,   394,   395,   985,    37,    38,    39,    40,
    41,    42,    43,    44,   695,  1212,  1414,   958,  1216,  1413,
  1385,   716,  1355,   812,  1352,  1351,  1219,   160,   161,   162,
   163,   164,   165,    21,  1350,  1331,  1330,  1228,   468,   973,
  1323,  1232,  1233,  1235,  1236,  1285,  1017,   765,   764,   763,
   194,  1238,   762,  1241,  1242,  1243,   761,   167,   166,   160,
   161,   162,   163,   164,   165,   760,  1246,   759,   599,   770,
   582,   583,   584,   585,   586,   587,   588,   589,   778,  1248,
  1250,   167,   166,   160,   161,   162,   163,   164,   165,   758,
   757,   430,   756,   755,   754,  1253,  1254,   753,  1256,   752,
  1258,   751,  1260,   312,   158,   750,   749,  1262,  1264,   722,
   720,  1392,   721,   436,   723,   158,  1066,   439,   189,   813,
   722,   720,   171,   721,   748,   723,   600,   172,  1272,   747,
   159,   746,  1276,  1277,   907,   745,  1279,   311,   744,   743,
   742,   159,   741,   174,   188,   308,   171,   169,  1229,   170,
   437,   172,   904,  1234,   740,   739,   738,   890,   886,   737,
   736,   724,   892,   596,   597,   598,   689,   174,   303,   302,
   301,  1391,   724,   300,   173,  1245,   182,   181,   175,   176,
   177,   178,   179,   180,   299,   253,   298,   245,   244,  1247,
  1249,  1290,   820,   243,   440,   891,   242,   241,   173,   603,
   240,   357,   239,   206,   238,   237,   205,  1255,   236,  1257,
   235,  1259,   234,   233,   232,   231,   158,  1261,  1263,   819,
   230,   722,   720,  1389,   721,   889,   723,   229,   887,   228,
   227,   226,  1302,   209,   225,   224,   223,   222,   221,   893,
   158,   220,   159,   601,   602,   722,   720,  1388,   721,  1117,
   723,   219,   218,   217,   310,   216,   215,   167,   166,   160,
   161,   162,   163,   164,   165,  1048,   159,   821,   840,   822,
   438,  1128,  1135,   724,   187,  1144,   186,   185,   888,   184,
  1148,   595,   183,   151,   604,   150,   149,    69,   894,   885,
   206,   863,    70,   205,   861,   838,  1313,   724,   906,   487,
    12,  1314,  1315,    11,     9,     1,   575,   212,   210,    97,
   211,  1321,   167,   166,   160,   161,   162,   163,   164,   165,
    96,   356,   355,   731,   494,    19,    20,     7,    10,   126,
   158,   206,   594,   611,   205,   722,   396,   158,     8,  1345,
   723,   262,   155,   158,  1181,   849,     4,   156,   722,   720,
  1387,   721,  1358,   723,  1359,     3,   159,  1361,  1362,  1363,
  1364,     2,     0,   159,     0,     0,     0,     0,     0,   159,
   523,     0,     0,     0,     0,   519,   167,   166,   160,   161,
   162,   163,   164,   165,  1222,     0,     0,   724,  1367,  1368,
  1370,   158,     0,  1371,   157,  1386,   722,   720,     0,   721,
   724,   723,     0,  1372,  1373,   158,     0,     0,   522,  1384,
   722,   720,     0,   721,   208,   723,     0,   159,   524,     0,
  1379,     0,     0,     0,  1380,  1381,     0,  1382,     0,     0,
     0,   159,     0,   213,     0,   171,   169,  1390,   170,     0,
   172,     0,     0,     0,     0,  1395,     0,     0,   724,     0,
   521,     0,   520,     0,  1402,     0,   174,     0,  1403,  1404,
  1405,     0,   724,  1407,     0,     0,     0,     0,     0,     0,
     0,     0,  1411,   206,     0,     0,   205,  1412,   582,   583,
   584,   585,   586,   587,   588,   589,  1416,   173,  1418,     0,
  1420,     0,  1422,     0,     0,     0,     0,     0,     0,     0,
  1369,     0,     0,    13,    22,    23,    24,    25,    26,    27,
    28,    29,    30,    31,    32,    33,    34,    35,    36,    45,
    47,    48,    49,    50,    51,    52,    53,    54,    55,    56,
    57,    58,    59,    60,    61,    62,    63,    46,    64,    65,
    66,    67,     0,    37,    38,    39,    40,    41,    42,    43,
    44,    84,    79,     0,     0,    85,    89,     0,     0,     0,
   141,   142,     0,     0,  1296,     0,     0,    72,   101,     0,
    21,  1301,   145,    81,    74,     0,   158,     0,     0,     0,
   112,   722,   720,  1383,   721,   111,   723,    75,     0,     0,
    90,   109,     0,   514,   115,     0,   128,   135,   100,     0,
     0,     0,   159,     0,     0,    73,     0,     0,     0,     0,
    76,   513,     0,   136,     0,     0,   512,   511,    93,   103,
     0,     0,     0,     0,    80,   122,    86,   336,    17,   120,
     0,     0,   129,   724,     0,     0,     0,     0,     0,    99,
     0,     0,     0,     0,     0,     0,     0,     0,     0,   137,
   138,     0,    92,   510,   509,     0,     0,     0,   121,   397,
     0,     0,   113,     0,   398,     0,    78,    94,   102,     0,
     0,     0,     0,   581,     0,     0,     0,     0,    91,     0,
     0,     0,     0,     0,   167,   166,   160,   161,   162,   163,
   164,   165,   507,    77,   508,   167,   166,   160,   161,   162,
   163,   164,   165,     0,     0,     0,     0,     0,     0,     0,
   127,     0,     0,     0,     0,     0,   107,   108,    87,   106,
    71,    95,    18,   175,   176,   177,   178,   179,   180,   130,
   132,   131,   134,   133,     0,   335,   158,     0,    16,   148,
     0,   722,   720,    83,   721,   104,   723,     0,     0,   110,
     0,     0,     0,     0,     0,     0,     0,     0,   114,   119,
    82,     0,   159,     0,     0,   118,     0,     0,     0,   105,
     0,   125,     0,     0,   117,    88,   116,     0,     0,     0,
     0,     0,     0,   146,   139,     0,     0,     0,     0,     0,
     0,     0,  1375,   724,     0,     0,   167,   166,   160,   161,
   162,   163,   164,   165,     0,     0,     0,     0,     0,     0,
     0,     0,   147,   140,     0,     0,     0,   143,   144,     0,
   167,   166,   160,   161,   162,   163,   164,   165,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   317,   318,
   319,     0,   320,   321,   322,   323,   324,   325,   326,   327,
   328,   329,   330,   331,   332,   333,   334,    98,    15,    14,
     0,     0,    19,    20,     0,     0,     0,     0,     0,     0,
     0,     0,     0,    68,     0,     0,   358,   359,   360,   361,
   362,   363,   364,   365,   366,   367,   368,   369,   370,   371,
   372,   373,   375,   376,   377,   378,   379,   380,   381,   382,
   383,   384,   385,   386,   387,   388,   389,   390,   391,   374,
   392,   393,   394,   395,     0,    37,    38,    39,    40,    41,
    42,    43,    44,   167,   166,   160,   161,   162,   163,   164,
   165,     0,     0,     0,     0,     0,     0,     0,   158,     0,
     0,     0,    21,   722,   720,  1356,   721,     0,   723,     0,
     0,     0,   457,     0,     0,   461,     0,     0,     0,     0,
   465,     0,     0,   397,   159,     0,     0,     0,   398,     0,
     0,   167,   166,   160,   161,   162,   163,   164,   165,     0,
     0,     0,     0,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,   462,     0,   724,     0,   158,     0,     0,
   430,     0,   722,   720,  1354,   721,   455,   723,   158,     0,
     0,     0,     0,   722,   720,  1353,   721,     0,   723,     0,
     0,     0,     0,   159,     0,     0,   453,     0,     0,     0,
     0,   456,     0,     0,   159,   463,     0,   464,   158,     0,
     0,   452,     0,   722,   720,  1349,   721,     0,   723,     0,
     0,     0,     0,     0,   724,     0,     0,     0,   206,     0,
     0,   205,   158,     0,   159,   724,  1343,   155,   153,     0,
   154,   158,   156,     0,     0,  1341,   155,   153,     0,   154,
     0,   156,     0,     0,     0,     0,     0,     0,   159,     0,
     0,     0,     0,     0,   253,   724,     0,   159,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   158,     0,     0,
   357,  1339,   722,   720,     0,   721,   158,   723,     0,   157,
  1337,   722,   720,     0,   721,     0,   723,     0,   157,     0,
   466,     0,     0,   159,     0,     0,     0,     0,     0,     0,
     0,     0,   159,     0,     0,   454,     0,     0,     0,     0,
   459,     0,     0,     0,     0,     0,   167,   166,   160,   161,
   162,   163,   164,   165,   724,     0,     0,     0,     0,     0,
     0,     0,     0,   724,     0,     0,     0,     0,     0,   460,
   358,   359,   360,   361,   362,   363,   364,   365,   366,   367,
   368,   369,   370,   371,   372,   373,   375,   376,   377,   378,
   379,   380,   381,   382,   383,   384,   385,   386,   387,   388,
   389,   390,   391,   374,   392,   393,   394,   395,     0,    37,
    38,    39,    40,    41,    42,    43,    44,   397,     0,     0,
   356,   355,   398,     0,    19,    20,     0,     0,     0,     0,
     0,     0,     0,     0,   158,   396,    21,     0,  1335,   722,
   720,     0,   721,     0,   723,   158,     0,     0,     0,   417,
   722,   720,  1333,   721,   413,   723,     0,   158,     0,   418,
   159,     0,   722,   720,  1332,   721,     0,   723,     0,   158,
     0,   159,     0,  1329,   155,   153,     0,   154,     0,   156,
     0,     0,     0,   159,     0,     0,     0,   415,     0,     0,
     0,   724,     0,     0,   409,   159,     0,     0,     0,     0,
     0,     0,   724,     0,     0,     0,   167,   166,   160,   161,
   162,   163,   164,   165,   724,   158,     0,   416,     0,  1327,
   155,   153,     0,   154,   158,   156,   157,     0,  1325,   722,
   720,   412,   721,     0,   723,   411,     0,     0,   158,     0,
     0,   159,     0,   722,   720,  1322,   721,     0,   723,     0,
   159,     0,   206,   158,     0,   205,     0,     0,   722,   720,
  1317,   721,     0,   723,   159,   158,     0,     0,     0,     0,
   722,   720,   157,   721,     0,   723,     0,     0,     0,   159,
     0,   724,     0,     0,     0,     0,     0,     0,   253,     0,
     0,   159,     0,     0,   414,   724,     0,     0,     0,     0,
     0,     0,     0,     0,   357,     0,     0,     0,     0,     0,
   724,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,  1316,   724,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   358,   359,   360,   361,   362,   363,
   364,   365,   366,   367,   368,   369,   370,   371,   372,   373,
   375,   376,   377,   378,   379,   380,   381,   382,   383,   384,
   385,   386,   387,   388,   389,   390,   391,   374,   392,   393,
   394,   395,     0,    37,    38,    39,    40,    41,    42,    43,
    44,   397,     0,     0,     0,     0,   398,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   406,     0,     0,     0,
    21,     0,     0,     0,     0,     0,     0,     0,   167,   166,
   160,   161,   162,   163,   164,   165,     0,     0,   405,     0,
     0,     0,     0,   407,   356,   355,     0,     0,    19,    20,
   158,     0,     0,     0,     0,   722,   720,  1289,   721,   396,
   723,     0,     0,     0,     0,     0,     0,     0,     0,   158,
     0,     0,     0,  1045,   722,   720,   159,   721,   400,   723,
     0,     0,     0,     0,     0,     0,     0,   167,   166,   160,
   161,   162,   163,   164,   165,   159,     0,     0,   167,   166,
   160,   161,   162,   163,   164,   165,     0,   724,     0,     0,
     0,     0,   158,   404,     0,   403,  1043,   722,   720,   402,
   721,     0,   723,     0,     0,     0,   724,     0,   167,   166,
   160,   161,   162,   163,   164,   165,   206,     0,   159,   205,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   167,   166,   160,   161,   162,   163,   164,   165,
     0,   167,   166,   160,   161,   162,   163,   164,   165,   724,
     0,     0,   253,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   357,     0,
     0,     0,     0,     0,     0,     0,     0,   167,   166,   160,
   161,   162,   163,   164,   165,     0,   167,   166,   160,   161,
   162,   163,   164,   165,     0,     0,     0,     0,   358,   359,
   360,   361,   362,   363,   364,   365,   366,   367,   368,   369,
   370,   371,   372,   373,   375,   376,   377,   378,   379,   380,
   381,   382,   383,   384,   385,   386,   387,   388,   389,   390,
   391,   374,   392,   393,   394,   395,     0,    37,    38,    39,
    40,    41,    42,    43,    44,   397,     0,     0,     0,     0,
   398,     0,     0,   158,     0,     0,     0,     0,   722,   720,
  1288,   721,     0,   723,    21,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,   159,
     0,     0,   352,     0,     0,     0,     0,   354,   356,   355,
     0,     0,    19,    20,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   396,     0,     0,     0,     0,     0,   353,
   724,     0,     0,     0,   167,   166,   160,   161,   162,   163,
   164,   165,   347,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,     0,     0,     0,     0,   167,   166,   160,
   161,   162,   163,   164,   165,     0,     0,     0,     0,   167,
   166,   160,   161,   162,   163,   164,   165,   350,     0,   351,
  1340,   171,   169,   349,   170,     0,   172,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   206,     0,   174,   205,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,     0,   167,   166,   160,   161,   162,   163,
   164,   165,     0,   173,     0,     0,   253,     0,   167,   166,
   160,   161,   162,   163,   164,   165,     0,     0,     0,     0,
     0,     0,   357,   167,   166,   160,   161,   162,   163,   164,
   165,     0,     0,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   358,   359,   360,   361,   362,   363,   364,   365,
   366,   367,   368,   369,   370,   371,   372,   373,   375,   376,
   377,   378,   379,   380,   381,   382,   383,   384,   385,   386,
   387,   388,   389,   390,   391,   374,   392,   393,   394,   395,
     0,    37,    38,    39,    40,    41,    42,    43,    44,   397,
     0,     0,     0,     0,   398,     0,   158,     0,     0,     0,
     0,   722,   720,  1287,   721,   158,   723,     0,    21,  1041,
   722,   720,     0,   721,     0,   723,     0,     0,     0,     0,
     0,     0,   159,     0,     0,     0,  1138,     0,     0,     0,
     0,   159,   356,   355,     0,     0,    19,    20,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   396,     0,     0,
     0,     0,     0,   724,     0,     0,     0,     0,     0,     0,
     0,     0,   724,     0,     0,     0,   430,     0,     0,  1141,
     0,     0,   158,     0,     0,     0,  1039,   722,   720,     0,
   721,     0,   723,     0,     0,     0,     0,     0,     0,     0,
   167,   166,   160,   161,   162,   163,   164,   165,   159,     0,
     0,  1140,     0,  1139,     0,     0,     0,     0,     0,   167,
   166,   160,   161,   162,   163,   164,   165,     0,     0,     0,
     0,     0,     0,     0,   206,   158,     0,   205,     0,   724,
   722,   720,  1286,   721,     0,   723,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   159,   167,   166,   160,   161,   162,   163,   164,   165,
   253,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   357,     0,     0,  1137,
     0,     0,   724,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   358,   359,   360,   361,
   362,   363,   364,   365,   366,   367,   368,   369,   370,   371,
   372,   373,   375,   376,   377,   378,   379,   380,   381,   382,
   383,   384,   385,   386,   387,   388,   389,   390,   391,   374,
   392,   393,   394,   395,     0,    37,    38,    39,    40,    41,
    42,    43,    44,   397,     0,     0,     0,     0,   398,     0,
     0,     0,     0,     0,     0,   158,     0,     0,     0,  1035,
   722,   720,    21,   721,     0,   723,     0,   158,     0,     0,
     0,  1033,   722,   720,     0,   721,     0,   723,     0,     0,
  1131,   159,     0,     0,     0,     0,   356,   355,     0,     0,
    19,    20,     0,   159,     0,     0,     0,     0,     0,     0,
     0,   396,     0,   167,   166,   160,   161,   162,   163,   164,
   165,     0,   724,     0,     0,     0,     0,   338,   336,     0,
   430,     0,   158,  1134,   724,   337,     0,   722,   720,  1031,
   721,     0,   723,   158,     0,     0,     0,     0,   722,   720,
  1029,   721,     0,   723,   158,     0,     0,     0,   159,   722,
   720,  1027,   721,     0,   723,  1133,     0,  1132,     0,   159,
     0,     0,     0,     0,     0,     0,     0,   158,     0,   397,
   159,  1023,   722,   720,   398,   721,     0,   723,   206,   724,
     0,   205,     0,     0,     0,     0,     0,     0,     0,     0,
   724,     0,     0,   159,     0,     0,     0,     0,     0,     0,
     0,   724,     0,     0,     0,     0,   182,   181,   175,   176,
   177,   178,   179,   180,   253,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   724,     0,   335,     0,     0,     0,
   357,     0,     0,  1130,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   358,   359,   360,   361,   362,   363,   364,   365,   366,   367,
   368,   369,   370,   371,   372,   373,   375,   376,   377,   378,
   379,   380,   381,   382,   383,   384,   385,   386,   387,   388,
   389,   390,   391,   374,   392,   393,   394,   395,     0,    37,
    38,    39,    40,    41,    42,    43,    44,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,    21,     0,     0,   317,
   318,   319,     0,   320,   321,   322,   323,   324,   325,   326,
   327,   328,   329,   330,   331,   332,   333,   334,     0,     0,
   356,   355,     0,     0,    19,    20,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   396,   167,   166,   160,   161,
   162,   163,   164,   165,     0,   167,   166,   160,   161,   162,
   163,   164,   165,     0,   430,     0,   358,   359,   360,   361,
   362,   363,   364,   365,   366,   367,   368,   369,   370,   371,
   372,   373,   375,   376,   377,   378,   379,   380,   381,   382,
   383,   384,   385,   386,   387,   388,   389,   390,   391,   374,
   392,   393,   394,   395,     0,    37,    38,    39,    40,    41,
    42,    43,    44,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   167,   166,   160,   161,   162,   163,   164,   165,
   158,     0,    21,     0,     0,   722,   720,  1025,   721,     0,
   723,     0,   158,     0,     0,     0,  1021,   722,   720,     0,
   721,     0,   723,     0,     0,     0,   159,     0,   253,   158,
     0,     0,     0,  1019,   722,   720,     0,   721,   159,   723,
     0,     0,     0,     0,   357,   167,   166,   160,   161,   162,
   163,   164,   165,     0,     0,   159,     0,   724,     0,     0,
   430,     0,     0,     0,     0,     0,     0,     0,     0,   724,
   158,     0,     0,     0,     0,   722,   720,  1284,   721,     0,
   723,     0,     0,     0,     0,     0,   724,     0,     0,   397,
     0,     0,   433,   432,   398,     0,   159,     0,   158,     0,
     0,     0,  1014,   722,   720,     0,   721,     0,   723,   158,
     0,     0,     0,  1012,   722,   720,     0,   721,     0,   723,
     0,   435,   434,   158,   159,     0,     0,   724,   722,   720,
  1283,   721,     0,   723,     0,   159,   158,     0,     0,     0,
  1007,   722,   720,     0,   721,     0,   723,     0,     0,   159,
     0,     0,     0,     0,   253,   724,   397,     0,     0,     0,
     0,   398,   159,     0,   356,   355,   724,     0,    19,    20,
   357,     0,     0,     0,     0,     0,     0,     0,     0,   396,
   724,     0,     0,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,   724,     0,     0,     0,   167,   166,   160,
   161,   162,   163,   164,   165,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   427,   426,
     0,     0,     0,    69,     0,     0,     0,     0,    70,     0,
     0,     0,     0,     0,     0,   158,     0,     0,     0,  1005,
   722,   720,     0,   721,     0,   723,     0,   429,   428,     0,
     0,     0,   167,   166,   160,   161,   162,   163,   164,   165,
     0,   159,     0,   167,   166,   160,   161,   162,   163,   164,
   165,     0,     0,     0,   167,   166,   160,   161,   162,   163,
   164,   165,     0,     0,     0,     0,     0,     0,     0,     0,
   356,   355,   724,     0,    19,    20,     0,   167,   166,   160,
   161,   162,   163,   164,   165,   396,   358,   359,   360,   361,
   362,   363,   364,   365,   366,   367,   368,   369,   370,   371,
   372,   373,   375,   376,   377,   378,   379,   380,   381,   382,
   383,   384,   385,   386,   387,   388,   389,   390,   391,   374,
   392,   393,   394,   395,     0,    37,    38,    39,    40,    41,
    42,    43,    44,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,    21,   358,   359,   360,   361,   362,   363,   364,
   365,   366,   367,   368,   369,   370,   371,   372,   373,   375,
   376,   377,   378,   379,   380,   381,   382,   383,   384,   385,
   386,   387,   388,   389,   390,   391,   374,   392,   393,   394,
   395,     0,    37,    38,    39,    40,    41,    42,    43,    44,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   430,     0,     0,     0,     0,     0,     0,     0,     0,    21,
    22,    23,    24,    25,    26,    27,    28,    29,    30,    31,
    32,    33,    34,    35,    36,    45,   252,    48,    49,    50,
    51,    52,    53,    54,    55,    56,    57,    58,    59,    60,
    61,    62,    63,    46,    64,    65,    66,    67,     0,    37,
    38,    39,    40,    41,    42,    43,    44,     0,   158,     0,
     0,     0,  1003,   722,   720,     0,   721,   430,   723,   158,
     0,     0,     0,  1001,   722,   720,    21,   721,     0,   723,
     0,     0,     0,     0,   159,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   253,   159,     0,    69,     0,     0,
     0,     0,    70,     0,     0,     0,     0,     0,     0,     0,
   357,     0,     0,   158,     0,   724,     0,   999,   722,   720,
     0,   721,     0,   723,     0,     0,   724,     0,     0,     0,
     0,     0,   158,     0,   250,     0,   997,   722,   720,   159,
   721,  1188,   723,     0,     0,     0,     0,     0,     0,     0,
   167,   166,   160,   161,   162,   163,   164,   165,   159,     0,
     0,   253,   167,   166,   160,   161,   162,   163,   164,   165,
   724,     0,     0,     0,     0,     0,     0,   357,     0,   167,
   166,   160,   161,   162,   163,   164,   165,     0,     0,   724,
   158,     0,     0,     0,     0,   722,   720,   995,   721,     0,
   723,     0,     0,     0,     0,     0,     0,     0,  1186,     0,
     0,     0,     0,     0,     0,     0,   159,     0,     0,     0,
   167,   166,   160,   161,   162,   163,   164,   165,   253,     0,
   356,   355,     0,     0,    19,    20,     0,     0,     0,     0,
     0,     0,     0,     0,   251,   396,     0,   724,   167,   166,
   160,   161,   162,   163,   164,   165,     0,     0,     0,   167,
   166,   160,   161,   162,   163,   164,   165,     0,     0,     0,
     0,     0,     0,   167,   166,   160,   161,   162,   163,   164,
   165,     0,     0,     0,     0,     0,   167,   166,   160,   161,
   162,   163,   164,   165,     0,     0,     0,   356,   355,     0,
     0,    19,    20,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   396,     0,    22,    23,    24,    25,    26,    27,
    28,    29,    30,    31,    32,    33,    34,    35,    36,    45,
   252,    48,    49,    50,    51,    52,    53,    54,    55,    56,
    57,    58,    59,    60,    61,    62,    63,    46,    64,    65,
    66,    67,     0,    37,    38,    39,    40,    41,    42,    43,
    44,     0,     0,     0,   249,   248,     0,   158,    19,    20,
     0,   993,   722,   720,     0,   721,     0,   723,     0,    68,
    21,     0,     0,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,   159,   158,     0,     0,     0,   991,   722,
   720,     0,   721,   158,   723,     0,     0,   989,   722,   720,
     0,   721,     0,   723,     0,     0,     0,   158,     0,     0,
   159,  1282,   722,   720,   724,   721,   158,   723,     0,   159,
     0,   722,   720,  1281,   721,     0,   723,     0,   250,   158,
     0,     0,     0,   159,   722,   720,     0,   721,     0,   723,
     0,   724,   159,   158,     0,     0,     0,     0,   722,   720,
   724,   721,   158,   723,     0,   159,     0,   722,   720,  1240,
   721,     0,   723,     0,   724,     0,     0,     0,     0,   159,
     0,   158,     0,   724,     0,   692,   722,   720,   159,   721,
     0,   723,   158,     0,     0,  1266,   724,   722,   720,  1225,
   721,     0,   723,     0,     0,     0,     0,   159,     0,  1265,
   724,     0,     0,     0,     0,   158,     0,     0,   159,   724,
   722,   720,  1065,   721,     0,   723,     0,     0,     0,   158,
     0,     0,   253,  1045,   155,   153,     0,   154,   724,   156,
     0,   159,     0,     0,     0,     0,     0,     0,   649,   724,
     0,     0,   158,     0,     0,   159,  1043,   155,   153,     0,
   154,   158,   156,     0,     0,  1041,   155,   153,     0,   154,
     0,   156,   724,     0,     0,   158,     0,     0,   159,  1039,
   155,   153,     0,   154,     0,   156,   157,   159,     0,   158,
     0,     0,     0,     0,   155,   153,  1037,   154,     0,   156,
   158,   159,     0,     0,  1035,   155,   153,     0,   154,   157,
   156,     0,     0,     0,     0,   159,     0,     0,   157,     0,
     0,     0,     0,     0,     0,     0,   159,     0,     0,     0,
     0,     0,   157,     0,     0,     0,     0,     0,   167,   166,
   160,   161,   162,   163,   164,   165,   157,     0,     0,   167,
   166,   160,   161,   162,   163,   164,   165,   157,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   249,   248,
     0,     0,    19,    20,     0,     0,   158,     0,     0,     0,
  1033,   155,   153,    68,   154,     0,   156,     0,     0,     0,
     0,     0,     0,   167,   166,   160,   161,   162,   163,   164,
   165,   158,   159,     0,     0,     0,   155,   153,  1031,   154,
     0,   156,   167,   166,   160,   161,   162,   163,   164,   165,
     0,     0,     0,     0,   158,     0,     0,   159,     0,   155,
   153,  1029,   154,   157,   156,   158,     0,     0,     0,     0,
   155,   153,  1027,   154,     0,   156,     0,     0,     0,     0,
   159,     0,     0,     0,     0,     0,     0,   158,   157,     0,
     0,   159,   155,   153,  1025,   154,     0,   156,     0,     0,
   167,   166,   160,   161,   162,   163,   164,   165,     0,     0,
   158,   157,     0,   159,  1023,   155,   153,     0,   154,   158,
   156,     0,   157,  1021,   155,   153,     0,   154,     0,   156,
     0,     0,     0,   158,     0,     0,   159,  1019,   155,   153,
     0,   154,   158,   156,   157,   159,     0,   155,   153,  1015,
   154,     0,   156,     0,     0,     0,   158,     0,     0,   159,
  1014,   155,   153,     0,   154,   158,   156,   157,   159,  1012,
   155,   153,     0,   154,     0,   156,   157,     0,   158,     0,
     0,     0,   159,   155,   153,  1009,   154,     0,   156,     0,
   157,   159,   158,     0,     0,     0,  1007,   155,   153,   157,
   154,   158,   156,     0,   159,  1005,   155,   153,     0,   154,
     0,   156,     0,   157,     0,   158,     0,     0,   159,  1003,
   155,   153,   157,   154,     0,   156,     0,   159,   158,     0,
     0,     0,  1001,   155,   153,   157,   154,     0,   156,     0,
   158,   159,     0,     0,   999,   155,   153,     0,   154,   157,
   156,     0,     0,     0,   159,     0,     0,     0,   157,     0,
     0,     0,     0,     0,     0,   158,   159,     0,     0,   997,
   155,   153,   157,   154,     0,   156,     0,   167,   166,   160,
   161,   162,   163,   164,   165,   157,     0,     0,     0,     0,
     0,   159,     0,     0,     0,     0,     0,   157,     0,     0,
     0,     0,     0,     0,   167,   166,   160,   161,   162,   163,
   164,   165,     0,   167,   166,   160,   161,   162,   163,   164,
   165,     0,   157,     0,     0,     0,     0,   167,   166,   160,
   161,   162,   163,   164,   165,     0,   167,   166,   160,   161,
   162,   163,   164,   165,     0,     0,     0,     0,     0,   167,
   166,   160,   161,   162,   163,   164,   165,     0,     0,     0,
     0,     0,     0,   167,   166,   160,   161,   162,   163,   164,
   165,     0,   167,   166,   160,   161,   162,   163,   164,   165,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   167,   166,   160,   161,   162,   163,   164,   165,     0,
     0,     0,   167,   166,   160,   161,   162,   163,   164,   165,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,     0,     0,     0,     0,     0,     0,   167,
   166,   160,   161,   162,   163,   164,   165,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   167,   166,   160,   161,   162,   163,   164,   165,
     0,   167,   166,   160,   161,   162,   163,   164,   165,     0,
     0,     0,     0,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,     0,     0,     0,     0,     0,     0,   167,
   166,   160,   161,   162,   163,   164,   165,     0,     0,     0,
   167,   166,   160,   161,   162,   163,   164,   165,   158,     0,
     0,     0,     0,   155,   153,   995,   154,   158,   156,     0,
     0,   993,   155,   153,     0,   154,     0,   156,     0,     0,
     0,   158,     0,     0,   159,   991,   155,   153,     0,   154,
   158,   156,     0,   159,   989,   155,   153,     0,   154,     0,
   156,     0,     0,     0,     0,     0,     0,   159,     0,     0,
     0,     0,     0,   158,     0,   157,   159,   986,   155,   153,
     0,   154,     0,   156,   157,     0,   167,   166,   160,   161,
   162,   163,   164,   165,     0,     0,   158,     0,   157,   159,
     0,   722,   720,   983,   721,     0,   723,   157,     0,     0,
     0,   167,   166,   160,   161,   162,   163,   164,   165,     0,
     0,     0,   159,     0,     0,     0,     0,     0,     0,     0,
   157,     0,     0,     0,   167,   166,   160,   161,   162,   163,
   164,   165,     0,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,   724,   158,     0,     0,     0,     0,   722,
   720,   982,   721,     0,   723,     0,     0,   167,   166,   160,
   161,   162,   163,   164,   165,     0,     0,     0,     0,     0,
   159,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   167,   166,   160,   161,   162,   163,   164,   165,     0,   167,
   166,   160,   161,   162,   163,   164,   165,     0,     0,     0,
     0,   724,     0,   167,   166,   160,   161,   162,   163,   164,
   165,     0,   167,   166,   160,   161,   162,   163,   164,   165,
     0,     0,     0,     0,     0,     0,   167,   166,   160,   161,
   162,   163,   164,   165,     0,   167,   166,   160,   161,   162,
   163,   164,   165,     0,     0,     0,     0,     0,   167,   166,
   160,   161,   162,   163,   164,   165,     0,     0,     0,     0,
     0,     0,   167,   166,   160,   161,   162,   163,   164,   165,
     0,   167,   166,   160,   161,   162,   163,   164,   165,     0,
     0,     0,     0,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,     0,     0,     0,     0,     0,   167,   166,
   160,   161,   162,   163,   164,   165,     0,     0,     0,     0,
   167,   166,   160,   161,   162,   163,   164,   165,   158,     0,
     0,     0,     0,   722,   720,   970,   721,     0,   723,     0,
     0,     0,     0,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,   158,   159,     0,     0,     0,   722,   720,
     0,   721,   158,   723,     0,     0,     0,   722,   720,     0,
   721,     0,   723,     0,     0,     0,   158,     0,     0,   159,
     0,   722,   720,     0,   721,   724,   723,     0,   159,  1338,
   171,   169,     0,   170,     0,   172,     0,   966,   158,     0,
     0,     0,   159,   722,   720,   823,   721,     0,   723,   969,
   724,   174,     0,     0,     0,   158,     0,     0,   968,   724,
   722,   720,   798,   721,   159,   723,     0,     0,     0,     0,
   158,     0,     0,   724,     0,   722,   720,   793,   721,   158,
   723,   159,   173,     0,   722,   720,   777,   721,     0,   723,
     0,     0,   158,     0,     0,   724,   159,   722,   720,   769,
   721,     0,   723,   158,     0,   159,     0,     0,   722,   720,
   719,   721,   724,   723,     0,   158,     0,     0,   159,   692,
   155,   153,     0,   154,   152,   156,     0,   724,     0,   159,
     0,     0,   158,     0,     0,     0,   724,   722,   720,     0,
   721,   159,   723,     0,  1336,   171,   169,     0,   170,   724,
   172,   158,     0,     0,     0,     0,   155,   153,   159,   154,
   724,   156,     0,     0,     0,   158,   174,     0,     0,     0,
   155,   153,   157,   154,     0,   156,     0,   159,  1334,   171,
   169,     0,   170,     0,   172,     0,     0,     0,     0,   724,
     0,   159,     0,     0,     0,     0,     0,   173,     0,     0,
   174,     0,     0,  1328,   171,   169,     0,   170,   157,   172,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   157,     0,     0,   174,     0,     0,     0,     0,
     0,   173,     0,     0,     0,     0,     0,     0,   167,   166,
   160,   161,   162,   163,   164,   165,     0,   167,   166,   160,
   161,   162,   163,   164,   165,     0,   173,     0,     0,     0,
     0,   167,   166,   160,   161,   162,   163,   164,   165,     0,
   167,   166,   160,   161,   162,   163,   164,   165,     0,  1326,
   171,   169,     0,   170,     0,   172,     0,     0,     0,     0,
     0,     0,     0,   167,   166,   160,   161,   162,   163,   164,
   165,   174,  1324,   171,   169,     0,   170,     0,   172,     0,
     0,     0,     0,     0,     0,     0,   167,   166,   160,   161,
   162,   163,   164,   165,   174,     0,     0,     0,     0,  1044,
   171,   169,   173,   170,     0,   172,     0,  1042,   171,   169,
     0,   170,     0,   172,     0,     0,  1040,   171,   169,     0,
   170,   174,   172,     0,     0,   173,     0,     0,     0,   174,
     0,  1038,   171,   169,     0,   170,     0,   172,   174,     0,
     0,     0,     0,     0,   167,   166,   160,   161,   162,   163,
   164,   165,   173,   174,   171,   169,  1036,   170,     0,   172,
   173,  1034,   171,   169,     0,   170,     0,   172,     0,   173,
  1032,   171,   169,     0,   170,   174,   172,     0,     0,     0,
     0,     0,     0,   174,   173,     0,   171,   169,  1030,   170,
     0,   172,   174,     0,   171,   169,  1028,   170,     0,   172,
     0,     0,     0,     0,     0,     0,   173,   174,   171,   169,
  1026,   170,     0,   172,   173,   174,   171,   169,  1024,   170,
     0,   172,     0,   173,     0,     0,  1022,   171,   169,   174,
   170,     0,   172,     0,     0,     0,     0,   174,   173,  1020,
   171,   169,     0,   170,     0,   172,   173,     0,   174,  1018,
   171,   169,     0,   170,     0,   172,     0,     0,     0,     0,
   173,   174,   171,   169,  1016,   170,     0,   172,   173,     0,
     0,   174,     0,     0,  1013,   171,   169,     0,   170,   173,
   172,     0,     0,   174,  1011,   171,   169,     0,   170,     0,
   172,     0,   173,     0,     0,     0,   174,     0,     0,     0,
     0,     0,   173,     0,     0,     0,   174,     0,   171,   169,
  1008,   170,     0,   172,   173,     0,     0,     0,   167,   166,
   160,   161,   162,   163,   164,   165,     0,   173,     0,   174,
     0,     0,     0,     0,     0,     0,     0,   173,     0,     0,
     0,     0,     0,   167,   166,   160,   161,   162,   163,   164,
   165,     0,   167,   166,   160,   161,   162,   163,   164,   165,
   173,     0,     0,     0,     0,     0,   167,   166,   160,   161,
   162,   163,   164,   165,     0,   182,   181,   175,   176,   177,
   178,   179,   180,     0,     0,     0,     0,     0,   167,   166,
   160,   161,   162,   163,   164,   165,     0,  1006,   171,   169,
     0,   170,     0,   172,     0,   167,   166,   160,   161,   162,
   163,   164,   165,     0,     0,     0,     0,     0,     0,   174,
   167,   166,   160,   161,   162,   163,   164,   165,     0,   167,
   166,   160,   161,   162,   163,   164,   165,     0,     0,     0,
     0,     0,   167,   166,   160,   161,   162,   163,   164,   165,
   173,     0,     0,   167,   166,   160,   161,   162,   163,   164,
   165,     0,     0,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   167,   166,   160,   161,   162,   163,   164,   165,
   182,   181,   175,   176,   177,   178,   179,   180,     0,     0,
     0,   167,   166,   160,   161,   162,   163,   164,   165,     0,
     0,     0,     0,     0,     0,   167,   166,   160,   161,   162,
   163,   164,   165,     0,   182,   181,   175,   176,   177,   178,
   179,   180,     0,     0,     0,  1004,   171,   169,     0,   170,
     0,   172,     0,     0,     0,     0,     0,     0,     0,   182,
   181,   175,   176,   177,   178,   179,   180,   174,  1002,   171,
   169,     0,   170,     0,   172,     0,     0,  1000,   171,   169,
     0,   170,     0,   172,     0,     0,     0,     0,     0,     0,
   174,   998,   171,   169,     0,   170,     0,   172,   173,   174,
   996,   171,   169,     0,   170,     0,   172,     0,     0,     0,
     0,     0,     0,   174,     0,     0,     0,     0,     0,     0,
     0,   173,   174,     0,   171,   169,   994,   170,     0,   172,
   173,     0,     0,     0,     0,   182,   181,   175,   176,   177,
   178,   179,   180,     0,   173,   174,     0,     0,   992,   171,
   169,     0,   170,   173,   172,   196,     0,     0,   182,   181,
   175,   176,   177,   178,   179,   180,     0,     0,     0,     0,
   174,     0,     0,     0,     0,     0,   173,     0,     0,     0,
     0,     0,     0,     0,     0,   182,   181,   175,   176,   177,
   178,   179,   180,   182,   181,   175,   176,   177,   178,   179,
   180,   173,   182,   181,   175,   176,   177,   178,   179,   180,
     0,     0,     0,     0,     0,     0,     0,   182,   181,   175,
   176,   177,   178,   179,   180,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,   182,
   181,   175,   176,   177,   178,   179,   180,   182,   181,   175,
   176,   177,   178,   179,   180,     0,   182,   181,   175,   176,
   177,   178,   179,   180,     0,     0,     0,     0,     0,     0,
     0,   182,   181,   175,   176,   177,   178,   179,   180,   182,
   181,   175,   176,   177,   178,   179,   180,     0,     0,     0,
   911,     0,     0,   182,   181,   175,   176,   177,   178,   179,
   180,   182,   181,   175,   176,   177,   178,   179,   180,   912,
     0,     0,   182,   181,   175,   176,   177,   178,   179,   180,
     0,     0,     0,     0,     0,   182,   181,   175,   176,   177,
   178,   179,   180,     0,     0,   182,   181,   175,   176,   177,
   178,   179,   180,     0,     0,     0,     0,   182,   181,   175,
   176,   177,   178,   179,   180,     0,     0,     0,     0,     0,
   182,   181,   175,   176,   177,   178,   179,   180,     0,     0,
   182,   181,   175,   176,   177,   178,   179,   180,     0,   990,
   171,   169,     0,   170,     0,   172,     0,     0,     0,     0,
   203,     0,     0,   182,   181,   175,   176,   177,   178,   179,
   180,   174,   988,   171,   169,   913,   170,     0,   172,     0,
     0,   987,   171,   169,     0,   170,   168,   172,     0,     0,
   171,   169,     0,   170,   174,   172,     0,     0,     0,     0,
   199,     0,   173,   174,     0,     0,   967,     0,   691,   171,
   169,   174,   170,     0,   172,     0,     0,     0,   171,   169,
     0,   170,     0,   172,     0,   173,   171,   169,     0,   170,
   174,   172,     0,     0,   173,     0,     0,     0,     0,   174,
     0,     0,   173,     0,     0,     0,     0,   174,     0,   202,
     0,     0,     0,   182,   181,   175,   176,   177,   178,   179,
   180,   173,     0,     0,     0,     0,     0,   200,     0,     0,
   173,     0,     0,     0,     0,     0,     0,     0,   173,     0,
     0,     0,     0,     0,     0,   198,     0,     0,     0,     0,
     0,   914,   915,   916,   917,   918,   919,   920,   921,   922,
   923,   924,   925,   926,   927,   928,   929,   930,   931,   932,
   933,   934,   935,   936,     0,     0,     0,     0,   206,     0,
     0,   205,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   204,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   182,   181,   175,   176,   177,   178,   179,   180,     0,
     0,   201,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   182,   181,   175,   176,   177,   178,
   179,   180,     0,   182,   181,   175,   176,   177,   178,   179,
   180,     0,     0,     0,     0,     0,     0,   182,   181,   175,
   176,   177,   178,   179,   180,     0,   182,   181,   175,   176,
   177,   178,   179,   180,     0,     0,   870,     0,   867,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,   182,
   181,   175,   176,   177,   178,   179,   180,   880,   850,     0,
   847,   846,   882,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   503,   499,   182,   181,   175,   176,   177,   178,
   179,   180,     0,     0,     0,     0,     0,     0,     0,     0,
   845,     0,     0,   497,     0,   881,     0,   866,     0,   495,
     0,     0,     0,     0,     0,   502,     0,   492,   879,     0,
   860,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   852,     0,     0,     0,     0,   871,   848,     0,   869,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,   883,
     0,     0,     0,     0,     0,     0,     0,   500,     0,   501,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   206,   490,     0,   205,   874,     0,     0,     0,     0,     0,
   206,     0,     0,   205,     0,   858,     0,     0,     0,     0,
     0,     0,   865,   868,     0,     0,     0,     0,     0,     0,
     0,     0,   491,     0,     0,     0,     0,   853,     0,     0,
     0,     0,     0,     0,     0,   841,     0,     0,   842,     0,
     0,     0,     0,     0,   875,     0,   872,     0,   206,   843,
   844,   205,   854,     0,   859,   504,   496,   873,   876,     0,
     0,   877,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   864,     0,   493,     0,   878,     0,     0,
     0,     0,     0,   489,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   851,     0,     0,     0,     0,   856,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   498,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   855,     0,     0,     0,   182,   181,   175,   176,   177,
   178,   179,   180,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   182,   181,
   175,   176,   177,   178,   179,   180,   884,   182,   181,   175,
   176,   177,   178,   179,   180,   182,   181,   175,   176,   177,
   178,   179,   180,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   182,   181,   175,   176,   177,   178,
   179,   180,     0,   182,   181,   175,   176,   177,   178,   179,
   180,   182,   181,   175,   176,   177,   178,   179,   180,     0,
     0,     0,     0,     0,   857 };
yytabelem yypact[]={

  1177, -1000,  1206,  1205,  1203,  5694,  6706,  1202,  1199,  1197,
  1196,  1194,  1064,  1038,   730,   728,   522,  6409,   822, -1000,
 -1000,  1146,  1145,  1143,  1142,  1141,  1131,  1128,  1127, -1000,
 -1000, -1000,  1126,  1125,  1124,  1121,  1120, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000,  1119,  1117,  1110,
  1105,  1104,  1103,  1102,  1100,  1098,  1095,  1094,  1092,  1090,
 -1000, -1000, -1000,  1087,  1086,  1083,  1078,  1077,  3803,  3803,
  3803, -1000,    21,   346,   243,  -276, -1000,   -34,    25,    19,
    19,    19, -1000,  -291,  -292,    19,   345,   342,    75,     7,
    62,    42,   183, -1000,  -255,  1076,  1074,  1063,  1060,  1059,
  1058,  -118,   177,   694,   152,  1227,  2958, -1000, -1000, -1000,
  -520,    61,  2381,  2117,  1853,   213,  3299,  3173,   706,   299,
   324,  1549,   446,   366, -1000,   228,  6681,   111,  -293,   229,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000,   964,   964,   964, -1000, -1000,
 -1000, -1000, -1000,  3803,  3803,  3803,  3803,  3803,   640,   640,
   640,   640,   640,   640,   640,   640,   640,   640, -1000,  3803,
  3803,  3803,  3803,  3803,  3803,  3803,  3803,  3803,  3803,  3803,
  3803,  3803,  3803, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
   640,  3803,   640,  3803,   640,  -114,  1112, -1000,   177,    38,
    19,   670,    26,   -71, -1000, -1000, -1000, -1000,   -31,  -294,
  -295,  -296,   640,   640,  -245,     2,  3803,  3803,  3803,  3803,
  3803,  3803,  3803,  3803,  3803,  3803,  3803,  3803,  4107,  3803,
  3803,  -297,  3803,  3803,  3803,  3803,  3803,  3803,  3803,  3803,
  3803,  3803,  3803,  3803,  3803,  3803,   705,   672,   607,   605,
   813,   804,  1056,   800,  6697,  5658,   705,   672,   177, -1000,
  -298,   900, -1000, -1000,  -299, -1000, -1000, -1000, -1000, -1000,
 -1000,  -128,   177, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000,  -300,  -301,  -302,  -303,  -130,
   794,  -132,   793, -1000, -1000, -1000, -1000,  -304,    -6,    -7,
   -11,   -16,   -38,   -39, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,   341,   209,
 -1000,   640, -1000, -1000, -1000, -1000, -1000,   777,  5646,  -157,
  -305,  -306,  -308,   241, -1000,   607,   605,   787,  1050,  1049,
  1046,  1045,  1044,  1032,  1030, -1000, -1000, -1000,  1029,  1028,
  1025,  1021,  1019, -1000, -1000,  1014,   996,   995,   991,   989,
   987,   984,   983,   982,   980,   979,   957,   955, -1000, -1000,
 -1000,   946,   942,   939,   938,   937,   640,   640,   640, -1000,
   777,  5635,  -157,  -310,  -312,  -315,  -468, -1000, -1000,   777,
  5622,  -157,  -316,  -336,  -338,  -339,  -341,   -75,   339,  -342,
  -344,  -346,   -78,  -479,   -84,  5613,   640,   640,   640,   640,
   777,  5598,  -352,  -353,  -354,  -355, -1000,  -356,  -357,  -358,
  -359, -1000,  -360,  -362,  -364,  -367,   -72,   366, -1000, -1000,
 -1000, -1000,  -157,  -368,  -383,  -399,  -400,   781,  5581,   640,
   640,   -85,  -403,  -404,  -405,  -406,  -408, -1000,  -411,  -412,
  -413,  -414,   177,   239, -1000,  6729,  6671,   751,   358, -1000,
  -415,   177,  -416,  -417,  -418,  -157,  -155, -1000, -1000,  1227,
   640,  -419,  6245,  -307,  -426,  -320,  -429,   -30,   640,   332,
 -1000, -1000, -1000, -1000, -1000,   326,  1156, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000,  -430, -1000, -1000,  -432,
  -433,  -437,  -440,   -90,   177, -1000, -1000,  1230,  1010,  1230,
  1010,   719,   634,   719,   634,   719,   634,   621,  5559,   743,
   743,   743,   743,   743,   743,   338,    90,  1010,  1230,  1010,
  1230,   634,   740,   634,   740,   740,   634,  6678,  5708,  1323,
  1323,  1323,  1323,  1323,  1323,  1034,   207,  5545,  6714,  5708,
  5536,  6714,  5708,  5511,   720, -1000, -1000, -1000, -1000, -1000,
 -1000,   511, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000,   149, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000,  6245,  -463,   640,  -464,
  -465, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000,  5337,  5279,   757,   891,  5256,  6670,  6661,  5233,  6638,
  5224,  6407,  5210,  6382,  5201,  6359,  4948,  6350,  4923,  6336,
  4911,  6327,  4898,  6304,  4884,  6166,  4875,  6076,  4861,   826,
  6053,  4848,  6043,  4839,  4825,  6030,   935,  6018,  4816,  6008,
  4802,  5995,  4793,  5984,  4770,  5976,  4748,  5962,  4737,  5954,
  4714,  5939,  4689,  5930,  4613,  5922,  4602,  5900,  4588,  5885,
  4574,  5876,  4565,  5868,  4542,   640,   640,   704,  -134,  3803,
  -247, -1000, -1000, -1000, -1000,  -466, -1000,   192, -1000, -1000,
 -1000, -1000, -1000,   -40,   -45,   -47,   -49,   849,   848,   847,
   843,   842,   839,   836, -1000, -1000,   314,  4528,   555,   640,
   640,   640,   640,   640,   640, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000,  -467,  -470, -1000,  -243,   640,   640,   640,   640,
   640,   640,   640,   640,   640,   640,   640,   640,   640,   640,
   640,  -471,   640,   640,   640,   640,   640,   640,   640,   640,
   640,   640,   640,   640,   640,   640,   672,  4494,   672,   640,
 -1000, -1000, -1000, -1000, -1000,  -472,  -473,   640, -1000, -1000,
 -1000, -1000, -1000, -1000,  -474, -1000, -1000, -1000, -1000,  -475,
 -1000,  -476,  -477,   640,  5675,  5675,  5675,  5675,   640, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000,  -481, -1000, -1000, -1000, -1000, -1000, -1000, -1000,    28,
  -491,  -492,  -494,   640,  5675,  5675,  -496, -1000, -1000, -1000,
 -1000,   306, -1000, -1000, -1000, -1000, -1000,  -499,  6729, -1000,
 -1000,  2909,  2645,   640,   640,   177,   640,   640,  -503, -1000,
   177,  -506,  -507,  -508,   127,   146,  -509,   832, -1000, -1000,
 -1000,  6671, -1000, -1000,   129,  -510,   -70,   305,   304,     4,
  -511,   250,  -512,  -513,   127,   364,  3736,  3669,  -514,  -515,
   -94,  -516,  -519,  -521,   831, -1000, -1000,   123,  -309,   250,
   -99,  -522,  -523,  -525, -1000, -1000,  -526,  -527,  -530, -1000,
 -1000, -1000, -1000, -1000, -1000,  -531,   101, -1000,  5675, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,  -532,    19,
  -534,  -536,  -539, -1000, -1000,   210,  -540, -1000, -1000, -1000,
  -542,   127,  -547,  -548,   353,  4505, -1000, -1000,   298, -1000,
 -1000, -1000, -1000, -1000,  -551, -1000,   640,  3803,   741,   735,
   640,   640,  3803,   640,  -248, -1000, -1000,  6245,   830,  4475,
 -1000, -1000,   640,   640,   640,  -250, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000,  3803,   640, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,  3803,  3803,
 -1000, -1000, -1000, -1000, -1000,  -552,  -553, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000,   640,   640,  3803,   640,  3803,   640,
  3803,   640, -1000, -1000, -1000, -1000,  3803,  3803, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000,  4466,  4452,   774,   604,
 -1000,   829, -1000, -1000,  -145, -1000,  -148,   640,  -555,  -556,
  -557,   640,   640,  -558, -1000,   640,   758,  4439,  1223,  1223,
   621,   621,   621, -1000, -1000,   604,  4430,  4416,  4407,  4380,
  4203,  4145,  4126,  4082,  4071,  3818,  3719,  3706,  3692,  3681,
  3653,   934,  3612,  3595,  3300,  3583,  3277,  3266,  3255,  3200,
  3188,  3048,  2995,  2928,  2495,  2452,  2919, -1000, -1000,  5675,
 -1000, -1000, -1000, -1000,  2656,  2433, -1000, -1000,   210,  -559,
 -1000, -1000, -1000,  5675, -1000, -1000, -1000, -1000, -1000,  5675,
  -560,  -562,  -563,  -564,   177, -1000,  5675,  -566,  -571,  -573,
  -574,   177,  5675,  5675, -1000,  5675,  5675, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000,   640, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000,  5675,    76,  5675,    72, -1000,
 -1000,  -576, -1000, -1000, -1000,   297, -1000, -1000, -1000, -1000,
   827, -1000,  -577, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000,  -578,  -579,   640, -1000, -1000,  5675,  6714,
   640,   640,  5675,  2268,  6714,  5708,  2256,   718, -1000,  -580,
   640,  2241,  5675,  5675,   929,  5841,  2227,  5818,  2218,  5742,
  2172,   925,   924,  2160,  2148,  5717,  2137,  5683,  2009,  5568,
  2000,  2759,  1964,   489,  1955, -1000, -1000,  -251,   640,  -582,
   174,   154,  1931,   923,   914,   913,  1901,  1890,   911,  1831,
  -253,   640, -1000,   640,  -583, -1000,   640,   640,   640,   640,
 -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000,  5675, -1000, -1000, -1000, -1000, -1000, -1000,  -584,
 -1000, -1000, -1000,  5675,  5675,  5675,   723,   640,   640,  3803,
 -1000,  5675,   640, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000,   640,   640, -1000, -1000, -1000, -1000, -1000, -1000,
 -1000, -1000, -1000, -1000,   602,  1629,   819,   721,   687,   640,
 -1000, -1000, -1000,   640,   640, -1000,   640,   602,  1469,  1298,
   909,  1284,  1236,  1133,  1109, -1000,   640,  5675,  1008,  6714,
  5708,   997,   689,   625,   640, -1000,  -585,   -67,   -69,  5675,
   570,   394,   370,   640, -1000, -1000, -1000,   640,   640,   640,
  5675,   714,   640, -1000, -1000,    83, -1000, -1000, -1000,  -595,
  -603,   640,  5675,  5675,  5675,  5675,   640,  5675, -1000,   908,
   905,    35,  5675, -1000, -1000,   640,     3,   640,   -20,   640,
   -29,   640,  5675 };
yytabelem yypgo[]={

     0,     0,   110,  1291,  1285,  1276,   359,     2,     5,   596,
     3,  1275,  1274,     6,     4,  1271,   440,  1268,  1263,  1262,
  1259,  1258,  1257,  1254,  1253,   611,   574,  1250,  1239,  1236,
  1235,  1234,  1233,  1230,  1229,  1228,   691,   505,   689,   718,
  1225,  1224,  1219,  1218,    10,     7 };
yytabelem yyr1[]={

     0,    30,    30,    30,    30,    30,    30,    30,    30,    30,
    30,    30,    30,    30,    33,    33,    33,    33,    33,    33,
    16,    16,    16,    16,    16,    16,    16,    16,    17,    17,
    17,    17,    17,    17,    17,    17,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    22,    22,    22,    22,    22,    22,    22,    22,    22,
    22,    21,    21,    21,    21,    21,    21,    21,    26,    26,
    26,    26,    26,    26,    26,    26,    26,    26,    26,    26,
    26,    26,    26,    26,    26,    26,    26,    26,    19,    19,
    19,    19,    19,    19,    19,    19,    19,    19,    18,    18,
    18,    18,    18,    18,    32,    35,    34,    34,    34,    34,
    34,    34,    34,    34,    34,    34,    34,    34,    34,    34,
    34,    34,    34,    34,    34,    34,    34,    34,    34,    34,
    34,    31,    31,    31,    31,    31,    31,    36,    36,    36,
    36,    36,    36,    38,    38,    38,    39,    39,    39,    39,
    39,    39,    39,    37,    37,    37,    37,    37,    40,    40,
    44,    44,    44,    44,    44,    44,    44,    44,    44,    44,
    44,    44,    44,    44,    44,    44,    44,    44,    44,    44,
    44,    44,    44,    44,    44,    44,    44,    44,    44,    44,
    44,    41,    41,    45,    45,    45,    45,    45,    45,    45,
    45,    45,    45,    45,    45,    45,    45,    45,    45,    45,
    45,    45,    45,    45,    45,    45,    45,    45,    45,    45,
    45,    45,    45,    42,    42,    42,    42,    42,    42,    42,
    42,    42,    42,    42,    43,    43,    43,    43,    20,    20,
    20,    20,    20,    20,    23,    23,    23,    23,    23,     6,
     6,     7,     7,    27,    27,    27,    27,    27,    28,    28,
    28,    28,    25,    25,    24,    24,    24,    14,    14,    14,
    14,    14,    13,    13,    13,    29,    29,    29,    29,     8,
     8,    11,    11,    11,    10,    10,    10,    10,    10,    10,
    10,    10,    10,    10,    10,    10,    10,    10,    10,    10,
    10,    10,    10,    10,    10,    10,    10,    10,    10,    10,
    12,    12,    12,    15,    15,    15,    15,    15,    15,     9,
     9,     3,     3,     3,     3,     5,     4,     4,     4,     4,
     4,     4,     4,     4,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,     1,     1 };
yytabelem yyr2[]={

     0,     0,     4,     4,     4,     5,     5,     4,     4,     4,
     4,     4,     4,     5,     7,     9,     7,     5,     7,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     5,     7,
     7,     7,     7,    19,    11,     9,     3,     7,     5,     7,
    17,     3,     5,     5,     7,     7,     5,     5,     5,     3,
     5,     5,     5,     5,     5,     5,     5,     7,    11,    15,
     9,    17,     9,    17,     5,     5,     5,     5,     3,    15,
    13,    13,    13,    21,    21,    13,     9,     3,     5,     5,
     5,     5,     5,     5,     5,     5,     5,     5,     5,     5,
     7,     7,     9,     3,     3,     3,     5,    35,     5,     5,
     5,     7,     5,     5,    17,     7,     7,     7,     7,     7,
     9,     9,     5,     5,     7,     5,     5,     5,    17,     7,
     7,     7,     7,     7,     9,     9,     5,     5,     5,     7,
     5,     5,     9,     7,     7,     7,     7,     7,     7,     9,
     7,     7,     7,     7,     9,     7,     9,     9,    17,     7,
     7,     7,     7,    17,     7,     7,     7,     7,     5,     7,
     7,     7,     7,     5,     7,     7,     7,     7,     9,     5,
     7,     7,     7,     7,     7,     7,     9,    11,    11,     9,
     9,     9,     9,     7,     7,     9,     7,     7,     7,     7,
     9,     5,     7,     7,     7,     7,     7,     9,     5,     7,
     9,     9,     7,     7,     7,     7,    11,    13,    13,     9,
     9,     7,     7,     7,     7,     7,     7,     9,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     2,     2,
     2,     2,     2,     2,     4,     1,     7,     5,     5,     5,
     5,     5,     7,     7,     7,     7,     7,     5,     5,     7,
     7,     5,     7,     7,     7,     7,     7,     9,     9,     9,
     5,     2,     4,     2,     4,     6,     4,     2,     2,     2,
     2,     2,     2,     4,     4,     4,     3,     5,     5,     5,
     5,     7,     5,     4,     4,     4,     4,     3,     2,     4,
     3,     5,     5,     5,     5,     5,     5,     5,     5,     5,
     5,     3,     5,     5,     7,     7,     5,     5,     7,     7,
     7,     7,     7,     7,     7,     7,     5,     5,     5,     5,
     7,     2,     4,     3,     5,     5,     5,     5,     5,     5,
     5,     5,     5,     5,     5,     5,     5,     5,     5,     5,
     5,     5,     7,     7,     7,     7,     5,     5,     7,     5,
     5,     5,     7,     3,     5,     5,     5,     5,     9,     5,
     7,     5,     5,     5,     3,     5,     5,     5,     7,     3,
     3,     5,     5,     5,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
     3,    13,    13,    17,    21,    11,     7,     7,    11,    15,
     7,     7,    11,    15,     3,     3,    11,     7,     3,     7,
     7,     7,     7,     7,     7,     7,     7,     7,     7,     7,
     7,     7,     7,     7,     7,     7,     7,     7,     7,     9,
     9,     9,     9,     9,    13,     9,     9,     3,     3,     3,
     9,     9,     9,     9,    13,    13,    13,    13,     3,     3,
     9,     9,    13,    13,     9,     9,     9,     9,    17,    13,
    13,    13,     9,     9,     3,     3,     3,    13,    13,    13,
    13,     9,     9,     9,     9,    11,     7,     7,     7,     7,
     7,     7,     7,     7,     5,     7,     5,     2,     3,     9,
     9,     7,    13,     7,     7,    13,    17,     7,     7,     7,
     7,     7,     7,     9,     9,     9,     9,    13,     9,     9,
     3,     3,     3,     9,     9,     9,     9,    13,     7,     7,
     7,     7,     7,     7,     7,     7,     3,     3,     3,     3,
     3,     3,     3,     3,     3,     3,     9,     9,    13,     9,
     9,     9,     9,    17,    13,    13,    13,     9,     9,     3,
     3,     3,    13,     9,     9,     9,     9,    11,     7,     7,
     7,     7,     7,     7,     7,     7,     5,     7,     5 };
yytabelem yychk[]={

 -1000,   -30,    -3,    -4,    -5,    -1,    -2,   -22,   -17,   -31,
   -21,   -32,   -33,   256,   612,   611,   491,   381,   475,   615,
   616,   323,   257,   258,   259,   260,   261,   262,   263,   264,
   265,   266,   267,   268,   269,   270,   271,   296,   297,   298,
   299,   300,   301,   302,   303,   272,   290,   273,   274,   275,
   276,   277,   278,   279,   280,   281,   282,   283,   284,   285,
   286,   287,   288,   289,   291,   292,   293,   294,   626,    40,
    45,   473,   320,   358,   327,   340,   363,   446,   419,   305,
   377,   326,   513,   496,   304,   308,   379,   471,   528,   309,
   343,   431,   405,   371,   420,   474,   -27,   -28,   610,   392,
   351,   321,   421,   372,   498,   522,   472,   469,   470,   344,
   502,   338,   333,   415,   511,   347,   529,   527,   518,   512,
   382,   411,   378,   -36,   -38,   524,   -20,   463,   349,   385,
   482,   484,   483,   486,   485,   350,   366,   402,   403,   537,
   566,   313,   314,   570,   571,   325,   536,   565,   492,    10,
    10,    10,    10,    43,    45,    42,    47,    94,    37,    63,
   619,   620,   621,   622,   623,   624,   618,   617,    10,    43,
    45,    42,    47,    94,    63,   619,   620,   621,   622,   623,
   624,   618,   617,    10,    10,    10,    10,    10,    10,    10,
    91,    61,    91,    61,   458,    46,    46,    -6,   406,   321,
   388,   522,   370,   281,   492,   442,   439,    -6,   522,   341,
   416,   418,   415,   541,    46,    40,    40,    40,    40,    40,
    40,    40,    40,    40,    40,    40,    40,    40,    40,    40,
    40,    40,    40,    40,    40,    40,    40,    40,    40,    40,
    40,    40,    40,    40,    40,    40,    -2,    -1,   612,   611,
   381,   491,   273,   475,    -2,    -1,    -2,    -1,   473,   337,
   341,   615,   -15,   615,   399,   523,   306,   479,   410,   396,
   445,   475,   446,    -8,   521,   365,    -8,    -8,   615,   615,
    -8,   337,   337,   381,   491,   333,   415,   511,   491,   491,
   381,   491,   381,   491,   492,   381,   382,   612,    40,    40,
    40,    40,    40,    40,   536,   565,   491,    -6,   381,    -6,
   490,   373,   339,   -25,   352,   456,   -26,   541,   542,   543,
   545,   546,   547,   548,   549,   550,   551,   552,   553,   554,
   555,   556,   557,   558,   559,   438,   330,   337,   329,   -26,
   615,   529,   502,   333,   415,   511,    -6,   381,    -1,   422,
   416,   418,   341,   368,   346,   612,   611,   491,   257,   258,
   259,   260,   261,   262,   263,   264,   265,   266,   267,   268,
   269,   270,   271,   272,   290,   273,   274,   275,   276,   277,
   278,   279,   280,   281,   282,   283,   284,   285,   286,   287,
   288,   289,   291,   292,   293,   294,   626,    40,    45,    -6,
   381,    -1,   422,   418,   416,   341,   319,   346,    -6,   381,
    -1,   422,   418,   341,   481,   374,   404,   336,   346,   416,
   418,   341,   336,   374,   514,    -1,   540,   539,   569,   568,
   381,    -1,   540,   539,   569,   568,   337,   374,   494,   341,
   418,   337,   374,   494,   341,   418,   281,   -36,   -38,   492,
   491,    -6,   422,   407,   526,   387,   412,   333,    -1,   531,
   560,   336,   374,   416,   418,   341,   511,    -6,   522,   416,
   418,   341,   368,   327,   -37,   515,   516,   406,   328,    -6,
   488,   411,   418,   416,   341,   422,   319,   -34,    -6,   522,
   430,   461,   376,   514,   -23,   368,   495,   362,   557,   342,
   416,   418,   374,   341,   494,   -16,   519,   466,   468,   428,
   427,   391,   390,   385,   367,   615,   349,   -39,    -6,   341,
   418,   416,   374,   336,   384,   -39,   -39,    -1,    -2,    -1,
    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -1,    -1,
    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -2,    -1,    -2,
    -1,    -2,    -1,    -2,    -1,    -1,    -2,    -2,    -1,    -2,
    -2,    -2,    -2,    -2,    -2,    -2,    -2,    -1,    -2,    -1,
    -1,    -2,    -1,    -1,   611,   -29,   412,   540,   539,   569,
   568,   491,   296,   297,   298,   299,   300,   301,   302,   303,
    -6,   522,    -8,    -8,   -19,   541,   423,   424,   425,   328,
   386,   503,   504,   459,   544,    -6,   376,   461,   541,   522,
   492,   -18,   572,   573,   410,   479,   574,   575,   615,   615,
   615,    -1,    -1,   611,   491,    -1,    -2,    -2,    -1,    -2,
    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,
    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,   491,
    -2,    -1,    -2,    -1,    -1,    -2,   615,    -2,    -1,    -2,
    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,
    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,    -1,    -2,
    -1,    -2,    -1,    -2,    -1,    91,    91,    46,    46,    40,
    46,    41,    41,    -6,   615,    44,   615,   519,    -6,   615,
   615,   615,   615,   519,    46,   519,    46,   615,   491,   491,
   491,   491,   491,   491,   337,   337,   -25,    -1,    46,    44,
    43,    45,    42,    47,    94,    -9,   529,   527,   615,   615,
   615,   -24,   341,   451,   436,    46,    40,    40,    40,    40,
    40,    40,    40,    40,    40,    40,    40,    40,    40,    40,
    40,    40,    40,    40,    40,    40,    40,    40,    40,    40,
    40,    40,    40,    40,    40,    40,    -1,    -1,    -1,    44,
    -9,   615,   615,   615,   615,   494,   522,    44,    -9,   615,
   615,   615,   615,   615,   494,   337,   615,   615,   615,   494,
   615,   498,   494,    44,    -1,    -1,    -1,    -1,    44,   615,
   615,   615,   615,   615,   615,   615,   615,   615,   615,   615,
   615,   492,   -37,    -9,   615,   615,   615,   615,    -6,   368,
   341,   416,   418,    44,    -1,    -1,   494,   615,   615,   615,
   615,   615,   615,   615,   615,   615,    -6,   341,   -40,   -44,
    -6,   426,   429,   440,   441,   311,   282,   281,   347,   -11,
   279,   494,   341,   418,   443,   522,   499,   615,   396,   445,
   331,   -41,   -45,    -6,   522,   461,   376,   317,   462,   407,
   315,   404,   495,   506,   443,   493,   507,   510,   526,   387,
   336,   374,   341,   418,   615,   -42,   337,   407,   457,   404,
   336,   374,   341,   418,   -43,    -6,   341,   416,   418,   615,
    -6,   615,   615,   615,    -9,   522,   -35,   -26,    -1,   615,
   -10,   345,   364,   460,   576,   577,   578,   579,   580,   581,
   582,   583,   584,   585,   586,   587,   588,   589,   590,   591,
   592,   593,   594,   595,   596,   597,   598,   615,   368,   335,
   494,   336,   495,   615,   615,   528,    -7,   341,   451,   615,
   412,   522,   418,   416,   480,    -1,   337,   337,   -16,   615,
   615,   615,   615,   615,   494,    -6,    58,    58,    93,    93,
    44,    91,    61,   458,    46,   320,   499,   -10,   615,    -1,
   615,   615,    44,    44,    61,    44,    41,    41,    41,    41,
    41,    41,    41,    41,    44,    44,    41,    41,    41,    41,
    41,    41,    41,    41,    41,    41,    41,    41,    44,    44,
    41,    41,    41,    41,    41,    44,    44,    41,    41,    41,
    41,    41,    41,    41,    44,    44,    44,    44,    44,    44,
    44,    44,    41,    41,    41,    41,    44,    44,    41,    41,
    41,    41,    41,    41,    41,    41,    -1,    -1,   491,   611,
   611,   615,   381,   491,   491,   491,   491,    44,    44,    44,
    44,    44,    44,    44,   337,    44,   491,    -1,    -1,    -1,
    -1,    -1,    -1,   615,   615,   611,    -1,    -1,    -1,    -1,
    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
    -1,   615,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
    -1,    -1,    -1,    -1,    -1,    -1,    -1,   615,   615,    -1,
   615,   615,   615,   615,    -1,    -1,   615,    -6,   528,    -7,
   615,   615,   615,    -1,   615,   337,   615,   -44,    -6,    -1,
   494,   341,   418,   416,   384,    -6,    -1,   494,   341,   418,
   416,   384,    -1,    -1,    -6,    -1,    -1,   615,    -6,   615,
   615,   615,   -14,   520,   332,   410,   479,   331,   320,   499,
   615,    44,   -45,   320,   499,   615,   -10,   615,   337,   337,
   389,   525,   499,   615,   -13,   479,   410,   335,   615,   615,
   -14,   -12,   437,   307,   434,    -1,   522,    -1,   522,   615,
   615,   494,   615,   615,   615,    44,   453,   447,   320,   499,
   615,   -13,   494,   615,   615,   615,   615,   615,   615,   615,
   394,   615,    -8,   615,   615,   615,    -7,   615,   615,   -14,
   615,   615,    -6,   418,   416,    44,   337,   615,    -1,    -2,
    61,    61,    -1,    -1,    -2,    -1,    -1,   611,   -10,    44,
    44,    -1,    -1,    -1,   611,    -2,    -1,    -2,    -1,    -2,
    -1,   615,   615,    -1,    -1,    -2,    -1,    -2,    -1,    -2,
    -1,    -2,    -1,    -2,    -1,    93,    93,    46,    91,    44,
   519,   519,    -1,   615,   615,   615,    -1,    -1,   615,    -1,
    46,    44,    41,    44,    44,    41,    44,    44,    44,    44,
    -7,   615,   615,   615,   615,   615,    -6,   615,   615,   615,
   615,    -6,    -1,   499,   320,   499,   320,   615,   337,    44,
   615,   615,   615,    -1,    -1,    -1,    93,    44,    91,    61,
   615,    -1,    44,    41,    41,    41,    41,    41,    41,    41,
    41,    41,    44,    44,    41,    41,    41,    41,    41,    41,
    41,    41,    41,    41,   611,    -1,   615,   381,   381,    44,
    41,    41,    41,    44,    44,    41,    44,   611,    -1,    -1,
   615,    -1,    -1,    -1,    -1,   615,    61,    -1,    -1,    -2,
    -1,    -1,    -1,    -1,    91,    93,    44,    46,    46,    -1,
    -1,    -1,    -1,    44,    41,    41,    41,    44,    44,    44,
    -1,    93,    44,    41,    41,    -1,   615,   491,   491,    44,
    44,    44,    -1,    -1,    -1,    -1,    61,    -1,    93,   615,
   615,    -1,    -1,    41,    41,   515,    -1,    44,    -1,    44,
    -1,    44,    -1 };
yytabelem yydef[]={

     1,    -2,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   484,   485,   389,     0,     0,   567,
   568,     0,     0,     0,     0,     0,     0,     0,     0,    -2,
    -2,    -2,     0,     0,     0,     0,     0,   606,   607,   608,
   609,   610,   611,   612,   613,    -2,    -2,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
    -2,    -2,    -2,     0,     0,     0,     0,     0,     0,     0,
     0,    36,     0,     0,     0,     0,    41,     0,     0,     0,
     0,     0,    49,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,    68,     0,     0,     0,     0,     0,     0,
     0,    77,     0,     0,     0,     0,     0,    93,    94,    95,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,   281,   283,     0,     0,     0,     0,    19,
   403,   404,   405,   406,   407,   408,   409,   410,   411,   287,
   288,   289,   290,   291,   292,     0,     0,     0,   390,     2,
     3,     4,     5,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     6,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     7,     8,     9,    10,    11,    12,    13,
     0,     0,     0,     0,     0,     0,     0,   198,     0,     0,
     0,     0,     0,     0,   391,   399,   400,    28,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   564,    -2,   484,   485,
     0,     0,     0,     0,     0,     0,   566,    -2,     0,    38,
     0,     0,    42,    43,     0,   463,   464,   465,   466,   467,
   468,     0,     0,    46,   429,   430,    47,    48,    50,    51,
    52,    53,    54,    55,    56,   100,   113,   128,     0,     0,
     0,     0,     0,    64,    65,    66,    67,     0,     0,     0,
     0,     0,     0,     0,    78,    79,    80,    81,    82,    83,
    84,    85,    86,    87,   412,   413,    88,   218,   219,   220,
   221,   222,   223,   224,   225,   226,   227,   228,   229,   230,
   231,   232,   233,   234,   235,   236,   237,    89,     0,     0,
    96,     0,    98,    99,   115,   127,   102,   103,     0,     0,
     0,     0,     0,     0,   112,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   590,   591,   592,     0,     0,
     0,     0,     0,   614,   615,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,   629,   630,
   631,     0,     0,     0,     0,     0,     0,     0,     0,   116,
   117,     0,     0,     0,     0,     0,     0,   126,   130,   131,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   158,     0,     0,     0,
     0,   163,     0,     0,     0,     0,     0,   284,   286,   392,
   393,   169,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   191,     0,     0,
     0,     0,     0,     0,   282,     0,     0,     0,     0,   307,
     0,     0,     0,     0,     0,     0,     0,   254,   255,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
   394,   395,   396,   397,   398,     0,     0,    20,    21,    22,
    23,    24,    25,    26,    27,    17,     0,   293,   296,     0,
     0,     0,     0,     0,     0,   294,   295,    -2,   491,    -2,
   495,    -2,   499,    -2,   503,    -2,   506,   581,     0,    -2,
    -2,    -2,    -2,    -2,    -2,   644,   645,   490,    -2,   494,
    -2,   498,    -2,   502,    -2,    -2,   508,     0,   488,    -2,
    -2,    -2,    -2,    -2,    -2,   562,   563,     0,   476,   480,
     0,   477,   481,     0,   487,   573,   574,   425,   426,   427,
   428,   388,   598,   599,   600,   601,   602,   603,   604,   605,
   199,     0,   202,   203,   204,   238,   239,   240,   241,   242,
   243,   244,   245,   246,   247,   205,     0,     0,     0,     0,
     0,    29,   248,   249,   250,   251,   252,   253,    30,    31,
    32,     0,     0,   571,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,   565,   647,    37,    39,     0,    44,     0,    45,   101,
   114,   129,    57,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,    90,    91,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   105,   469,   470,   106,   107,
   108,   109,   415,   414,   416,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,   646,     0,   648,     0,
   119,   120,   121,   122,   123,     0,     0,     0,   133,   134,
   135,   136,   137,   138,     0,   140,   141,   142,   143,     0,
   145,     0,     0,     0,   149,   150,   151,   152,     0,   154,
   155,   156,   157,   159,   160,   161,   162,   164,   165,   166,
   167,     0,   285,   170,   171,   172,   173,   174,   175,     0,
     0,     0,     0,     0,   183,   184,     0,   186,   187,   188,
   189,     0,   192,   193,   194,   195,   196,     0,   303,   308,
   310,     0,     0,     0,     0,     0,     0,     0,     0,   321,
     0,     0,     0,     0,     0,     0,     0,     0,   431,   432,
   433,   304,   341,   343,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   305,   373,     0,     0,     0,
     0,     0,     0,     0,   306,   384,     0,     0,     0,   211,
   212,   213,   214,   215,   216,     0,     0,   257,   258,   259,
   260,   434,   435,   436,   437,   438,   439,   440,   441,   442,
   443,   444,   445,   446,   447,   448,   449,   450,   451,   452,
   453,   454,   455,   456,   457,   458,   459,   261,     0,     0,
     0,     0,     0,   267,   268,     0,     0,   401,   402,   271,
     0,     0,     0,     0,     0,     0,   280,    14,    16,    18,
   297,   298,   299,   300,     0,   302,     0,     0,   569,   570,
     0,     0,     0,     0,     0,   200,   201,     0,     0,     0,
   209,   210,     0,     0,     0,     0,    -2,   510,   511,   584,
   512,   585,   513,   586,     0,     0,   515,   588,   516,   589,
   520,   593,   521,   594,   522,   595,   523,   596,     0,     0,
    76,   530,   616,   531,   617,     0,     0,    -2,   535,   620,
   536,   621,   537,   622,     0,     0,     0,     0,     0,     0,
     0,     0,   542,   627,   543,   628,     0,     0,   551,   633,
   552,   634,   553,   635,   554,   636,     0,     0,     0,   487,
   571,     0,    35,    60,     0,    62,     0,     0,     0,     0,
     0,     0,     0,     0,    92,     0,     0,     0,   577,   578,
   579,   580,   582,   110,   111,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,   124,   125,   132,
   139,   144,   146,   147,     0,     0,   168,   176,     0,     0,
   179,   180,   181,   182,   185,   190,   197,   309,   311,   313,
     0,     0,     0,     0,     0,   312,   314,     0,     0,     0,
     0,     0,   315,   316,   317,   318,   319,   320,   322,   323,
   326,   327,   336,   417,   418,   419,   420,   421,   337,   338,
   339,     0,   342,   344,   345,   346,   347,   348,   349,   350,
   351,   352,   353,   354,   355,   422,   423,   424,   356,   357,
   358,   359,   460,   461,   462,   360,     0,   361,     0,   366,
   367,     0,   369,   370,   371,     0,   374,   375,   376,   377,
     0,   379,     0,   381,   382,   383,   385,   386,   387,   217,
   256,   262,   263,   264,   265,   266,   269,   270,   272,   273,
   274,   275,   276,     0,     0,     0,    15,   301,   637,   555,
     0,     0,    58,     0,   478,   482,     0,   486,   206,     0,
     0,     0,    34,   475,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   569,   570,     0,     0,     0,
     0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,   583,     0,     0,   619,     0,     0,     0,     0,
   177,   178,   324,   328,   330,   332,   334,   325,   329,   331,
   333,   335,   340,   362,   363,   364,   365,   368,   372,     0,
   380,   277,   278,   279,   471,   472,   572,     0,     0,     0,
   207,   208,     0,   575,   514,   587,   524,   526,   525,    -2,
    -2,   533,     0,     0,   539,   624,   540,   625,   541,   626,
   547,   549,   548,    -2,   486,     0,     0,     0,     0,     0,
    70,    71,    72,     0,     0,    75,     0,     0,     0,     0,
     0,     0,     0,     0,     0,   378,     0,    59,     0,   479,
   483,     0,     0,     0,     0,   572,     0,     0,     0,    69,
     0,     0,     0,     0,   597,   618,   632,     0,     0,     0,
   473,   576,     0,   538,   623,     0,    40,    61,    63,     0,
     0,     0,   104,   118,   148,   153,     0,    33,   576,     0,
     0,     0,   474,    73,    74,     0,     0,     0,     0,     0,
     0,     0,    97 };
typedef struct { char *t_name; int t_val; } yytoktype;
#ifndef YYDEBUG
#	define YYDEBUG	1	/* allow debugging */
#endif

#if YYDEBUG

yytoktype yytoks[] =
{
	"ABS",	257,
	"ACOS",	258,
	"ASIN",	259,
	"ATAN",	260,
	"ATAN2",	261,
	"CEIL",	262,
	"COS",	263,
	"DEG",	264,
	"DX",	265,
	"DY",	266,
	"ERF",	267,
	"ERFC",	268,
	"EXP",	269,
	"FLOOR",	270,
	"HYPOT",	271,
	"INDEX",	272,
	"INT",	273,
	"INVN",	274,
	"INVT",	275,
	"IRAND",	276,
	"LGAMMA",	277,
	"LN",	278,
	"LOG",	279,
	"LOGISTIC",	280,
	"MAXP",	281,
	"MINP",	282,
	"MOD",	283,
	"NORM",	284,
	"NORMP",	285,
	"PI_XVGR",	286,
	"RAD",	287,
	"RAND",	288,
	"RNORM",	289,
	"SETNO",	290,
	"SIN",	291,
	"SQR",	292,
	"SQRT",	293,
	"TAN",	294,
	"INUM",	295,
	"VX1",	296,
	"VX2",	297,
	"VY1",	298,
	"VY2",	299,
	"WX1",	300,
	"WX2",	301,
	"WY1",	302,
	"WY2",	303,
	"DELAYP",	304,
	"DOUBLEBUFFER",	305,
	"DOWN",	306,
	"ABSOLUTE",	307,
	"ABORT",	308,
	"ACTIVATE",	309,
	"ACTIVE",	310,
	"ALT",	311,
	"ALTERNATE",	312,
	"ALTXAXIS",	313,
	"ALTYAXIS",	314,
	"ANGLE",	315,
	"ANNOTATE",	316,
	"APPEND",	317,
	"AREA",	318,
	"ARROW",	319,
	"AUTO",	320,
	"AUTOSCALE",	321,
	"AUTOTICKS",	322,
	"AVG",	323,
	"AXIS",	324,
	"AXES",	325,
	"BACKBUFFER",	326,
	"BACKGROUND",	327,
	"BAR",	328,
	"BATCH",	329,
	"BIN",	330,
	"BOTH",	331,
	"BOTTOM",	332,
	"BOX",	333,
	"CELLS",	334,
	"CENTER",	335,
	"CHAR",	336,
	"CHRSTR",	337,
	"CLEAR",	338,
	"CLICK",	339,
	"CMAP",	340,
	"COLOR",	341,
	"COMMENT",	342,
	"COPY",	343,
	"CYCLE",	344,
	"DECIMAL",	345,
	"DEF",	346,
	"DEFAULT",	347,
	"DELETE",	348,
	"DEVICE",	349,
	"DFT",	350,
	"DIFFERENCE",	351,
	"DISK",	352,
	"DRAW2",	353,
	"DXDX",	354,
	"DXP",	355,
	"DYDY",	356,
	"DYP",	357,
	"ECHO",	358,
	"EDIT",	359,
	"ELSE",	360,
	"END",	361,
	"ERRORBAR",	362,
	"EXIT",	363,
	"EXPONENTIAL",	364,
	"FALSEP",	365,
	"FFT",	366,
	"FILEP",	367,
	"FILL",	368,
	"FIND",	369,
	"FIXEDPOINT",	370,
	"FLUSH",	371,
	"FOCUS",	372,
	"FOLLOWS",	373,
	"FONTP",	374,
	"FOREGROUND",	375,
	"FORMAT",	376,
	"FRONTBUFFER",	377,
	"FRAMEP",	378,
	"GETP",	379,
	"GRAPH",	380,
	"GRAPHNO",	381,
	"GRAPHS",	382,
	"GRAPHTYPE",	383,
	"GRID",	384,
	"HARDCOPY",	385,
	"HBAR",	386,
	"HGAP",	387,
	"HIDDEN",	388,
	"HORIZONTAL",	389,
	"HPGLL",	390,
	"HPGLP",	391,
	"HISTO",	392,
	"IF",	393,
	"IGNORE",	394,
	"IHL",	395,
	"IN",	396,
	"INIT",	397,
	"INITGRAPHICS",	398,
	"INOUT",	399,
	"INTEGRATE",	400,
	"INTERP",	401,
	"INVDFT",	402,
	"INVFFT",	403,
	"JUST",	404,
	"KILL",	405,
	"LABEL",	406,
	"LAYOUT",	407,
	"LEAVE",	408,
	"LEAVEGRAPHICS",	409,
	"LEFT",	410,
	"LEGEND",	411,
	"LENGTH",	412,
	"LEVEL",	413,
	"LEVELS",	414,
	"LINE",	415,
	"LINESTYLE",	416,
	"LINETO",	417,
	"LINEWIDTH",	418,
	"LINK",	419,
	"LOAD",	420,
	"LOCATOR",	421,
	"LOCTYPE",	422,
	"LOGX",	423,
	"LOGY",	424,
	"LOGXY",	425,
	"MAJOR",	426,
	"MIFL",	427,
	"MIFP",	428,
	"MINOR",	429,
	"MISSINGP",	430,
	"MOVE",	431,
	"MOVE2",	432,
	"MOVETO",	433,
	"NEGATE",	434,
	"NO",	435,
	"NONE",	436,
	"NORMAL",	437,
	"NXY",	438,
	"OFF",	439,
	"OFFSETX",	440,
	"OFFSETY",	441,
	"ON",	442,
	"OP",	443,
	"ORIENT",	444,
	"OUT",	445,
	"PAGE",	446,
	"PARA",	447,
	"PARALLEL",	448,
	"PARAMETERS",	449,
	"PARAMS",	450,
	"PATTERN",	451,
	"PERIMETER",	452,
	"PERP",	453,
	"PERPENDICULAR",	454,
	"PIE",	455,
	"PIPE",	456,
	"PLACE",	457,
	"POINT",	458,
	"POLAR",	459,
	"POWER",	460,
	"PREC",	461,
	"PREPEND",	462,
	"PRINT",	463,
	"PS",	464,
	"PSCOLORP",	465,
	"PSMONOP",	466,
	"PSCOLORL",	467,
	"PSMONOL",	468,
	"PUSH",	469,
	"POP",	470,
	"PUTP",	471,
	"READ",	472,
	"REDRAW",	473,
	"REGRESS",	474,
	"REGNUM",	475,
	"REGIONS",	476,
	"RENDER",	477,
	"REVERSE",	478,
	"RIGHT",	479,
	"RISER",	480,
	"ROT",	481,
	"RUNAVG",	482,
	"RUNMED",	483,
	"RUNSTD",	484,
	"RUNMIN",	485,
	"RUNMAX",	486,
	"SAMPLE",	487,
	"SCALE",	488,
	"SCIENTIFIC",	489,
	"SET",	490,
	"SETNUM",	491,
	"SETS",	492,
	"SIGN",	493,
	"SIZE",	494,
	"SKIP",	495,
	"SLEEP",	496,
	"SLICE",	497,
	"SOURCE",	498,
	"SPEC",	499,
	"SPECIFIED",	500,
	"SPECTRUM",	501,
	"STACK",	502,
	"STACKEDBAR",	503,
	"STACKEDHBAR",	504,
	"STACKEDLINE",	505,
	"STAGGER",	506,
	"START",	507,
	"STARTTYPE",	508,
	"STATUS",	509,
	"STOP",	510,
	"STRING",	511,
	"SUBTITLE",	512,
	"SWAPBUFFER",	513,
	"SYMBOL",	514,
	"TICK",	515,
	"TICKLABEL",	516,
	"TICKMARKS",	517,
	"TITLE",	518,
	"TO",	519,
	"TOP",	520,
	"TRUEP",	521,
	"TYPE",	522,
	"UP",	523,
	"VELOCITY",	524,
	"VERTICAL",	525,
	"VGAP",	526,
	"VIEW",	527,
	"WITH",	528,
	"WORLD",	529,
	"WRITE",	530,
	"X1",	531,
	"X2",	532,
	"X3",	533,
	"X4",	534,
	"X5",	535,
	"XAXES",	536,
	"XAXIS",	537,
	"XCOR",	538,
	"XMAX",	539,
	"XMIN",	540,
	"XY",	541,
	"XYARC",	542,
	"XYBOX",	543,
	"XYFIXED",	544,
	"XYHILO",	545,
	"XYRT",	546,
	"XYSEG",	547,
	"XYSTRING",	548,
	"XYDX",	549,
	"XYDY",	550,
	"XYDXDX",	551,
	"XYDYDY",	552,
	"XYDXDY",	553,
	"XYX2Y2",	554,
	"XYXX",	555,
	"XYYY",	556,
	"XYZ",	557,
	"XYZW",	558,
	"XYUV",	559,
	"Y1",	560,
	"Y2",	561,
	"Y3",	562,
	"Y4",	563,
	"Y5",	564,
	"YAXES",	565,
	"YAXIS",	566,
	"YES",	567,
	"YMAX",	568,
	"YMIN",	569,
	"ZEROXAXIS",	570,
	"ZEROYAXIS",	571,
	"ABOVE",	572,
	"BELOW",	573,
	"POLYI",	574,
	"POLYO",	575,
	"GENERAL",	576,
	"DDMMYY",	577,
	"MMDDYY",	578,
	"MMYY",	579,
	"MMDD",	580,
	"MONTHDAY",	581,
	"DAYMONTH",	582,
	"MONTHS",	583,
	"MONTHL",	584,
	"DAYOFWEEKS",	585,
	"DAYOFWEEKL",	586,
	"DAYOFYEAR",	587,
	"HMS",	588,
	"MMDDHMS",	589,
	"MMDDYYHMS",	590,
	"DEGREESLON",	591,
	"DEGREESMMLON",	592,
	"DEGREESMMSSLON",	593,
	"MMSSLON",	594,
	"DEGREESLAT",	595,
	"DEGREESMMLAT",	596,
	"DEGREESMMSSLAT",	597,
	"MMSSLAT",	598,
	"DOT",	599,
	"STAR",	600,
	"PLUS",	601,
	"CROSS",	602,
	"CIRCLE",	603,
	"SQUARE",	604,
	"DIAMOND",	605,
	"TRIANGLE1",	606,
	"TRIANGLE2",	607,
	"TRIANGLE3",	608,
	"TRIANGLE4",	609,
	"SPLINE",	610,
	"SVAR",	611,
	"VAR",	612,
	"X",	613,
	"Y",	614,
	"NUMBER",	615,
	"FITPARM",	616,
	"=",	61,
	"OR",	617,
	"AND",	618,
	"GT",	619,
	"LT",	620,
	"LE",	621,
	"GE",	622,
	"EQ",	623,
	"NE",	624,
	"+",	43,
	"-",	45,
	"*",	42,
	"/",	47,
	"%",	37,
	"^",	94,
	"UMINUS",	625,
	"NOT",	626,
	"-unknown-",	-1	/* ends search */
};

char * yyreds[] =
{
	"-no such reduction-",
      "list : /* empty */",
      "list : asgn '\n'",
      "list : vasgn '\n'",
      "list : rasgn '\n'",
      "list : expr '\n'",
      "list : vexpr '\n'",
      "list : parmset '\n'",
      "list : regionset '\n'",
      "list : setaxis '\n'",
      "list : setvelocity '\n'",
      "list : set_setprop '\n'",
      "list : setprint '\n'",
      "list : error '\n'",
      "setprint : PRINT printer CHRSTR",
      "setprint : PRINT TO printer CHRSTR",
      "setprint : PRINT TO printer",
      "setprint : DEVICE NUMBER",
      "setprint : HARDCOPY DEVICE NUMBER",
      "setprint : HARDCOPY",
      "printer : PSMONOP",
      "printer : PSMONOL",
      "printer : MIFP",
      "printer : MIFL",
      "printer : HPGLP",
      "printer : HPGLL",
      "printer : HARDCOPY",
      "printer : FILEP",
      "regionset : REGNUM onoff",
      "regionset : REGNUM TYPE regiontype",
      "regionset : REGNUM COLOR NUMBER",
      "regionset : REGNUM LINESTYLE NUMBER",
      "regionset : REGNUM LINEWIDTH NUMBER",
      "regionset : REGNUM LINE expr ',' expr ',' expr ',' expr",
      "regionset : REGNUM XY expr ',' expr",
      "regionset : LINK REGNUM TO GRAPHNO",
      "parmset : REDRAW",
      "parmset : AUTO REDRAW onoff",
      "parmset : ECHO CHRSTR",
      "parmset : BACKGROUND COLOR NUMBER",
      "parmset : CMAP NUMBER ',' NUMBER ',' NUMBER ',' NUMBER",
      "parmset : EXIT",
      "parmset : PAGE direction",
      "parmset : PAGE NUMBER",
      "parmset : PAGE INOUT NUMBER",
      "parmset : LINK PAGE onoff",
      "parmset : DOUBLEBUFFER torf",
      "parmset : FRONTBUFFER torf",
      "parmset : BACKBUFFER torf",
      "parmset : SWAPBUFFER",
      "parmset : SLEEP NUMBER",
      "parmset : DELAYP NUMBER",
      "parmset : ABORT torf",
      "parmset : GETP CHRSTR",
      "parmset : PUTP CHRSTR",
      "parmset : WITH GRAPHNO",
      "parmset : WITH SETNUM",
      "parmset : ACTIVATE SETNUM NUMBER",
      "parmset : SETNUM POINT expr ',' expr",
      "parmset : GRAPHNO '.' SETNUM POINT expr ',' expr",
      "parmset : COPY SETNUM TO SETNUM",
      "parmset : COPY GRAPHNO '.' SETNUM TO GRAPHNO '.' SETNUM",
      "parmset : MOVE SETNUM TO SETNUM",
      "parmset : MOVE GRAPHNO '.' SETNUM TO GRAPHNO '.' SETNUM",
      "parmset : KILL SETNUM",
      "parmset : KILL SETS",
      "parmset : KILL GRAPHNO",
      "parmset : KILL GRAPHS",
      "parmset : FLUSH",
      "parmset : LOAD VAR NUMBER ',' expr ',' expr",
      "parmset : REGRESS '(' SETNUM ',' NUMBER ')'",
      "parmset : runtype '(' SETNUM ',' NUMBER ')'",
      "parmset : ffttype '(' SETNUM ',' NUMBER ')'",
      "parmset : SPLINE '(' SETNUM ',' expr ',' expr ',' NUMBER ')'",
      "parmset : HISTO '(' SETNUM ',' expr ',' expr ',' NUMBER ')'",
      "parmset : DIFFERENCE '(' SETNUM ',' NUMBER ')'",
      "parmset : INT '(' SETNUM ')'",
      "parmset : AUTOSCALE",
      "parmset : AUTOSCALE XAXES",
      "parmset : AUTOSCALE YAXES",
      "parmset : AUTOSCALE SETNUM",
      "parmset : LOCATOR onoff",
      "parmset : FOCUS GRAPHNO",
      "parmset : FOCUS onoff",
      "parmset : FOCUS SET",
      "parmset : FOCUS FOLLOWS",
      "parmset : FOCUS CLICK",
      "parmset : SOURCE sourcetype",
      "parmset : TYPE xytype",
      "parmset : READ CHRSTR",
      "parmset : READ BATCH CHRSTR",
      "parmset : READ xytype CHRSTR",
      "parmset : READ xytype sourcetype CHRSTR",
      "parmset : PUSH",
      "parmset : POP",
      "parmset : CYCLE",
      "parmset : STACK NUMBER",
      "parmset : STACK WORLD expr ',' expr ',' expr ',' expr TICK expr ',' expr ',' expr ',' expr",
      "parmset : CLEAR STACK",
      "parmset : CLEAR BOX",
      "parmset : WITH BOX",
      "parmset : WITH BOX NUMBER",
      "parmset : BOX onoff",
      "parmset : BOX GRAPHNO",
      "parmset : BOX expr ',' expr ',' expr ',' expr",
      "parmset : BOX LOCTYPE worldview",
      "parmset : BOX LINESTYLE NUMBER",
      "parmset : BOX LINEWIDTH NUMBER",
      "parmset : BOX COLOR NUMBER",
      "parmset : BOX FILL filltype",
      "parmset : BOX FILL COLOR NUMBER",
      "parmset : BOX FILL PATTERN NUMBER",
      "parmset : BOX DEF",
      "parmset : WITH LINE",
      "parmset : WITH LINE NUMBER",
      "parmset : CLEAR LINE",
      "parmset : LINE onoff",
      "parmset : LINE GRAPHNO",
      "parmset : LINE expr ',' expr ',' expr ',' expr",
      "parmset : LINE LOCTYPE worldview",
      "parmset : LINE LINEWIDTH NUMBER",
      "parmset : LINE LINESTYLE NUMBER",
      "parmset : LINE COLOR NUMBER",
      "parmset : LINE ARROW NUMBER",
      "parmset : LINE ARROW SIZE NUMBER",
      "parmset : LINE ARROW TYPE NUMBER",
      "parmset : LINE DEF",
      "parmset : CLEAR STRING",
      "parmset : WITH STRING",
      "parmset : WITH STRING NUMBER",
      "parmset : STRING onoff",
      "parmset : STRING GRAPHNO",
      "parmset : STRING expr ',' expr",
      "parmset : STRING LOCTYPE worldview",
      "parmset : STRING LINEWIDTH NUMBER",
      "parmset : STRING COLOR NUMBER",
      "parmset : STRING ROT NUMBER",
      "parmset : STRING FONTP NUMBER",
      "parmset : STRING JUST NUMBER",
      "parmset : STRING CHAR SIZE NUMBER",
      "parmset : STRING DEF CHRSTR",
      "parmset : DEFAULT LINESTYLE NUMBER",
      "parmset : DEFAULT LINEWIDTH NUMBER",
      "parmset : DEFAULT COLOR NUMBER",
      "parmset : DEFAULT CHAR SIZE NUMBER",
      "parmset : DEFAULT FONTP NUMBER",
      "parmset : DEFAULT FONTP SOURCE NUMBER",
      "parmset : DEFAULT SYMBOL SIZE NUMBER",
      "parmset : WORLD expr ',' expr ',' expr ',' expr",
      "parmset : WORLD XMIN expr",
      "parmset : WORLD XMAX expr",
      "parmset : WORLD YMIN expr",
      "parmset : WORLD YMAX expr",
      "parmset : VIEW expr ',' expr ',' expr ',' expr",
      "parmset : VIEW XMIN NUMBER",
      "parmset : VIEW XMAX NUMBER",
      "parmset : VIEW YMIN NUMBER",
      "parmset : VIEW YMAX NUMBER",
      "parmset : TITLE CHRSTR",
      "parmset : TITLE FONTP NUMBER",
      "parmset : TITLE SIZE NUMBER",
      "parmset : TITLE COLOR NUMBER",
      "parmset : TITLE LINEWIDTH NUMBER",
      "parmset : SUBTITLE CHRSTR",
      "parmset : SUBTITLE FONTP NUMBER",
      "parmset : SUBTITLE SIZE NUMBER",
      "parmset : SUBTITLE COLOR NUMBER",
      "parmset : SUBTITLE LINEWIDTH NUMBER",
      "parmset : GRAPHS MAXP SETS NUMBER",
      "parmset : LEGEND onoff",
      "parmset : LEGEND LOCTYPE worldview",
      "parmset : LEGEND LAYOUT NUMBER",
      "parmset : LEGEND VGAP NUMBER",
      "parmset : LEGEND HGAP NUMBER",
      "parmset : LEGEND LENGTH NUMBER",
      "parmset : LEGEND BOX onoff",
      "parmset : LEGEND BOX FILL onoff",
      "parmset : LEGEND BOX FILL WITH colpat",
      "parmset : LEGEND BOX FILL colpat NUMBER",
      "parmset : LEGEND BOX COLOR NUMBER",
      "parmset : LEGEND BOX LINESTYLE NUMBER",
      "parmset : LEGEND BOX LINEWIDTH NUMBER",
      "parmset : LEGEND expr ',' expr",
      "parmset : LEGEND X1 expr",
      "parmset : LEGEND Y1 expr",
      "parmset : LEGEND CHAR SIZE NUMBER",
      "parmset : LEGEND FONTP NUMBER",
      "parmset : LEGEND LINESTYLE NUMBER",
      "parmset : LEGEND LINEWIDTH NUMBER",
      "parmset : LEGEND COLOR NUMBER",
      "parmset : LEGEND STRING NUMBER CHRSTR",
      "parmset : FRAMEP onoff",
      "parmset : FRAMEP TYPE NUMBER",
      "parmset : FRAMEP LINESTYLE NUMBER",
      "parmset : FRAMEP LINEWIDTH NUMBER",
      "parmset : FRAMEP COLOR NUMBER",
      "parmset : FRAMEP FILL onoff",
      "parmset : FRAMEP BACKGROUND COLOR NUMBER",
      "parmset : GRAPHNO onoff",
      "parmset : GRAPHNO LABEL onoff",
      "parmset : GRAPHNO AUTOSCALE TYPE AUTO",
      "parmset : GRAPHNO AUTOSCALE TYPE SPEC",
      "parmset : GRAPHNO AUTOSCALE torf",
      "parmset : GRAPHNO HIDDEN torf",
      "parmset : GRAPHNO TYPE graphtype",
      "parmset : GRAPHNO FIXEDPOINT onoff",
      "parmset : GRAPHNO FIXEDPOINT FORMAT formatchoice formatchoice",
      "parmset : GRAPHNO FIXEDPOINT PREC NUMBER ',' NUMBER",
      "parmset : GRAPHNO FIXEDPOINT XY expr ',' expr",
      "parmset : GRAPHNO FIXEDPOINT TYPE NUMBER",
      "parmset : GRAPHNO MAXP SETS NUMBER",
      "setvelocity : VELOCITY SCALE NUMBER",
      "setvelocity : VELOCITY LEGEND onoff",
      "setvelocity : VELOCITY LINEWIDTH NUMBER",
      "setvelocity : VELOCITY LINESTYLE NUMBER",
      "setvelocity : VELOCITY COLOR NUMBER",
      "setvelocity : VELOCITY LOCTYPE worldview",
      "setvelocity : VELOCITY ARROW TYPE NUMBER",
      "xytype : XY",
      "xytype : XYARC",
      "xytype : XYBOX",
      "xytype : XYHILO",
      "xytype : XYRT",
      "xytype : XYSEG",
      "xytype : XYSTRING",
      "xytype : XYDX",
      "xytype : XYDY",
      "xytype : XYDXDX",
      "xytype : XYDYDY",
      "xytype : XYDXDY",
      "xytype : XYX2Y2",
      "xytype : XYXX",
      "xytype : XYYY",
      "xytype : XYZ",
      "xytype : XYZW",
      "xytype : XYUV",
      "xytype : NXY",
      "xytype : BIN",
      "graphtype : XY",
      "graphtype : LOGX",
      "graphtype : LOGY",
      "graphtype : LOGXY",
      "graphtype : BAR",
      "graphtype : HBAR",
      "graphtype : STACKEDBAR",
      "graphtype : STACKEDHBAR",
      "graphtype : POLAR",
      "graphtype : XYFIXED",
      "regiontype : ABOVE",
      "regiontype : BELOW",
      "regiontype : LEFT",
      "regiontype : RIGHT",
      "regiontype : POLYI",
      "regiontype : POLYO",
      "set_setprop : selectsets setprop",
      "setprop : onoff",
      "setprop : onoff IGNORE",
      "setprop : TYPE xytype",
      "setprop : MISSINGP expr",
      "setprop : PREC NUMBER",
      "setprop : FORMAT formatchoice",
      "setprop : SYMBOL NUMBER",
      "setprop : SYMBOL FILL NUMBER",
      "setprop : SYMBOL CENTER torf",
      "setprop : SYMBOL SIZE NUMBER",
      "setprop : SYMBOL CHAR NUMBER",
      "setprop : SYMBOL SKIP NUMBER",
      "setprop : prop NUMBER",
      "setprop : FILL NUMBER",
      "setprop : FILL WITH colpat",
      "setprop : FILL colpat NUMBER",
      "setprop : SKIP NUMBER",
      "setprop : ERRORBAR LENGTH NUMBER",
      "setprop : ERRORBAR TYPE opchoice",
      "setprop : ERRORBAR LINEWIDTH NUMBER",
      "setprop : ERRORBAR LINESTYLE NUMBER",
      "setprop : ERRORBAR RISER onoff",
      "setprop : ERRORBAR RISER LINEWIDTH NUMBER",
      "setprop : ERRORBAR RISER LINESTYLE NUMBER",
      "setprop : XYZ expr ',' expr",
      "setprop : COMMENT CHRSTR",
      "setaxis : axis",
      "setaxis : axis axisfeature",
      "setaxis : allaxes",
      "setaxis : GRAPHS axis",
      "setaxis : GRAPHS axis axisfeature",
      "setaxis : GRAPHS allaxes",
      "axis : XAXIS",
      "axis : YAXIS",
      "axis : ALTXAXIS",
      "axis : ALTYAXIS",
      "axis : ZEROXAXIS",
      "axis : ZEROYAXIS",
      "allaxes : AXES axesprops",
      "allaxes : XAXES axesprops",
      "allaxes : YAXES axesprops",
      "axesprops : onoff",
      "axesprops : COLOR NUMBER",
      "axesprops : LINEWIDTH NUMBER",
      "axesprops : LINESTYLE NUMBER",
      "axesprops : FONTP NUMBER",
      "axesprops : CHAR SIZE NUMBER",
      "axesprops : GRID onoff",
      "axisfeature : TICK tickdesc",
      "axisfeature : TICKLABEL ticklabeldesc",
      "axisfeature : LABEL axislabeldesc",
      "axisfeature : BAR axisbardesc",
      "axisfeature : onoff",
      "tickdesc : tickattr",
      "tickdesc : tickdesc tickattr",
      "tickattr : onoff",
      "tickattr : MAJOR onoff",
      "tickattr : MINOR onoff",
      "tickattr : MAJOR expr",
      "tickattr : MINOR expr",
      "tickattr : OFFSETX expr",
      "tickattr : OFFSETY expr",
      "tickattr : ALT onoff",
      "tickattr : MINP expr",
      "tickattr : MAXP expr",
      "tickattr : DEFAULT NUMBER",
      "tickattr : inoutchoice",
      "tickattr : LOG onoff",
      "tickattr : SIZE NUMBER",
      "tickattr : MAJOR SIZE NUMBER",
      "tickattr : MINOR SIZE NUMBER",
      "tickattr : COLOR NUMBER",
      "tickattr : LINEWIDTH NUMBER",
      "tickattr : MAJOR COLOR NUMBER",
      "tickattr : MINOR COLOR NUMBER",
      "tickattr : MAJOR LINEWIDTH NUMBER",
      "tickattr : MINOR LINEWIDTH NUMBER",
      "tickattr : MAJOR LINESTYLE NUMBER",
      "tickattr : MINOR LINESTYLE NUMBER",
      "tickattr : MAJOR GRID onoff",
      "tickattr : MINOR GRID onoff",
      "tickattr : OP opchoice",
      "tickattr : TYPE AUTO",
      "tickattr : TYPE SPEC",
      "tickattr : SPEC NUMBER",
      "tickattr : NUMBER ',' expr",
      "ticklabeldesc : ticklabelattr",
      "ticklabeldesc : ticklabeldesc ticklabelattr",
      "ticklabelattr : onoff",
      "ticklabelattr : TYPE AUTO",
      "ticklabelattr : TYPE SPEC",
      "ticklabelattr : PREC NUMBER",
      "ticklabelattr : FORMAT formatchoice",
      "ticklabelattr : FORMAT NUMBER",
      "ticklabelattr : APPEND CHRSTR",
      "ticklabelattr : PREPEND CHRSTR",
      "ticklabelattr : LAYOUT HORIZONTAL",
      "ticklabelattr : LAYOUT VERTICAL",
      "ticklabelattr : LAYOUT SPEC",
      "ticklabelattr : ANGLE NUMBER",
      "ticklabelattr : JUST justchoice",
      "ticklabelattr : SKIP NUMBER",
      "ticklabelattr : STAGGER NUMBER",
      "ticklabelattr : OP opchoice",
      "ticklabelattr : SIGN signchoice",
      "ticklabelattr : START expr",
      "ticklabelattr : STOP expr",
      "ticklabelattr : START TYPE SPEC",
      "ticklabelattr : START TYPE AUTO",
      "ticklabelattr : STOP TYPE SPEC",
      "ticklabelattr : STOP TYPE AUTO",
      "ticklabelattr : VGAP NUMBER",
      "ticklabelattr : HGAP NUMBER",
      "ticklabelattr : CHAR SIZE NUMBER",
      "ticklabelattr : FONTP NUMBER",
      "ticklabelattr : COLOR NUMBER",
      "ticklabelattr : LINEWIDTH NUMBER",
      "ticklabelattr : NUMBER ',' CHRSTR",
      "axislabeldesc : CHRSTR",
      "axislabeldesc : LAYOUT PERP",
      "axislabeldesc : LAYOUT PARA",
      "axislabeldesc : PLACE AUTO",
      "axislabeldesc : PLACE SPEC",
      "axislabeldesc : PLACE NUMBER ',' NUMBER",
      "axislabeldesc : JUST justchoice",
      "axislabeldesc : CHAR SIZE NUMBER",
      "axislabeldesc : FONTP NUMBER",
      "axislabeldesc : COLOR NUMBER",
      "axislabeldesc : LINEWIDTH NUMBER",
      "axisbardesc : onoff",
      "axisbardesc : COLOR NUMBER",
      "axisbardesc : LINESTYLE NUMBER",
      "axisbardesc : LINEWIDTH NUMBER",
      "selectsets : GRAPHNO '.' SETNUM",
      "selectsets : SETNUM",
      "selectsets : SETS",
      "selectsets : GRAPHNO SETS",
      "selectsets : GRAPHS SETS",
      "selectsets : GRAPHS SETNUM",
      "prop : LINESTYLE",
      "prop : LINEWIDTH",
      "prop : FONTP",
      "prop : COLOR",
      "prop : SIZE",
      "onoff : ON",
      "onoff : OFF",
      "colpat : COLOR",
      "colpat : PATTERN",
      "runtype : RUNAVG",
      "runtype : RUNSTD",
      "runtype : RUNMED",
      "runtype : RUNMAX",
      "runtype : RUNMIN",
      "ffttype : DFT",
      "ffttype : FFT",
      "ffttype : INVDFT",
      "ffttype : INVFFT",
      "sourcetype : DISK",
      "sourcetype : PIPE",
      "filltype : PATTERN",
      "filltype : COLOR",
      "filltype : NONE",
      "opchoice : TOP",
      "opchoice : BOTTOM",
      "opchoice : LEFT",
      "opchoice : RIGHT",
      "opchoice : BOTH",
      "justchoice : RIGHT",
      "justchoice : LEFT",
      "justchoice : CENTER",
      "extremetype : XMIN",
      "extremetype : XMAX",
      "extremetype : YMIN",
      "extremetype : YMAX",
      "torf : TRUEP",
      "torf : FALSEP",
      "inoutchoice : IN",
      "inoutchoice : OUT",
      "inoutchoice : BOTH",
      "formatchoice : DECIMAL",
      "formatchoice : EXPONENTIAL",
      "formatchoice : POWER",
      "formatchoice : GENERAL",
      "formatchoice : DDMMYY",
      "formatchoice : MMDDYY",
      "formatchoice : MMYY",
      "formatchoice : MMDD",
      "formatchoice : MONTHDAY",
      "formatchoice : DAYMONTH",
      "formatchoice : MONTHS",
      "formatchoice : MONTHL",
      "formatchoice : DAYOFWEEKS",
      "formatchoice : DAYOFWEEKL",
      "formatchoice : DAYOFYEAR",
      "formatchoice : HMS",
      "formatchoice : MMDDHMS",
      "formatchoice : MMDDYYHMS",
      "formatchoice : DEGREESLON",
      "formatchoice : DEGREESMMLON",
      "formatchoice : DEGREESMMSSLON",
      "formatchoice : MMSSLON",
      "formatchoice : DEGREESLAT",
      "formatchoice : DEGREESMMLAT",
      "formatchoice : DEGREESMMSSLAT",
      "formatchoice : MMSSLAT",
      "signchoice : NORMAL",
      "signchoice : ABSOLUTE",
      "signchoice : NEGATE",
      "direction : UP",
      "direction : DOWN",
      "direction : RIGHT",
      "direction : LEFT",
      "direction : IN",
      "direction : OUT",
      "worldview : WORLD",
      "worldview : VIEW",
      "asgn : VAR '[' expr ']' '=' expr",
      "asgn : SVAR '[' expr ']' '=' expr",
      "asgn : SETNUM '.' SVAR '[' expr ']' '=' expr",
      "asgn : GRAPHNO '.' SETNUM '.' SVAR '[' expr ']' '=' expr",
      "rasgn : REGNUM '.' SVAR '=' expr",
      "vasgn : VAR '=' vexpr",
      "vasgn : SVAR '=' vexpr",
      "vasgn : SETNUM '.' SVAR '=' vexpr",
      "vasgn : GRAPHNO '.' SETNUM '.' SVAR '=' vexpr",
      "vasgn : VAR '=' expr",
      "vasgn : SVAR '=' expr",
      "vasgn : SETNUM '.' SVAR '=' expr",
      "vasgn : GRAPHNO '.' SETNUM '.' SVAR '=' expr",
      "vexpr : VAR",
      "vexpr : SVAR",
      "vexpr : GRAPHNO '.' SETNUM '.' SVAR",
      "vexpr : SETNUM '.' SVAR",
      "vexpr : expr",
      "vexpr : expr '+' expr",
      "vexpr : vexpr '+' vexpr",
      "vexpr : expr '+' vexpr",
      "vexpr : vexpr '+' expr",
      "vexpr : expr '-' expr",
      "vexpr : vexpr '-' vexpr",
      "vexpr : expr '-' vexpr",
      "vexpr : vexpr '-' expr",
      "vexpr : expr '*' expr",
      "vexpr : vexpr '*' vexpr",
      "vexpr : expr '*' vexpr",
      "vexpr : vexpr '*' expr",
      "vexpr : expr '/' expr",
      "vexpr : vexpr '/' vexpr",
      "vexpr : expr '/' vexpr",
      "vexpr : vexpr '/' expr",
      "vexpr : expr '^' expr",
      "vexpr : expr '^' vexpr",
      "vexpr : vexpr '^' expr",
      "vexpr : vexpr '^' vexpr",
      "vexpr : ABS '(' expr ')'",
      "vexpr : ABS '(' vexpr ')'",
      "vexpr : ACOS '(' vexpr ')'",
      "vexpr : ASIN '(' vexpr ')'",
      "vexpr : ATAN '(' vexpr ')'",
      "vexpr : ATAN2 '(' vexpr ',' vexpr ')'",
      "vexpr : CEIL '(' vexpr ')'",
      "vexpr : COS '(' vexpr ')'",
      "vexpr : DEG",
      "vexpr : DX",
      "vexpr : DY",
      "vexpr : ERF '(' vexpr ')'",
      "vexpr : ERFC '(' vexpr ')'",
      "vexpr : EXP '(' vexpr ')'",
      "vexpr : FLOOR '(' vexpr ')'",
      "vexpr : HYPOT '(' vexpr ',' vexpr ')'",
      "vexpr : HYPOT '(' expr ',' vexpr ')'",
      "vexpr : HYPOT '(' vexpr ',' expr ')'",
      "vexpr : HYPOT '(' expr ',' expr ')'",
      "vexpr : INDEX",
      "vexpr : SETNO",
      "vexpr : INT '(' vexpr ')'",
      "vexpr : INVN '(' vexpr ')'",
      "vexpr : INVT '(' expr ',' NUMBER ')'",
      "vexpr : INVT '(' vexpr ',' NUMBER ')'",
      "vexpr : IRAND '(' NUMBER ')'",
      "vexpr : LGAMMA '(' vexpr ')'",
      "vexpr : LN '(' vexpr ')'",
      "vexpr : LOG '(' vexpr ')'",
      "vexpr : LOGISTIC '(' vexpr ',' expr ',' expr ')'",
      "vexpr : MAXP '(' vexpr ',' vexpr ')'",
      "vexpr : MINP '(' vexpr ',' vexpr ')'",
      "vexpr : MOD '(' vexpr ',' vexpr ')'",
      "vexpr : NORM '(' vexpr ')'",
      "vexpr : NORMP '(' vexpr ')'",
      "vexpr : PI_XVGR",
      "vexpr : RAD",
      "vexpr : RAND",
      "vexpr : RNORM '(' vexpr ',' vexpr ')'",
      "vexpr : RNORM '(' expr ',' vexpr ')'",
      "vexpr : RNORM '(' vexpr ',' expr ')'",
      "vexpr : RNORM '(' expr ',' expr ')'",
      "vexpr : SIN '(' vexpr ')'",
      "vexpr : SQR '(' vexpr ')'",
      "vexpr : SQRT '(' vexpr ')'",
      "vexpr : TAN '(' vexpr ')'",
      "vexpr : vexpr '?' vexpr ':' vexpr",
      "vexpr : vexpr GT vexpr",
      "vexpr : vexpr LT vexpr",
      "vexpr : vexpr LE vexpr",
      "vexpr : vexpr GE vexpr",
      "vexpr : vexpr EQ vexpr",
      "vexpr : vexpr NE vexpr",
      "vexpr : vexpr AND vexpr",
      "vexpr : vexpr OR vexpr",
      "vexpr : NOT vexpr",
      "vexpr : '(' vexpr ')'",
      "vexpr : '-' vexpr",
      "expr : NUMBER",
      "expr : FITPARM",
      "expr : VAR '[' expr ']'",
      "expr : SVAR '[' expr ']'",
      "expr : REGNUM '.' SVAR",
      "expr : SETNUM '.' SVAR '[' expr ']'",
      "expr : SETNUM '.' extremetype",
      "expr : SETNUM '.' LENGTH",
      "expr : AVG '(' SETNUM ',' SVAR ')'",
      "expr : GRAPHNO '.' SETNUM '.' SVAR '[' expr ']'",
      "expr : expr '+' expr",
      "expr : expr '-' expr",
      "expr : expr '*' expr",
      "expr : expr '/' expr",
      "expr : expr '%' expr",
      "expr : expr '^' expr",
      "expr : ABS '(' expr ')'",
      "expr : ACOS '(' expr ')'",
      "expr : ASIN '(' expr ')'",
      "expr : ATAN '(' expr ')'",
      "expr : ATAN2 '(' expr ',' expr ')'",
      "expr : CEIL '(' expr ')'",
      "expr : COS '(' expr ')'",
      "expr : DEG",
      "expr : DX",
      "expr : DY",
      "expr : ERF '(' expr ')'",
      "expr : ERFC '(' expr ')'",
      "expr : EXP '(' expr ')'",
      "expr : FLOOR '(' expr ')'",
      "expr : HYPOT '(' expr ',' expr ')'",
      "expr : GRAPHNO '.' VX1",
      "expr : GRAPHNO '.' VX2",
      "expr : GRAPHNO '.' VY1",
      "expr : GRAPHNO '.' VY2",
      "expr : GRAPHNO '.' WX1",
      "expr : GRAPHNO '.' WX2",
      "expr : GRAPHNO '.' WY1",
      "expr : GRAPHNO '.' WY2",
      "expr : VX1",
      "expr : VX2",
      "expr : VY1",
      "expr : VY2",
      "expr : WX1",
      "expr : WX2",
      "expr : WY1",
      "expr : WY2",
      "expr : INDEX",
      "expr : SETNO",
      "expr : INT '(' expr ')'",
      "expr : INVN '(' expr ')'",
      "expr : INVT '(' expr ',' NUMBER ')'",
      "expr : IRAND '(' NUMBER ')'",
      "expr : LGAMMA '(' expr ')'",
      "expr : LN '(' expr ')'",
      "expr : LOG '(' expr ')'",
      "expr : LOGISTIC '(' expr ',' expr ',' expr ')'",
      "expr : MAXP '(' expr ',' expr ')'",
      "expr : MINP '(' expr ',' expr ')'",
      "expr : MOD '(' expr ',' expr ')'",
      "expr : NORM '(' expr ')'",
      "expr : NORMP '(' expr ')'",
      "expr : PI_XVGR",
      "expr : RAD",
      "expr : RAND",
      "expr : RNORM '(' expr ',' expr ')'",
      "expr : SIN '(' expr ')'",
      "expr : SQR '(' expr ')'",
      "expr : SQRT '(' expr ')'",
      "expr : TAN '(' expr ')'",
      "expr : expr '?' expr ':' expr",
      "expr : expr GT expr",
      "expr : expr LT expr",
      "expr : expr LE expr",
      "expr : expr GE expr",
      "expr : expr EQ expr",
      "expr : expr NE expr",
      "expr : expr AND expr",
      "expr : expr OR expr",
      "expr : NOT expr",
      "expr : '(' expr ')'",
      "expr : '-' expr",
};
#endif /* YYDEBUG */
/* @(#)27       1.7  com/cmd/lang/yacc/yaccpar, bos, bos320 8/12/91 16:09:43 */
/*
 * COMPONENT_NAME: (CMDLANG) Language Utilities
 *
 * FUNCTIONS: yyparse
 * ORIGINS: 03
 */
/*
** Skeleton parser driver for yacc output
*/

/*
** yacc user known macros and defines
*/
#ifdef YYSPLIT
#   define YYERROR      return(-2)
#else
#   define YYERROR      goto yyerrlab
#endif
#ifdef YACC_MSG
#ifndef _XOPEN_SOURCE
#define _XOPEN_SOURCE
#endif
#include <nl_types.h>
nl_catd catd;
#endif
#define YYACCEPT        return(0)
#define YYABORT         return(1)
#ifndef YACC_MSG
#define YYBACKUP( newtoken, newvalue )\
{\
        if ( yychar >= 0 || ( yyr2[ yytmp ] >> 1 ) != 1 )\
        {\
                yyerror( "syntax error - cannot backup" );\
                YYERROR;\
        }\
        yychar = newtoken;\
        yystate = *yyps;\
        yylval = newvalue;\
        goto yynewstate;\
}
#else
#define YYBACKUP( newtoken, newvalue )\
{\
        if ( yychar >= 0 || ( yyr2[ yytmp ] >> 1 ) != 1 )\
        {\
                catd=catopen("yacc_user.cat",0);\
                yyerror(catgets(catd,1,1,"syntax error - cannot backup" ));\
                YYERROR;\
        }\
        yychar = newtoken;\
        yystate = *yyps;\
        yylval = newvalue;\
        goto yynewstate;\
}
#endif
#define YYRECOVERING()  (!!yyerrflag)
#ifndef YYDEBUG
#       define YYDEBUG  1       /* make debugging available */
#endif

/*
** user known globals
*/
int yydebug;                    /* set to 1 to get debugging */

/*
** driver internal defines
*/
#define YYFLAG          (-1000)

#ifdef YYSPLIT
#   define YYSCODE { \
                        extern int (*_yyf[])(); \
                        register int yyret; \
                        if (_yyf[yytmp]) \
                            if ((yyret=(*_yyf[yytmp])()) == -2) \
                                    goto yyerrlab; \
                                else if (yyret>=0) return(yyret); \
                   }
#endif

/*
** global variables used by the parser
*/
YYSTYPE yyv[ YYMAXDEPTH ];      /* value stack */
int yys[ YYMAXDEPTH ];          /* state stack */

YYSTYPE *yypv;                  /* top of value stack */
YYSTYPE *yypvt;                 /* top of value stack for $vars */
int *yyps;                      /* top of state stack */

int yystate;                    /* current state */
int yytmp;                      /* extra var (lasts between blocks) */

int yynerrs;                    /* number of errors */
int yyerrflag;                  /* error recovery flag */
int yychar;                     /* current input token number */



/*
** yyparse - return 0 if worked, 1 if syntax error not recovered from
*/
int
yyparse()
{
        /*
        ** Initialize externals - yyparse may be called more than once
        */
        yypv = &yyv[-1];
        yyps = &yys[-1];
        yystate = 0;
        yytmp = 0;
        yynerrs = 0;
        yyerrflag = 0;
        yychar = -1;
#ifdef YACC_MSG
        catd=catopen("yacc_user.cat",0);
#endif
        goto yystack;
        {
                register YYSTYPE *yy_pv;        /* top of value stack */
                register int *yy_ps;            /* top of state stack */
                register int yy_state;          /* current state */
                register int  yy_n;             /* internal state number info */

                /*
                ** get globals into registers.
                ** branch to here only if YYBACKUP was called.
                */
        yynewstate:
                yy_pv = yypv;
                yy_ps = yyps;
                yy_state = yystate;
                goto yy_newstate;

                /*
                ** get globals into registers.
                ** either we just started, or we just finished a reduction
                */
        yystack:
                yy_pv = yypv;
                yy_ps = yyps;
                yy_state = yystate;

                /*
                ** top of for (;;) loop while no reductions done
                */
        yy_stack:
                /*
                ** put a state and value onto the stacks
                */
#if YYDEBUG
                /*
                ** if debugging, look up token value in list of value vs.
                ** name pairs.  0 and negative (-1) are special values.
                ** Note: linear search is used since time is not a real
                ** consideration while debugging.
                */
                if ( yydebug )
                {
                        register int yy_i;

                        printf( "State %d, token ", yy_state );
                        if ( yychar == 0 )
                                printf( "end-of-file\n" );
                        else if ( yychar < 0 )
                                printf( "-none-\n" );
                        else
                        {
                                for ( yy_i = 0; yytoks[yy_i].t_val >= 0;
                                        yy_i++ )
                                {
                                        if ( yytoks[yy_i].t_val == yychar )
                                                break;
                                }
                                printf( "%s\n", yytoks[yy_i].t_name );
                        }
                }
#endif /* YYDEBUG */
                if ( ++yy_ps >= &yys[ YYMAXDEPTH ] )    /* room on stack? */
                {
#ifndef YACC_MSG
                        yyerror( "yacc stack overflow" );
#else
                        yyerror(catgets(catd,1,2,"yacc stack overflow" ));
#endif
                        YYABORT;
                }
                *yy_ps = yy_state;
                *++yy_pv = yyval;

                /*
                ** we have a new state - find out what to do
                */
        yy_newstate:
                if ( ( yy_n = yypact[ yy_state ] ) <= YYFLAG )
                        goto yydefault;         /* simple state */
#if YYDEBUG
                /*
                ** if debugging, need to mark whether new token grabbed
                */
                yytmp = yychar < 0;
#endif
                if ( ( yychar < 0 ) && ( ( yychar = yylex() ) < 0 ) )
                        yychar = 0;             /* reached EOF */
#if YYDEBUG
                if ( yydebug && yytmp )
                {
                        register int yy_i;

                        printf( "Received token " );
                        if ( yychar == 0 )
                                printf( "end-of-file\n" );
                        else if ( yychar < 0 )
                                printf( "-none-\n" );
                        else
                        {
                                for ( yy_i = 0; yytoks[yy_i].t_val >= 0;
                                        yy_i++ )
                                {
                                        if ( yytoks[yy_i].t_val == yychar )
                                                break;
                                }
                                printf( "%s\n", yytoks[yy_i].t_name );
                        }
                }
#endif /* YYDEBUG */
                if ( ( ( yy_n += yychar ) < 0 ) || ( yy_n >= YYLAST ) )
                        goto yydefault;
                if ( yychk[ yy_n = yyact[ yy_n ] ] == yychar )  /*valid shift*/
                {
                        yychar = -1;
                        yyval = yylval;
                        yy_state = yy_n;
                        if ( yyerrflag > 0 )
                                yyerrflag--;
                        goto yy_stack;
                }

        yydefault:
                if ( ( yy_n = yydef[ yy_state ] ) == -2 )
                {
#if YYDEBUG
                        yytmp = yychar < 0;
#endif
                        if ( ( yychar < 0 ) && ( ( yychar = yylex() ) < 0 ) )
                                yychar = 0;             /* reached EOF */
#if YYDEBUG
                        if ( yydebug && yytmp )
                        {
                                register int yy_i;

                                printf( "Received token " );
                                if ( yychar == 0 )
                                        printf( "end-of-file\n" );
                                else if ( yychar < 0 )
                                        printf( "-none-\n" );
                                else
                                {
                                        for ( yy_i = 0;
                                                yytoks[yy_i].t_val >= 0;
                                                yy_i++ )
                                        {
                                                if ( yytoks[yy_i].t_val
                                                        == yychar )
                                                {
                                                        break;
                                                }
                                        }
                                        printf( "%s\n", yytoks[yy_i].t_name );
                                }
                        }
#endif /* YYDEBUG */
                        /*
                        ** look through exception table
                        */
                        {
                                register int *yyxi = yyexca;

                                while ( ( *yyxi != -1 ) ||
                                        ( yyxi[1] != yy_state ) )
                                {
                                        yyxi += 2;
                                }
                                while ( ( *(yyxi += 2) >= 0 ) &&
                                        ( *yyxi != yychar ) )
                                        ;
                                if ( ( yy_n = yyxi[1] ) < 0 )
                                        YYACCEPT;
                        }
                }

                /*
                ** check for syntax error
                */
                if ( yy_n == 0 )        /* have an error */
                {
                        /* no worry about speed here! */
                        switch ( yyerrflag )
                        {
                        case 0:         /* new error */
#ifndef YACC_MSG
                                yyerror( "syntax error" );
#else
                                yyerror(catgets(catd,1,3,"syntax error" ));
#endif
                                goto skip_init;
                        yyerrlab:
                                /*
                                ** get globals into registers.
                                ** we have a user generated syntax type error
                                */
                                yy_pv = yypv;
                                yy_ps = yyps;
                                yy_state = yystate;
                                yynerrs++;
                        skip_init:
                        case 1:
                        case 2:         /* incompletely recovered error */
                                        /* try again... */
                                yyerrflag = 3;
                                /*
                                ** find state where "error" is a legal
                                ** shift action
                                */
                                while ( yy_ps >= yys )
                                {
                                        yy_n = yypact[ *yy_ps ] + YYERRCODE;
                                        if ( yy_n >= 0 && yy_n < YYLAST &&
                                                yychk[yyact[yy_n]] == YYERRCODE)                                        {
                                                /*
                                                ** simulate shift of "error"
                                                */
                                                yy_state = yyact[ yy_n ];
                                                goto yy_stack;
                                        }
                                        /*
                                        ** current state has no shift on
                                        ** "error", pop stack
                                        */
#if YYDEBUG
#       define _POP_ "Error recovery pops state %d, uncovers state %d\n"
                                        if ( yydebug )
                                                printf( _POP_, *yy_ps,
                                                        yy_ps[-1] );
#       undef _POP_
#endif
                                        yy_ps--;
                                        yy_pv--;
                                }
                                /*
                                ** there is no state on stack with "error" as
                                ** a valid shift.  give up.
                                */
                                YYABORT;
                        case 3:         /* no shift yet; eat a token */
#if YYDEBUG
                                /*
                                ** if debugging, look up token in list of
                                ** pairs.  0 and negative shouldn't occur,
                                ** but since timing doesn't matter when
                                ** debugging, it doesn't hurt to leave the
                                ** tests here.
                                */
                                if ( yydebug )
                                {
                                        register int yy_i;

                                        printf( "Error recovery discards " );
                                        if ( yychar == 0 )
                                                printf( "token end-of-file\n" );
                                        else if ( yychar < 0 )
                                                printf( "token -none-\n" );
                                        else
                                        {
                                                for ( yy_i = 0;
                                                        yytoks[yy_i].t_val >= 0;
                                                        yy_i++ )
                                                {
                                                        if ( yytoks[yy_i].t_val
                                                                == yychar )
                                                        {
                                                                break;
                                                        }
                                                }
                                                printf( "token %s\n",
                                                        yytoks[yy_i].t_name );
                                        }
                                }
#endif /* YYDEBUG */
                                if ( yychar == 0 )      /* reached EOF. quit */
                                        YYABORT;
                                yychar = -1;
                                goto yy_newstate;
                        }
                }/* end if ( yy_n == 0 ) */
                /*
                ** reduction by production yy_n
                ** put stack tops, etc. so things right after switch
                */
#if YYDEBUG
                /*
                ** if debugging, print the string that is the user's
                ** specification of the reduction which is just about
                ** to be done.
                */
                if ( yydebug )
                        printf( "Reduce by (%d) \"%s\"\n",
                                yy_n, yyreds[ yy_n ] );
#endif
                yytmp = yy_n;                   /* value to switch over */
                yypvt = yy_pv;                  /* $vars top of value stack */
                /*
                ** Look in goto table for next state
                ** Sorry about using yy_state here as temporary
                ** register variable, but why not, if it works...
                ** If yyr2[ yy_n ] doesn't have the low order bit
                ** set, then there is no action to be done for
                ** this reduction.  So, no saving & unsaving of
                ** registers done.  The only difference between the
                ** code just after the if and the body of the if is
                ** the goto yy_stack in the body.  This way the test
                ** can be made before the choice of what to do is needed.
                */
                {
                        /* length of production doubled with extra bit */
                        register int yy_len = yyr2[ yy_n ];

                        if ( !( yy_len & 01 ) )
                        {
                                yy_len >>= 1;
                                yyval = ( yy_pv -= yy_len )[1]; /* $$ = $1 */
                                yy_state = yypgo[ yy_n = yyr1[ yy_n ] ] +
                                        *( yy_ps -= yy_len ) + 1;
                                if ( yy_state >= YYLAST ||
                                        yychk[ yy_state =
                                        yyact[ yy_state ] ] != -yy_n )
                                {
                                        yy_state = yyact[ yypgo[ yy_n ] ];
                                }
                                goto yy_stack;
                        }
                        yy_len >>= 1;
                        yyval = ( yy_pv -= yy_len )[1]; /* $$ = $1 */
                        yy_state = yypgo[ yy_n = yyr1[ yy_n ] ] +
                                *( yy_ps -= yy_len ) + 1;
                        if ( yy_state >= YYLAST ||
                                yychk[ yy_state = yyact[ yy_state ] ] != -yy_n )
                        {
                                yy_state = yyact[ yypgo[ yy_n ] ];
                        }
                }
                                        /* save until reenter driver code */
                yystate = yy_state;
                yyps = yy_ps;
                yypv = yy_pv;
        }
        /*
        ** code supplied by user is placed in this switch
        */

                switch(yytmp){

case 5:
# line 478 "pars.yacc"
{
	    result = yypvt[-1].val;
	} /*NOTREACHED*/ break;
case 6:
# line 481 "pars.yacc"
{
	    result = *yypvt[-1].ptr;
	} /*NOTREACHED*/ break;
case 13:
# line 490 "pars.yacc"
{
	    return 1;
	} /*NOTREACHED*/ break;
case 14:
# line 496 "pars.yacc"
{
	    if (yypvt[-1].pset == FILEP) {
		set_printer(FILEP, yypvt[-0].pset);
	    }
	    else {
		set_printer(yypvt[-1].pset, yypvt[-0].pset);
	    }
	} /*NOTREACHED*/ break;
case 15:
# line 504 "pars.yacc"
{
	    if (yypvt[-1].pset == FILEP) {
		set_printer(FILEP, yypvt[-0].pset);
	    }
	    else {
		set_printer(yypvt[-1].pset, yypvt[-0].pset);
	    }
	} /*NOTREACHED*/ break;
case 16:
# line 512 "pars.yacc"
{
	    if (yypvt[-0].pset == FILEP) {
		set_printer(FILEP, NULL);
	    }
	    else {
		set_printer(yypvt[-0].pset, NULL);
	    }
	} /*NOTREACHED*/ break;
case 17:
# line 520 "pars.yacc"
{
	    tdevice = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 18:
# line 523 "pars.yacc"
{
	    hdevice = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 19:
# line 526 "pars.yacc"
{
	    do_hardcopy();
	} /*NOTREACHED*/ break;
case 20:
# line 532 "pars.yacc"
{ yyval.pset = GR_PS_P; } /*NOTREACHED*/ break;
case 21:
# line 533 "pars.yacc"
{ yyval.pset = GR_PS_L; } /*NOTREACHED*/ break;
case 22:
# line 534 "pars.yacc"
{ yyval.pset = GR_MIF_P; } /*NOTREACHED*/ break;
case 23:
# line 535 "pars.yacc"
{ yyval.pset = GR_MIF_L; } /*NOTREACHED*/ break;
case 24:
# line 536 "pars.yacc"
{ yyval.pset = GR_HPGL_P; } /*NOTREACHED*/ break;
case 25:
# line 537 "pars.yacc"
{ yyval.pset = GR_HPGL_L; } /*NOTREACHED*/ break;
case 26:
# line 538 "pars.yacc"
{ yyval.pset = hdevice; } /*NOTREACHED*/ break;
case 27:
# line 539 "pars.yacc"
{ yyval.pset = FILEP; } /*NOTREACHED*/ break;
case 28:
# line 543 "pars.yacc"
{
	    rg[yypvt[-1].pset].active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 29:
# line 546 "pars.yacc"
{
	    rg[yypvt[-2].pset].type = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 30:
# line 549 "pars.yacc"
{
	    rg[yypvt[-2].pset].color = checkon(COLOR, rg[yypvt[-2].pset].color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 31:
# line 552 "pars.yacc"
{
	    rg[yypvt[-2].pset].lines = checkon(LINESTYLE, rg[yypvt[-2].pset].lines, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 32:
# line 555 "pars.yacc"
{
	    rg[yypvt[-2].pset].linew = checkon(LINEWIDTH, rg[yypvt[-2].pset].linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 33:
# line 559 "pars.yacc"
{
	    rg[yypvt[-8].pset].x1 = yypvt[-6].val;
	    rg[yypvt[-8].pset].y1 = yypvt[-4].val;
	    rg[yypvt[-8].pset].x2 = yypvt[-2].val;
	    rg[yypvt[-8].pset].y2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 34:
# line 566 "pars.yacc"
{
	    if (rg[yypvt[-4].pset].x == NULL || rg[yypvt[-4].pset].n == 0) {
		rg[yypvt[-4].pset].n = 0;
		rg[yypvt[-4].pset].x = (double *) calloc(1, sizeof(double));
		rg[yypvt[-4].pset].y = (double *) calloc(1, sizeof(double));
	    } else {
		rg[yypvt[-4].pset].x = (double *) realloc(rg[yypvt[-4].pset].x, (rg[yypvt[-4].pset].n + 1) * sizeof(double));
		rg[yypvt[-4].pset].y = (double *) realloc(rg[yypvt[-4].pset].y, (rg[yypvt[-4].pset].n + 1) * sizeof(double));
	    }
	    rg[yypvt[-4].pset].x[rg[yypvt[-4].pset].n] = yypvt[-2].val;
	    rg[yypvt[-4].pset].y[rg[yypvt[-4].pset].n] = yypvt[-0].val;
	    rg[yypvt[-4].pset].n++;
	} /*NOTREACHED*/ break;
case 35:
# line 579 "pars.yacc"
{
	    rg[yypvt[-2].pset].linkto[yypvt[-0].pset] = TRUE;
	} /*NOTREACHED*/ break;
case 36:
# line 585 "pars.yacc"
{
	    drawgraph();
	} /*NOTREACHED*/ break;
case 37:
# line 588 "pars.yacc"
{
	    auto_redraw = (yypvt[-0].pset == ON);
	} /*NOTREACHED*/ break;
case 38:
# line 591 "pars.yacc"
{
	    if (inwin) {
		set_left_footer(yypvt[-0].pset);
	    }
	    else {
		printf("%s\n", yypvt[-0].pset);
	    }
	} /*NOTREACHED*/ break;
case 39:
# line 599 "pars.yacc"
{
	    setbgcolor((int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 40:
# line 602 "pars.yacc"
{
	    xlibsetcmap((int) yypvt[-6].val, (int) yypvt[-4].val, (int) yypvt[-2].val, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 41:
# line 605 "pars.yacc"
{
	    exit(0);
	} /*NOTREACHED*/ break;
case 42:
# line 609 "pars.yacc"
{
	    switch (yypvt[-0].pset) {
	    case UP:
		gwindup_proc();
		break;
	    case DOWN:
		gwinddown_proc();
		break;
	    case RIGHT:
		gwindright_proc();
		break;
	    case LEFT:
		gwindleft_proc();
		break;
	    case IN:
		gwindshrink_proc();
		break;
	    case OUT:
		gwindexpand_proc();
		break;
	    }
	} /*NOTREACHED*/ break;
case 43:
# line 631 "pars.yacc"
{
	    scroll_proc((int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 44:
# line 634 "pars.yacc"
{
	    scrollinout_proc((int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 45:
# line 637 "pars.yacc"
{
	    scrolling_islinked = yypvt[-0].pset == ON;
	} /*NOTREACHED*/ break;
case 46:
# line 640 "pars.yacc"
{
	    my_doublebuffer(yypvt[-0].pset == TRUEP);
	} /*NOTREACHED*/ break;
case 47:
# line 643 "pars.yacc"
{
	    my_frontbuffer(yypvt[-0].pset == TRUEP);
	} /*NOTREACHED*/ break;
case 48:
# line 646 "pars.yacc"
{
	    my_backbuffer(yypvt[-0].pset == TRUEP);
	} /*NOTREACHED*/ break;
case 49:
# line 649 "pars.yacc"
{
	    my_swapbuffer();
	} /*NOTREACHED*/ break;
case 50:
# line 652 "pars.yacc"
{
	    sleep((int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 51:
# line 655 "pars.yacc"
{	/* TODO add delay function */
	} /*NOTREACHED*/ break;
case 52:
# line 657 "pars.yacc"
{		/* TODO add abort flag and function */
	} /*NOTREACHED*/ break;
case 53:
# line 660 "pars.yacc"
{
	    gotparams = TRUE;
	    strcpy(paramfile, (char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 54:
# line 665 "pars.yacc"
{
	    if (!fexists((char *) yypvt[-0].pset)) {
		FILE *pp = fopen((char *) yypvt[-0].pset, "w");
		if (pp != NULL) {
		    putparms(cg, pp, 0);
		    fclose(pp);
		} else {
		    errwin("Unable to write parameter file");
		}
	    }
	} /*NOTREACHED*/ break;
case 55:
# line 676 "pars.yacc"
{
	    cg = (int) yypvt[-0].pset;
	    g[cg].parmsread = TRUE;
	    change_gno = cg;
	} /*NOTREACHED*/ break;
case 56:
# line 681 "pars.yacc"
{
	    curset = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 57:
# line 684 "pars.yacc"
{
	    do_activateset(cg, yypvt[-1].pset, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 58:
# line 687 "pars.yacc"
{
	    add_point(cg, yypvt[-4].pset, yypvt[-2].val, yypvt[-0].val, 0.0, 0.0, XY);
	} /*NOTREACHED*/ break;
case 59:
# line 690 "pars.yacc"
{
	    add_point(yypvt[-6].pset, yypvt[-4].pset, yypvt[-2].val, yypvt[-0].val, 0.0, 0.0, XY);
	} /*NOTREACHED*/ break;
case 60:
# line 693 "pars.yacc"
{
	    do_copyset(cg, yypvt[-2].pset, cg, yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 61:
# line 696 "pars.yacc"
{
	    do_copyset(yypvt[-6].pset, yypvt[-4].pset, yypvt[-2].pset, yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 62:
# line 699 "pars.yacc"
{
	    do_moveset(cg, yypvt[-2].pset, cg, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 63:
# line 702 "pars.yacc"
{
	    do_moveset(yypvt[-6].pset, yypvt[-4].pset, yypvt[-2].pset, yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 64:
# line 706 "pars.yacc"
{
	    killset(cg, yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 65:
# line 710 "pars.yacc"
{
	    int i;
	    for (i = 0; i < g[cg].maxplot; i++) {
		killset(cg, i);
	    }
	} /*NOTREACHED*/ break;
case 66:
# line 717 "pars.yacc"
{
	    kill_graph(yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 67:
# line 721 "pars.yacc"
{
	    kill_graph(MAXGRAPH);
	} /*NOTREACHED*/ break;
case 68:
# line 725 "pars.yacc"
{
	    wipeout(0);
	} /*NOTREACHED*/ break;
case 69:
# line 729 "pars.yacc"
{
	    int i;
	    for (i = 0; i < (int) yypvt[-4].val; i++) {
		yypvt[-5].ptr[i] = yypvt[-2].val + yypvt[-0].val * i;
	    }
	} /*NOTREACHED*/ break;
case 70:
# line 736 "pars.yacc"
{
	    int setno = yypvt[-3].pset, ideg = (int) yypvt[-1].val;
	    do_regress(setno, ideg, 0);
	} /*NOTREACHED*/ break;
case 71:
# line 741 "pars.yacc"
{
	    do_running_command(yypvt[-5].pset, yypvt[-3].pset, (int) yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 72:
# line 745 "pars.yacc"
{
	    do_fourier_command(yypvt[-5].pset, yypvt[-3].pset, (int) yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 73:
# line 749 "pars.yacc"
{
	    do_spline(yypvt[-7].pset, yypvt[-5].val, yypvt[-3].val, (int) yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 74:
# line 753 "pars.yacc"
{
	    do_histo_command(yypvt[-7].pset, yypvt[-5].val, yypvt[-3].val, (int) yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 75:
# line 757 "pars.yacc"
{
	    do_differ(yypvt[-3].pset, (int) yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 76:
# line 761 "pars.yacc"
{
	    do_int(yypvt[-1].pset, 0);
	} /*NOTREACHED*/ break;
case 77:
# line 765 "pars.yacc"
{
	    if (activeset(cg)) {
		defaultgraph(cg);
		default_axis(cg, g[cg].auto_type, X_AXIS);
		default_axis(cg, g[cg].auto_type, ZX_AXIS);
		default_axis(cg, g[cg].auto_type, Y_AXIS);
		default_axis(cg, g[cg].auto_type, ZY_AXIS);
		update_world(cg);
		drawgraph();
	    } else {
		errwin("No active sets!");
	    }
	} /*NOTREACHED*/ break;
case 78:
# line 779 "pars.yacc"
{
	    if (activeset(cg)) {
		defaultx(cg, -1);
		default_axis(cg, g[cg].auto_type, X_AXIS);
		default_axis(cg, g[cg].auto_type, ZX_AXIS);
		update_world(cg);
		drawgraph();
	    } else {
		errwin("No active sets!");
	    }
	} /*NOTREACHED*/ break;
case 79:
# line 791 "pars.yacc"
{
	    if (activeset(cg)) {
		defaulty(cg, -1);
		default_axis(cg, g[cg].auto_type, Y_AXIS);
		default_axis(cg, g[cg].auto_type, ZY_AXIS);
		update_world(cg);
		drawgraph();
	    } else {
		errwin("No active sets!");
	    }
	} /*NOTREACHED*/ break;
case 80:
# line 803 "pars.yacc"
{
	    if (isactive_set(cg, yypvt[-0].pset)) {
		defaultsetgraph(cg, yypvt[-0].pset);
		default_axis(cg, g[cg].auto_type, X_AXIS);
		default_axis(cg, g[cg].auto_type, ZX_AXIS);
		default_axis(cg, g[cg].auto_type, Y_AXIS);
		default_axis(cg, g[cg].auto_type, ZY_AXIS);
		update_world(cg);
		drawgraph();
	    } else {
		errwin("Set not active");
	    }
	} /*NOTREACHED*/ break;
case 81:
# line 817 "pars.yacc"
{
	    extern int go_locateflag;
	    go_locateflag = (yypvt[-0].pset == ON);
	} /*NOTREACHED*/ break;
case 82:
# line 822 "pars.yacc"
{
	    draw_focus(cg);
	    cg = (int) yypvt[-0].pset;
	    defineworld(g[cg].w.xg1, g[cg].w.yg1, g[cg].w.xg2, g[cg].w.yg2);
	    viewport(g[cg].v.xv1, g[cg].v.yv1, g[cg].v.xv2, g[cg].v.yv2);
	    draw_focus(cg);
	    update_all(cg);
	} /*NOTREACHED*/ break;
case 83:
# line 830 "pars.yacc"
{
	    draw_focus_flag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 84:
# line 833 "pars.yacc"
{
	    focus_policy = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 85:
# line 836 "pars.yacc"
{
	    focus_policy = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 86:
# line 839 "pars.yacc"
{
	    focus_policy = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 87:
# line 842 "pars.yacc"
{
	    cursource = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 88:
# line 845 "pars.yacc"
{
	    curtype = yypvt[-0].pset;
	    change_type = curtype;
	} /*NOTREACHED*/ break;
case 89:
# line 850 "pars.yacc"
{
	    gotread = TRUE;
	    readtype = curtype;
	    readsrc = cursource;
	    strcpy(readfile, (char *)yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 90:
# line 857 "pars.yacc"
{
	    gotbatch = TRUE;
	    strcpy(batchfile, (char *)yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 91:
# line 862 "pars.yacc"
{
	    gotread = TRUE;
	    readtype = yypvt[-1].pset;
	    readsrc = cursource;
	    strcpy(readfile, (char *)yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 92:
# line 869 "pars.yacc"
{
	    gotread = TRUE;
	    strcpy(readfile, (char *)yypvt[-0].pset);
	    readtype = yypvt[-2].pset;
	    readsrc = yypvt[-1].pset;
	} /*NOTREACHED*/ break;
case 93:
# line 875 "pars.yacc"
{
	    push_world();
	} /*NOTREACHED*/ break;
case 94:
# line 878 "pars.yacc"
{
	    pop_world();
	} /*NOTREACHED*/ break;
case 95:
# line 881 "pars.yacc"
{
	    cycle_world_stack();
	} /*NOTREACHED*/ break;
case 96:
# line 884 "pars.yacc"
{
	    if ((int) yypvt[-0].val > 0)
		show_world_stack((int) yypvt[-0].val - 1);
	} /*NOTREACHED*/ break;
case 97:
# line 889 "pars.yacc"
{
	    add_world(cg, yypvt[-14].val, yypvt[-12].val, yypvt[-10].val, yypvt[-8].val, yypvt[-6].val, yypvt[-4].val, yypvt[-2].val, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 98:
# line 892 "pars.yacc"
{
	    clear_world_stack();
	} /*NOTREACHED*/ break;
case 99:
# line 895 "pars.yacc"
{
	    do_clear_boxes();
	} /*NOTREACHED*/ break;
case 100:
# line 898 "pars.yacc"
{
	    curbox = next_box();
	} /*NOTREACHED*/ break;
case 101:
# line 901 "pars.yacc"
{
	    curbox = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 102:
# line 904 "pars.yacc"
{
	    boxes[curbox].active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 103:
# line 907 "pars.yacc"
{
	    boxes[curbox].gno = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 104:
# line 911 "pars.yacc"
{
	    if (curbox >= 0 && curbox < MAXBOXES) {
		boxes[curbox].x1 = yypvt[-6].val;
		boxes[curbox].y1 = yypvt[-4].val;
		boxes[curbox].x2 = yypvt[-2].val;
		boxes[curbox].y2 = yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 105:
# line 919 "pars.yacc"
{
	    box_loctype = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 106:
# line 922 "pars.yacc"
{
	    box_lines = checkon(LINESTYLE, box_lines, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 107:
# line 925 "pars.yacc"
{
	    box_linew = checkon(LINEWIDTH, box_linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 108:
# line 928 "pars.yacc"
{
	    box_color = checkon(COLOR, box_color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 109:
# line 931 "pars.yacc"
{
	    box_fill = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 110:
# line 934 "pars.yacc"
{
	    box_fillcolor = checkon(COLOR, box_fillcolor, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 111:
# line 937 "pars.yacc"
{
	    box_fillpat = checkon(PATTERN, box_fillpat, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 112:
# line 941 "pars.yacc"
{
	    if (curbox >= 0 && curbox < MAXBOXES) {
		boxes[curbox].lines = box_lines;
		boxes[curbox].linew = box_linew;
		boxes[curbox].color = box_color;
		boxes[curbox].fill = box_fill;
		boxes[curbox].fillcolor = box_fillcolor;
		boxes[curbox].fillpattern = box_fillpat;
		boxes[curbox].loctype = box_loctype;
	    }
	} /*NOTREACHED*/ break;
case 113:
# line 952 "pars.yacc"
{
	    curline = next_line();
	} /*NOTREACHED*/ break;
case 114:
# line 955 "pars.yacc"
{
	    curline = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 115:
# line 958 "pars.yacc"
{
	    do_clear_lines();
	} /*NOTREACHED*/ break;
case 116:
# line 961 "pars.yacc"
{
	    lines[curline].active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 117:
# line 964 "pars.yacc"
{
	    lines[curline].gno = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 118:
# line 968 "pars.yacc"
{
	    lines[curline].x1 = yypvt[-6].val;
	    lines[curline].y1 = yypvt[-4].val;
	    lines[curline].x2 = yypvt[-2].val;
	    lines[curline].y2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 119:
# line 974 "pars.yacc"
{
	    line_loctype = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 120:
# line 977 "pars.yacc"
{
	    line_linew = checkon(LINEWIDTH, line_linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 121:
# line 980 "pars.yacc"
{
	    line_lines = checkon(LINESTYLE, line_lines, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 122:
# line 983 "pars.yacc"
{
	    line_color = checkon(COLOR, line_color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 123:
# line 986 "pars.yacc"
{
	    line_arrow = checkon(ARROW, line_arrow, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 124:
# line 989 "pars.yacc"
{
	    line_asize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 125:
# line 992 "pars.yacc"
{
	    line_atype = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 126:
# line 996 "pars.yacc"
{
	    if (curline >= 0 && curline < MAXLINES) {
		lines[curline].lines = line_lines;
		lines[curline].linew = line_linew;
		lines[curline].color = line_color;
		lines[curline].arrow = line_arrow;
		lines[curline].asize = line_asize;
		lines[curline].atype = line_atype;
		lines[curline].loctype = line_loctype;
	    }
	} /*NOTREACHED*/ break;
case 127:
# line 1007 "pars.yacc"
{
	    do_clear_text();
	} /*NOTREACHED*/ break;
case 128:
# line 1010 "pars.yacc"
{
	    curstring = next_string();
	} /*NOTREACHED*/ break;
case 129:
# line 1013 "pars.yacc"
{
	    curstring = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 130:
# line 1016 "pars.yacc"
{
	    pstr[curstring].active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 131:
# line 1019 "pars.yacc"
{
	    pstr[curstring].gno = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 132:
# line 1023 "pars.yacc"
{
	    pstr[curstring].x = yypvt[-2].val;
	    pstr[curstring].y = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 133:
# line 1027 "pars.yacc"
{
	    string_loctype = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 134:
# line 1030 "pars.yacc"
{
	    string_linew = checkon(LINEWIDTH, string_linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 135:
# line 1033 "pars.yacc"
{
	    string_color = checkon(COLOR, string_color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 136:
# line 1036 "pars.yacc"
{
	    string_rot = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 137:
# line 1039 "pars.yacc"
{
	    string_font = checkon(FONTP, string_font, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 138:
# line 1042 "pars.yacc"
{
	    string_just = checkon(JUST, string_just, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 139:
# line 1045 "pars.yacc"
{
	    string_size = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 140:
# line 1049 "pars.yacc"
{
	    strcpy(pstr[curstring].s, (char *) yypvt[-0].pset);
	    pstr[curstring].linew = string_linew;
	    pstr[curstring].color = string_color;
	    pstr[curstring].font = string_font;
	    pstr[curstring].just = string_just;
	    pstr[curstring].loctype = string_loctype;
	    pstr[curstring].rot = string_rot;
	    pstr[curstring].charsize = string_size;
	} /*NOTREACHED*/ break;
case 141:
# line 1059 "pars.yacc"
{
	    g[cg].d.lines = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 142:
# line 1062 "pars.yacc"
{
	    g[cg].d.linew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 143:
# line 1065 "pars.yacc"
{
	    g[cg].d.color = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 144:
# line 1068 "pars.yacc"
{
	    g[cg].d.charsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 145:
# line 1071 "pars.yacc"
{
	    g[cg].d.font = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 146:
# line 1074 "pars.yacc"
{
	    g[cg].d.fontsrc = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 147:
# line 1077 "pars.yacc"
{
	    g[cg].d.symsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 148:
# line 1081 "pars.yacc"
{
	    g[cg].w.xg1 = yypvt[-6].val;
	    g[cg].w.yg1 = yypvt[-4].val;
	    g[cg].w.xg2 = yypvt[-2].val;
	    g[cg].w.yg2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 149:
# line 1087 "pars.yacc"
{
	    g[cg].w.xg1 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 150:
# line 1090 "pars.yacc"
{
	    g[cg].w.xg2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 151:
# line 1093 "pars.yacc"
{
	    g[cg].w.yg1 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 152:
# line 1096 "pars.yacc"
{
	    g[cg].w.yg2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 153:
# line 1100 "pars.yacc"
{
	    g[cg].v.xv1 = yypvt[-6].val;
	    g[cg].v.yv1 = yypvt[-4].val;
	    g[cg].v.xv2 = yypvt[-2].val;
	    g[cg].v.yv2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 154:
# line 1106 "pars.yacc"
{
	    g[cg].v.xv1 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 155:
# line 1109 "pars.yacc"
{
	    g[cg].v.xv2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 156:
# line 1112 "pars.yacc"
{
	    g[cg].v.yv1 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 157:
# line 1115 "pars.yacc"
{
	    g[cg].v.yv2 = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 158:
# line 1118 "pars.yacc"
{
	    strcpy(g[cg].labs.title.s, (char *)yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 159:
# line 1121 "pars.yacc"
{
	    g[cg].labs.title.font = checkon(FONTP, g[cg].labs.title.font, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 160:
# line 1124 "pars.yacc"
{
	    g[cg].labs.title.charsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 161:
# line 1127 "pars.yacc"
{
	    g[cg].labs.title.color = checkon(COLOR, g[cg].labs.title.color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 162:
# line 1131 "pars.yacc"
{
	    g[cg].labs.title.linew = checkon(LINEWIDTH, g[cg].labs.title.linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 163:
# line 1134 "pars.yacc"
{
	    strcpy(g[cg].labs.stitle.s, (char *)yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 164:
# line 1138 "pars.yacc"
{
	    g[cg].labs.stitle.font = checkon(FONTP, g[cg].labs.stitle.font, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 165:
# line 1141 "pars.yacc"
{
	    g[cg].labs.stitle.charsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 166:
# line 1145 "pars.yacc"
{
	    g[cg].labs.stitle.color = checkon(COLOR, g[cg].labs.stitle.color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 167:
# line 1149 "pars.yacc"
{
	    g[cg].labs.stitle.linew = checkon(LINEWIDTH, g[cg].labs.stitle.color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 168:
# line 1152 "pars.yacc"
{
	    realloc_plots((int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 169:
# line 1155 "pars.yacc"
{
	    g[cg].l.active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 170:
# line 1158 "pars.yacc"
{
	    g[cg].l.loctype = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 171:
# line 1161 "pars.yacc"
{
	    g[cg].l.layout = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 172:
# line 1164 "pars.yacc"
{
	    g[cg].l.vgap = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 173:
# line 1167 "pars.yacc"
{
	    g[cg].l.hgap = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 174:
# line 1170 "pars.yacc"
{
	    g[cg].l.len = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 175:
# line 1173 "pars.yacc"
{
	    g[cg].l.box = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 176:
# line 1176 "pars.yacc"
{
	    g[cg].l.boxfill = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 177:
# line 1179 "pars.yacc"
{
	    g[cg].l.boxfillusing = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 178:
# line 1183 "pars.yacc"
{
	    if (yypvt[-1].pset == COLOR) {
		g[cg].l.boxfillcolor = (int) yypvt[-0].val;
	    } else {
		g[cg].l.boxfillpat = (int) yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 179:
# line 1190 "pars.yacc"
{
	    g[cg].l.boxlcolor = checkon(COLOR, g[cg].l.boxlcolor, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 180:
# line 1193 "pars.yacc"
{
	    g[cg].l.boxlines = checkon(LINESTYLE, g[cg].l.boxlines, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 181:
# line 1196 "pars.yacc"
{
	    g[cg].l.boxlinew = checkon(LINEWIDTH, g[cg].l.boxlinew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 182:
# line 1199 "pars.yacc"
{
	    g[cg].l.legx = yypvt[-2].val;
	    g[cg].l.legy = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 183:
# line 1203 "pars.yacc"
{
	    g[cg].l.legx = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 184:
# line 1206 "pars.yacc"
{
	    g[cg].l.legy = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 185:
# line 1209 "pars.yacc"
{
	    g[cg].l.charsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 186:
# line 1212 "pars.yacc"
{
	    g[cg].l.font = checkon(FONTP, g[cg].l.font, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 187:
# line 1215 "pars.yacc"
{
	    g[cg].l.lines = checkon(LINESTYLE, g[cg].l.lines, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 188:
# line 1218 "pars.yacc"
{
	    g[cg].l.linew = checkon(LINEWIDTH, g[cg].l.linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 189:
# line 1221 "pars.yacc"
{
	    g[cg].l.color = checkon(COLOR, g[cg].l.color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 190:
# line 1224 "pars.yacc"
{
	    strcpy(g[cg].l.str[(int) yypvt[-1].val].s, (char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 191:
# line 1227 "pars.yacc"
{
	    g[cg].f.active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 192:
# line 1230 "pars.yacc"
{
	    g[cg].f.type = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 193:
# line 1233 "pars.yacc"
{
	    g[cg].f.lines = checkon(LINESTYLE, g[cg].f.lines, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 194:
# line 1236 "pars.yacc"
{
	    g[cg].f.linew = checkon(LINEWIDTH, g[cg].f.linew, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 195:
# line 1239 "pars.yacc"
{
	    g[cg].f.color = checkon(COLOR, g[cg].f.color, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 196:
# line 1242 "pars.yacc"
{
	    g[cg].f.fillbg = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 197:
# line 1245 "pars.yacc"
{
	    g[cg].f.bgcolor = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 198:
# line 1248 "pars.yacc"
{
	    g[yypvt[-1].pset].active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 199:
# line 1251 "pars.yacc"
{
	    g[yypvt[-2].pset].label = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 200:
# line 1254 "pars.yacc"
{
	    g[yypvt[-3].pset].auto_type = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 201:
# line 1257 "pars.yacc"
{
	    g[yypvt[-3].pset].auto_type = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 202:
# line 1260 "pars.yacc"
{
	    g[yypvt[-2].pset].parmsread = (yypvt[-0].pset == FALSEP);
	} /*NOTREACHED*/ break;
case 203:
# line 1263 "pars.yacc"
{
	    g[yypvt[-2].pset].hidden = (yypvt[-0].pset == TRUEP);
	} /*NOTREACHED*/ break;
case 204:
# line 1266 "pars.yacc"
{
	    g[yypvt[-2].pset].type = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 205:
# line 1269 "pars.yacc"
{
	    g[yypvt[-2].pset].pointset = (yypvt[-0].pset == ON);
	} /*NOTREACHED*/ break;
case 206:
# line 1273 "pars.yacc"
{
	    g[yypvt[-4].pset].fx = yypvt[-1].pset;
	    g[yypvt[-4].pset].fy = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 207:
# line 1278 "pars.yacc"
{
	    g[yypvt[-5].pset].px = yypvt[-2].val;
	    g[yypvt[-5].pset].py = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 208:
# line 1283 "pars.yacc"
{
	    g[yypvt[-5].pset].dsx = yypvt[-2].val;
	    g[yypvt[-5].pset].dsy = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 209:
# line 1287 "pars.yacc"
{
	    g[yypvt[-3].pset].pt_type = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 210:
# line 1290 "pars.yacc"
{
	    realloc_graph_plots(yypvt[-3].pset, (int) yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 211:
# line 1296 "pars.yacc"
{ g[cg].vp.vscale = yypvt[-0].val; } /*NOTREACHED*/ break;
case 212:
# line 1297 "pars.yacc"
{ g[cg].vp.active = yypvt[-0].pset; } /*NOTREACHED*/ break;
case 213:
# line 1298 "pars.yacc"
{ g[cg].vp.linew = (int) yypvt[-0].val; } /*NOTREACHED*/ break;
case 214:
# line 1299 "pars.yacc"
{ g[cg].vp.lines = (int) yypvt[-0].val; } /*NOTREACHED*/ break;
case 215:
# line 1300 "pars.yacc"
{ g[cg].vp.color = (int) yypvt[-0].val; } /*NOTREACHED*/ break;
case 216:
# line 1301 "pars.yacc"
{ g[cg].vp.loctype = yypvt[-0].pset; } /*NOTREACHED*/ break;
case 217:
# line 1302 "pars.yacc"
{ g[cg].vp.arrowtype = (int) yypvt[-0].val; } /*NOTREACHED*/ break;
case 218:
# line 1306 "pars.yacc"
{
	    yyval.pset = XY;
	} /*NOTREACHED*/ break;
case 219:
# line 1309 "pars.yacc"
{
	    yyval.pset = XYARC;
	} /*NOTREACHED*/ break;
case 220:
# line 1312 "pars.yacc"
{
	    yyval.pset = XYBOX;
	} /*NOTREACHED*/ break;
case 221:
# line 1315 "pars.yacc"
{
	    yyval.pset = XYHILO;
	} /*NOTREACHED*/ break;
case 222:
# line 1318 "pars.yacc"
{
	    yyval.pset = XYRT;
	} /*NOTREACHED*/ break;
case 223:
# line 1321 "pars.yacc"
{
	    yyval.pset = XYSEG;
	} /*NOTREACHED*/ break;
case 224:
# line 1324 "pars.yacc"
{
	    yyval.pset = XYSTRING;
	} /*NOTREACHED*/ break;
case 225:
# line 1327 "pars.yacc"
{
	    yyval.pset = XYDX;
	} /*NOTREACHED*/ break;
case 226:
# line 1330 "pars.yacc"
{
	    yyval.pset = XYDY;
	} /*NOTREACHED*/ break;
case 227:
# line 1333 "pars.yacc"
{
	    yyval.pset = XYDXDX;
	} /*NOTREACHED*/ break;
case 228:
# line 1336 "pars.yacc"
{
	    yyval.pset = XYDYDY;
	} /*NOTREACHED*/ break;
case 229:
# line 1339 "pars.yacc"
{
	    yyval.pset = XYDXDY;
	} /*NOTREACHED*/ break;
case 230:
# line 1342 "pars.yacc"
{
	    yyval.pset = XYX2Y2;
	} /*NOTREACHED*/ break;
case 231:
# line 1345 "pars.yacc"
{
	    yyval.pset = XYXX;
	} /*NOTREACHED*/ break;
case 232:
# line 1348 "pars.yacc"
{
	    yyval.pset = XYYY;
	} /*NOTREACHED*/ break;
case 233:
# line 1351 "pars.yacc"
{
	    yyval.pset = XYZ;
	} /*NOTREACHED*/ break;
case 234:
# line 1354 "pars.yacc"
{
	    yyval.pset = XYZW;
	} /*NOTREACHED*/ break;
case 235:
# line 1357 "pars.yacc"
{
	    yyval.pset = XYUV;
	} /*NOTREACHED*/ break;
case 236:
# line 1360 "pars.yacc"
{
	    yyval.pset = NXY;
	} /*NOTREACHED*/ break;
case 237:
# line 1363 "pars.yacc"
{
	    yyval.pset = BIN;
	} /*NOTREACHED*/ break;
case 238:
# line 1369 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 239:
# line 1372 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 240:
# line 1375 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 241:
# line 1378 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 242:
# line 1381 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 243:
# line 1384 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 244:
# line 1387 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 245:
# line 1390 "pars.yacc"
{
	    yyval.pset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 246:
# line 1393 "pars.yacc"
{
	    yyval.pset = XY;		/* not active */
	} /*NOTREACHED*/ break;
case 247:
# line 1396 "pars.yacc"
{
	    yyval.pset = XY;		/* not active */
	} /*NOTREACHED*/ break;
case 255:
# line 1426 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ACTIVE, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 256:
# line 1429 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ACTIVE, yypvt[-2].pset, 0);
	} /*NOTREACHED*/ break;
case 257:
# line 1432 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, TYPE, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 258:
# line 1435 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, MISSINGP, yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 259:
# line 1438 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, PREC, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 260:
# line 1441 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, FORMAT, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 261:
# line 1444 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, TYPE, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 262:
# line 1447 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, FILL, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 263:
# line 1450 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, CENTER, (yypvt[-0].pset == TRUEP), 0);
	} /*NOTREACHED*/ break;
case 264:
# line 1453 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, SIZE, yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 265:
# line 1456 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, CHAR, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 266:
# line 1459 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SYMBOL, SKIP, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 267:
# line 1462 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, yypvt[-1].pset, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 268:
# line 1465 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, FILL, TYPE, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 269:
# line 1468 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, FILL, WITH, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 270:
# line 1471 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, FILL, yypvt[-1].pset, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 271:
# line 1474 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, SKIP, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 272:
# line 1477 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, LENGTH, yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 273:
# line 1480 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, TYPE, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 274:
# line 1483 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, LINEWIDTH, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 275:
# line 1486 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, LINESTYLE, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 276:
# line 1489 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, RISER, ACTIVE, yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 277:
# line 1492 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, RISER, LINEWIDTH, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 278:
# line 1495 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, ERRORBAR, RISER, LINESTYLE, (int) yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 279:
# line 1498 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, XYZ, yypvt[-2].val, yypvt[-0].val, 0);
	} /*NOTREACHED*/ break;
case 280:
# line 1501 "pars.yacc"
{
	    set_prop(whichgraph, SET, SETNUM, whichset, COMMENT, (char *) yypvt[-0].pset, 0);
	} /*NOTREACHED*/ break;
case 296:
# line 1531 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-0].pset, 0.0);
	} /*NOTREACHED*/ break;
case 297:
# line 1534 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-1].pset, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 298:
# line 1537 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-1].pset, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 299:
# line 1540 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-1].pset, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 300:
# line 1543 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-1].pset, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 301:
# line 1546 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-2].pset, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 302:
# line 1549 "pars.yacc"
{
	    set_axis_prop(whichgraph, naxis, yypvt[-1].pset, yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 307:
# line 1559 "pars.yacc"
{
	    g[cg].t[naxis].active = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 310:
# line 1571 "pars.yacc"
{
	    g[cg].t[naxis].t_flag = yypvt[-0].pset;
	    g[cg].t[naxis].t_mflag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 311:
# line 1575 "pars.yacc"
{
	    g[cg].t[naxis].t_flag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 312:
# line 1578 "pars.yacc"
{
	    g[cg].t[naxis].t_mflag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 313:
# line 1581 "pars.yacc"
{
	    g[cg].t[naxis].tmajor = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 314:
# line 1584 "pars.yacc"
{
	    g[cg].t[naxis].tminor = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 315:
# line 1587 "pars.yacc"
{
	    g[cg].t[naxis].offsx = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 316:
# line 1590 "pars.yacc"
{
	    g[cg].t[naxis].offsy = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 317:
# line 1593 "pars.yacc"
{
	    g[cg].t[naxis].alt = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 318:
# line 1596 "pars.yacc"
{
	    g[cg].t[naxis].tmin = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 319:
# line 1599 "pars.yacc"
{
	    g[cg].t[naxis].tmax = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 320:
# line 1602 "pars.yacc"
{
	    g[cg].t[naxis].t_num = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 321:
# line 1605 "pars.yacc"
{
	    g[cg].t[naxis].t_inout = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 322:
# line 1608 "pars.yacc"
{
	    g[cg].t[naxis].t_log = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 323:
# line 1611 "pars.yacc"
{
	    g[cg].t[naxis].t_size = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 324:
# line 1614 "pars.yacc"
{
	    g[cg].t[naxis].t_size = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 325:
# line 1617 "pars.yacc"
{
	    g[cg].t[naxis].t_msize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 326:
# line 1620 "pars.yacc"
{
	    g[cg].t[naxis].t_color = g[cg].t[naxis].t_mcolor = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 327:
# line 1623 "pars.yacc"
{
	    g[cg].t[naxis].t_linew = g[cg].t[naxis].t_mlinew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 328:
# line 1626 "pars.yacc"
{
	    g[cg].t[naxis].t_color = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 329:
# line 1629 "pars.yacc"
{
	    g[cg].t[naxis].t_mcolor = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 330:
# line 1632 "pars.yacc"
{
	    g[cg].t[naxis].t_linew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 331:
# line 1635 "pars.yacc"
{
	    g[cg].t[naxis].t_mlinew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 332:
# line 1638 "pars.yacc"
{
	    g[cg].t[naxis].t_lines = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 333:
# line 1641 "pars.yacc"
{
	    g[cg].t[naxis].t_mlines = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 334:
# line 1644 "pars.yacc"
{
	    g[cg].t[naxis].t_gridflag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 335:
# line 1647 "pars.yacc"
{
	    g[cg].t[naxis].t_mgridflag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 336:
# line 1650 "pars.yacc"
{
	    g[cg].t[naxis].t_op = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 337:
# line 1653 "pars.yacc"
{
	    g[cg].t[naxis].t_type = AUTO;
	} /*NOTREACHED*/ break;
case 338:
# line 1656 "pars.yacc"
{
	    g[cg].t[naxis].t_type = SPEC;
	} /*NOTREACHED*/ break;
case 339:
# line 1659 "pars.yacc"
{
	    g[cg].t[naxis].t_spec = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 340:
# line 1662 "pars.yacc"
{
	    g[cg].t[naxis].t_specloc[(int) yypvt[-2].val] = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 343:
# line 1673 "pars.yacc"
{
	    g[cg].t[naxis].tl_flag = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 344:
# line 1676 "pars.yacc"
{
	    g[cg].t[naxis].tl_type = AUTO;
	} /*NOTREACHED*/ break;
case 345:
# line 1679 "pars.yacc"
{
	    g[cg].t[naxis].tl_type = SPEC;
	} /*NOTREACHED*/ break;
case 346:
# line 1682 "pars.yacc"
{
	    g[cg].t[naxis].tl_prec = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 347:
# line 1685 "pars.yacc"
{
	    g[cg].t[naxis].tl_format = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 348:
# line 1688 "pars.yacc"
{
	    g[cg].t[naxis].tl_format = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 349:
# line 1691 "pars.yacc"
{
	    strcpy(g[cg].t[naxis].tl_appstr, (char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 350:
# line 1694 "pars.yacc"
{
	    strcpy(g[cg].t[naxis].tl_prestr, (char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 351:
# line 1697 "pars.yacc"
{
	    g[cg].t[naxis].tl_layout = HORIZONTAL;
	} /*NOTREACHED*/ break;
case 352:
# line 1700 "pars.yacc"
{
	    g[cg].t[naxis].tl_layout = VERTICAL;
	} /*NOTREACHED*/ break;
case 353:
# line 1703 "pars.yacc"
{
	    g[cg].t[naxis].tl_layout = SPEC;
	} /*NOTREACHED*/ break;
case 354:
# line 1706 "pars.yacc"
{
	    g[cg].t[naxis].tl_angle = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 355:
# line 1709 "pars.yacc"
{
	    g[cg].t[naxis].tl_just = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 356:
# line 1712 "pars.yacc"
{
	    g[cg].t[naxis].tl_skip = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 357:
# line 1715 "pars.yacc"
{
	    g[cg].t[naxis].tl_staggered = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 358:
# line 1718 "pars.yacc"
{
	    g[cg].t[naxis].tl_op = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 359:
# line 1721 "pars.yacc"
{
	    g[cg].t[naxis].tl_sign = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 360:
# line 1724 "pars.yacc"
{
	    g[cg].t[naxis].tl_start = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 361:
# line 1727 "pars.yacc"
{
	    g[cg].t[naxis].tl_stop = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 362:
# line 1730 "pars.yacc"
{
	    g[cg].t[naxis].tl_starttype = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 363:
# line 1733 "pars.yacc"
{
	    g[cg].t[naxis].tl_starttype = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 364:
# line 1736 "pars.yacc"
{
	    g[cg].t[naxis].tl_stoptype = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 365:
# line 1739 "pars.yacc"
{
	    g[cg].t[naxis].tl_stoptype = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 366:
# line 1742 "pars.yacc"
{
	    g[cg].t[naxis].tl_vgap = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 367:
# line 1745 "pars.yacc"
{
	    g[cg].t[naxis].tl_hgap = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 368:
# line 1748 "pars.yacc"
{
	    g[cg].t[naxis].tl_charsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 369:
# line 1751 "pars.yacc"
{
	    g[cg].t[naxis].tl_font = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 370:
# line 1754 "pars.yacc"
{
	    g[cg].t[naxis].tl_color = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 371:
# line 1757 "pars.yacc"
{
	    g[cg].t[naxis].tl_linew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 372:
# line 1760 "pars.yacc"
{
	    strcpy(g[cg].t[naxis].t_speclab[(int) yypvt[-2].val].s, (char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 373:
# line 1766 "pars.yacc"
{
	    strcpy(g[cg].t[naxis].label.s, (char *) yypvt[-0].pset);
	} /*NOTREACHED*/ break;
case 374:
# line 1769 "pars.yacc"
{
	    g[cg].t[naxis].label_layout = PERP;
	} /*NOTREACHED*/ break;
case 375:
# line 1772 "pars.yacc"
{
	    g[cg].t[naxis].label_layout = PARA;
	} /*NOTREACHED*/ break;
case 376:
# line 1775 "pars.yacc"
{
	    g[cg].t[naxis].label_place = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 377:
# line 1778 "pars.yacc"
{
	    g[cg].t[naxis].label_place = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 378:
# line 1781 "pars.yacc"
{
	    g[cg].t[naxis].label.x = yypvt[-2].val;
	    g[cg].t[naxis].label.y = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 379:
# line 1785 "pars.yacc"
{
	    g[cg].t[naxis].label.just = (int) yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 380:
# line 1788 "pars.yacc"
{
	    g[cg].t[naxis].label.charsize = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 381:
# line 1791 "pars.yacc"
{
	    g[cg].t[naxis].label.font = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 382:
# line 1794 "pars.yacc"
{
	    g[cg].t[naxis].label.color = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 383:
# line 1797 "pars.yacc"
{
	    g[cg].t[naxis].label.linew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 384:
# line 1803 "pars.yacc"
{
	    g[cg].t[naxis].t_drawbar = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 385:
# line 1806 "pars.yacc"
{
	    g[cg].t[naxis].t_drawbarcolor = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 386:
# line 1809 "pars.yacc"
{
	    g[cg].t[naxis].t_drawbarlines = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 387:
# line 1812 "pars.yacc"
{
	    g[cg].t[naxis].t_drawbarlinew = (int) yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 388:
# line 1819 "pars.yacc"
{
	    whichgraph = yypvt[-2].pset;
	    whichset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 389:
# line 1824 "pars.yacc"
{
	    whichgraph = cg;
	    whichset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 390:
# line 1829 "pars.yacc"
{
	    whichgraph = cg;
	    whichset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 391:
# line 1834 "pars.yacc"
{
	    whichgraph = yypvt[-1].pset;
	    whichset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 392:
# line 1839 "pars.yacc"
{
	    whichgraph = yypvt[-1].pset;
	    whichset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 393:
# line 1844 "pars.yacc"
{
	    whichgraph = yypvt[-1].pset;
	    whichset = yypvt[-0].pset;
	} /*NOTREACHED*/ break;
case 394:
# line 1851 "pars.yacc"
{
            yyval.pset = yypvt[-0].pset;
        } /*NOTREACHED*/ break;
case 395:
# line 1854 "pars.yacc"
{
            yyval.pset = yypvt[-0].pset;
        } /*NOTREACHED*/ break;
case 396:
# line 1857 "pars.yacc"
{
            yyval.pset = yypvt[-0].pset;
        } /*NOTREACHED*/ break;
case 397:
# line 1860 "pars.yacc"
{
            yyval.pset = yypvt[-0].pset;
        } /*NOTREACHED*/ break;
case 398:
# line 1863 "pars.yacc"
{
            yyval.pset = yypvt[-0].pset;
        } /*NOTREACHED*/ break;
case 399:
# line 1869 "pars.yacc"
{
	    yyval.pset = ON;
	} /*NOTREACHED*/ break;
case 400:
# line 1872 "pars.yacc"
{
	    yyval.pset = OFF;
	} /*NOTREACHED*/ break;
case 401:
# line 1878 "pars.yacc"
{
	    yyval.pset = COLOR;
	} /*NOTREACHED*/ break;
case 402:
# line 1881 "pars.yacc"
{
	    yyval.pset = PATTERN;
	} /*NOTREACHED*/ break;
case 403:
# line 1887 "pars.yacc"
{
	    yyval.pset = RUNAVG;
	} /*NOTREACHED*/ break;
case 404:
# line 1890 "pars.yacc"
{
	    yyval.pset = RUNSTD;
	} /*NOTREACHED*/ break;
case 405:
# line 1893 "pars.yacc"
{
	    yyval.pset = RUNMED;
	} /*NOTREACHED*/ break;
case 406:
# line 1896 "pars.yacc"
{
	    yyval.pset = RUNMAX;
	} /*NOTREACHED*/ break;
case 407:
# line 1899 "pars.yacc"
{
	    yyval.pset = RUNMIN;
	} /*NOTREACHED*/ break;
case 408:
# line 1905 "pars.yacc"
{
	    yyval.pset = DFT;
	} /*NOTREACHED*/ break;
case 409:
# line 1908 "pars.yacc"
{
	    yyval.pset = FFT;
	} /*NOTREACHED*/ break;
case 410:
# line 1911 "pars.yacc"
{
	    yyval.pset = INVDFT;
	} /*NOTREACHED*/ break;
case 411:
# line 1914 "pars.yacc"
{
	    yyval.pset = INVFFT;
	} /*NOTREACHED*/ break;
case 412:
# line 1920 "pars.yacc"
{
	    yyval.pset = DISK;
	} /*NOTREACHED*/ break;
case 413:
# line 1923 "pars.yacc"
{
	    yyval.pset = PIPE;
	} /*NOTREACHED*/ break;
case 414:
# line 1929 "pars.yacc"
{
	    yyval.pset = PATTERN;
	} /*NOTREACHED*/ break;
case 415:
# line 1932 "pars.yacc"
{
	    yyval.pset = COLOR;
	} /*NOTREACHED*/ break;
case 416:
# line 1935 "pars.yacc"
{
	    yyval.pset = NONE;
	} /*NOTREACHED*/ break;
case 417:
# line 1941 "pars.yacc"
{
	    yyval.pset = TOP;
	} /*NOTREACHED*/ break;
case 418:
# line 1944 "pars.yacc"
{
	    yyval.pset = BOTTOM;
	} /*NOTREACHED*/ break;
case 419:
# line 1947 "pars.yacc"
{
	    yyval.pset = LEFT;
	} /*NOTREACHED*/ break;
case 420:
# line 1950 "pars.yacc"
{
	    yyval.pset = RIGHT;
	} /*NOTREACHED*/ break;
case 421:
# line 1953 "pars.yacc"
{
	    yyval.pset = BOTH;
	} /*NOTREACHED*/ break;
case 422:
# line 1959 "pars.yacc"
{
	    yyval.pset = RIGHT;
	} /*NOTREACHED*/ break;
case 423:
# line 1962 "pars.yacc"
{
	    yyval.pset = LEFT;
	} /*NOTREACHED*/ break;
case 424:
# line 1965 "pars.yacc"
{
	    yyval.pset = CENTER;
	} /*NOTREACHED*/ break;
case 425:
# line 1971 "pars.yacc"
{
	    yyval.pset = XMIN;
	} /*NOTREACHED*/ break;
case 426:
# line 1974 "pars.yacc"
{
	    yyval.pset = XMAX;
	} /*NOTREACHED*/ break;
case 427:
# line 1977 "pars.yacc"
{
	    yyval.pset = YMIN;
	} /*NOTREACHED*/ break;
case 428:
# line 1980 "pars.yacc"
{
	    yyval.pset = YMAX;
	} /*NOTREACHED*/ break;
case 429:
# line 1986 "pars.yacc"
{
	    yyval.pset = TRUEP;
	} /*NOTREACHED*/ break;
case 430:
# line 1989 "pars.yacc"
{
	    yyval.pset = FALSEP;
	} /*NOTREACHED*/ break;
case 431:
# line 1995 "pars.yacc"
{
	    yyval.pset = IN;
	} /*NOTREACHED*/ break;
case 432:
# line 1998 "pars.yacc"
{
	    yyval.pset = OUT;
	} /*NOTREACHED*/ break;
case 433:
# line 2001 "pars.yacc"
{
	    yyval.pset = BOTH;
	} /*NOTREACHED*/ break;
case 434:
# line 2007 "pars.yacc"
{
	    yyval.pset = DECIMAL;
	} /*NOTREACHED*/ break;
case 435:
# line 2010 "pars.yacc"
{
	    yyval.pset = EXPONENTIAL;
	} /*NOTREACHED*/ break;
case 436:
# line 2013 "pars.yacc"
{
	    yyval.pset = POWER;
	} /*NOTREACHED*/ break;
case 437:
# line 2016 "pars.yacc"
{
	    yyval.pset = GENERAL;
	} /*NOTREACHED*/ break;
case 438:
# line 2019 "pars.yacc"
{
	    yyval.pset = DDMMYY;
	} /*NOTREACHED*/ break;
case 439:
# line 2022 "pars.yacc"
{
	    yyval.pset = MMDDYY;
	} /*NOTREACHED*/ break;
case 440:
# line 2025 "pars.yacc"
{
	    yyval.pset = MMYY;
	} /*NOTREACHED*/ break;
case 441:
# line 2028 "pars.yacc"
{
	    yyval.pset = MMDD;
	} /*NOTREACHED*/ break;
case 442:
# line 2031 "pars.yacc"
{
	    yyval.pset = MONTHDAY;
	} /*NOTREACHED*/ break;
case 443:
# line 2034 "pars.yacc"
{
	    yyval.pset = DAYMONTH;
	} /*NOTREACHED*/ break;
case 444:
# line 2037 "pars.yacc"
{
	    yyval.pset = MONTHS;
	} /*NOTREACHED*/ break;
case 445:
# line 2040 "pars.yacc"
{
	    yyval.pset = MONTHL;
	} /*NOTREACHED*/ break;
case 446:
# line 2043 "pars.yacc"
{
	    yyval.pset = DAYOFWEEKS;
	} /*NOTREACHED*/ break;
case 447:
# line 2046 "pars.yacc"
{
	    yyval.pset = DAYOFWEEKL;
	} /*NOTREACHED*/ break;
case 448:
# line 2049 "pars.yacc"
{
	    yyval.pset = DAYOFYEAR;
	} /*NOTREACHED*/ break;
case 449:
# line 2052 "pars.yacc"
{
	    yyval.pset = HMS;
	} /*NOTREACHED*/ break;
case 450:
# line 2055 "pars.yacc"
{
	    yyval.pset = MMDDHMS;
	} /*NOTREACHED*/ break;
case 451:
# line 2058 "pars.yacc"
{
	    yyval.pset = MMDDYYHMS;
	} /*NOTREACHED*/ break;
case 452:
# line 2061 "pars.yacc"
{
	    yyval.pset = DEGREESLON;
	} /*NOTREACHED*/ break;
case 453:
# line 2064 "pars.yacc"
{
	    yyval.pset = DEGREESMMLON;
	} /*NOTREACHED*/ break;
case 454:
# line 2067 "pars.yacc"
{
	    yyval.pset = DEGREESMMSSLON;
	} /*NOTREACHED*/ break;
case 455:
# line 2070 "pars.yacc"
{
	    yyval.pset = MMSSLON;
	} /*NOTREACHED*/ break;
case 456:
# line 2073 "pars.yacc"
{
	    yyval.pset = DEGREESLAT;
	} /*NOTREACHED*/ break;
case 457:
# line 2076 "pars.yacc"
{
	    yyval.pset = DEGREESMMLAT;
	} /*NOTREACHED*/ break;
case 458:
# line 2079 "pars.yacc"
{
	    yyval.pset = DEGREESMMSSLAT;
	} /*NOTREACHED*/ break;
case 459:
# line 2082 "pars.yacc"
{
	    yyval.pset = MMSSLAT;
	} /*NOTREACHED*/ break;
case 460:
# line 2088 "pars.yacc"
{
	    yyval.pset = NORMAL;
	} /*NOTREACHED*/ break;
case 461:
# line 2091 "pars.yacc"
{
	    yyval.pset = ABSOLUTE;
	} /*NOTREACHED*/ break;
case 462:
# line 2094 "pars.yacc"
{
	    yyval.pset = NEGATE;
	} /*NOTREACHED*/ break;
case 463:
# line 2100 "pars.yacc"
{
	    yyval.pset = UP;
	} /*NOTREACHED*/ break;
case 464:
# line 2103 "pars.yacc"
{
	    yyval.pset = DOWN;
	} /*NOTREACHED*/ break;
case 465:
# line 2106 "pars.yacc"
{
	    yyval.pset = RIGHT;
	} /*NOTREACHED*/ break;
case 466:
# line 2109 "pars.yacc"
{
	    yyval.pset = LEFT;
	} /*NOTREACHED*/ break;
case 467:
# line 2112 "pars.yacc"
{
	    yyval.pset = IN;
	} /*NOTREACHED*/ break;
case 468:
# line 2115 "pars.yacc"
{
	    yyval.pset = OUT;
	} /*NOTREACHED*/ break;
case 469:
# line 2121 "pars.yacc"
{
	    yyval.pset = WORLD;
	} /*NOTREACHED*/ break;
case 470:
# line 2124 "pars.yacc"
{
	    yyval.pset = VIEW;
	} /*NOTREACHED*/ break;
case 471:
# line 2131 "pars.yacc"
{
	    int itmp = (int) yypvt[-3].val - 1;
	    if (itmp >= ls) {
		yyerror("subscript out of range");
		return 1;
	    } else {
		yypvt[-5].ptr[itmp] = yypvt[-0].val;
		result = yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 472:
# line 2142 "pars.yacc"
{
	    int itmp = (int) yypvt[-3].val - 1;
	    if (itmp >= lxy) {
		yyerror("subscript out of range");
		return 1;
	    } else {
		yypvt[-5].ptr[itmp] = yypvt[-0].val;
		result = yypvt[-0].val;
	    }
	    updatesetminmax(cg, curset);
	    update_set_status(cg, curset);
	} /*NOTREACHED*/ break;
case 473:
# line 2155 "pars.yacc"
{
	    /*
	     * what is on the stack is a pointer to x we need a pointer to
	     * the set SETNUM x or y 
	     */
	    int itmp = (int) yypvt[-3].val - 1;
	    if (yypvt[-5].ptr == xx) {
		g[cg].p[yypvt[-7].pset].ex[0][itmp] = yypvt[-0].val;
	    } else {
		g[cg].p[yypvt[-7].pset].ex[1][itmp] = yypvt[-0].val;
	    }
	    result = yypvt[-0].val;
	    updatesetminmax(cg, yypvt[-7].pset);
	    update_set_status(cg, yypvt[-7].pset);
	} /*NOTREACHED*/ break;
case 474:
# line 2171 "pars.yacc"
{
	    /*
	     * what is on the stack is a pointer to x we need a pointer to
	     * the set SETNUM x or y 
	     */
	    int itmp = (int) yypvt[-3].val - 1;
	    if (yypvt[-5].ptr == xx) {
		g[yypvt[-9].pset].p[yypvt[-7].pset].ex[0][itmp] = yypvt[-0].val;
	    } else if (yypvt[-5].ptr == yy) {
		g[yypvt[-9].pset].p[yypvt[-7].pset].ex[1][itmp] = yypvt[-0].val;
	    }
	    result = yypvt[-0].val;
	    updatesetminmax(yypvt[-9].pset, yypvt[-7].pset);
	    update_set_status(yypvt[-9].pset, yypvt[-7].pset);
	} /*NOTREACHED*/ break;
case 475:
# line 2190 "pars.yacc"
{
	    if (yypvt[-2].ptr == xx) {
		*xx = yypvt[-0].val;
	    } else {
		*yy = yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 476:
# line 2201 "pars.yacc"
{
	    int i;
	    for (i = 0; i < lxy; i++) {
		yypvt[-2].ptr[i] = yypvt[-0].ptr[i];
	    }
	    result = yypvt[-0].ptr[0];
	} /*NOTREACHED*/ break;
case 477:
# line 2209 "pars.yacc"
{
	    int i;
	    for (i = 0; i < lxy; i++) {
		yypvt[-2].ptr[i] = yypvt[-0].ptr[i];
	    }
	    result = yypvt[-0].ptr[0];
	    updatesetminmax(cg, curset);
	    update_set_status(cg, curset);
	} /*NOTREACHED*/ break;
case 478:
# line 2219 "pars.yacc"
{
	    int i;
	    double *tmp;
	    if (!isactive_set(cg, yypvt[-4].pset)) {
		activateset(cg, yypvt[-4].pset);
		setlength(cg, yypvt[-4].pset, lxy);
		setcomment(cg, yypvt[-4].pset, "Created");
	    }
	    if (yypvt[-2].ptr == xx) {
		tmp = g[cg].p[yypvt[-4].pset].ex[0];
	    } else {
		tmp = g[cg].p[yypvt[-4].pset].ex[1];
	    }
	    for (i = 0; i < lxy; i++) {
		tmp[i] = yypvt[-0].ptr[i];
	    }
	    result = yypvt[-0].ptr[0];
	    updatesetminmax(cg, yypvt[-4].pset);
	    update_set_status(cg, yypvt[-4].pset);
	} /*NOTREACHED*/ break;
case 479:
# line 2240 "pars.yacc"
{
	    int i;
	    double *tmp;
	    if (!isactive_set(yypvt[-6].pset, yypvt[-4].pset)) {
		activateset(yypvt[-6].pset, yypvt[-4].pset);
		setlength(yypvt[-6].pset, yypvt[-4].pset, lxy);
		setcomment(yypvt[-6].pset, yypvt[-4].pset, "Created");
	    }
	    if (yypvt[-2].ptr == xx) {
		tmp = g[yypvt[-6].pset].p[yypvt[-4].pset].ex[0];
	    } else {
		tmp = g[yypvt[-6].pset].p[yypvt[-4].pset].ex[1];
	    }
	    for (i = 0; i < lxy; i++) {
		tmp[i] = yypvt[-0].ptr[i];
	    }
	    result = yypvt[-0].ptr[0];
	    updatesetminmax(yypvt[-6].pset, yypvt[-4].pset);
	    update_set_status(yypvt[-6].pset, yypvt[-4].pset);
	} /*NOTREACHED*/ break;
case 480:
# line 2261 "pars.yacc"
{
	    int i;
	    for (i = 0; i < lxy; i++) {
		yypvt[-2].ptr[i] = yypvt[-0].val;
	    }
	    result = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 481:
# line 2269 "pars.yacc"
{
	    int i;
	    for (i = 0; i < lxy; i++) {
		yypvt[-2].ptr[i] = yypvt[-0].val;
	    }
	    result = yypvt[-0].val;
	    updatesetminmax(cg, curset);
	    update_set_status(cg, curset);
	} /*NOTREACHED*/ break;
case 482:
# line 2279 "pars.yacc"
{
	    int i;
	    double *tmp;
	    if (yypvt[-2].ptr == xx) {
		tmp = g[cg].p[yypvt[-4].pset].ex[0];
	    } else {
		tmp = g[cg].p[yypvt[-4].pset].ex[1];
	    }
	    for (i = 0; i < lxy; i++) {
		tmp[i] = yypvt[-0].val;
	    }
	    result = yypvt[-0].val;
	    updatesetminmax(cg, yypvt[-4].pset);
	    update_set_status(cg, yypvt[-4].pset);
	} /*NOTREACHED*/ break;
case 483:
# line 2295 "pars.yacc"
{
	    int i;
	    double *tmp;
	    if (yypvt[-2].ptr == xx) {
		tmp = g[yypvt[-6].pset].p[yypvt[-4].pset].ex[0];
	    } else {
		tmp = g[yypvt[-6].pset].p[yypvt[-4].pset].ex[1];
	    }
	    for (i = 0; i < lxy; i++) {
		tmp[i] = yypvt[-0].val;
	    }
	    result = yypvt[-0].val;
	    updatesetminmax(yypvt[-6].pset, yypvt[-4].pset);
	    update_set_status(yypvt[-6].pset, yypvt[-4].pset);
	} /*NOTREACHED*/ break;
case 484:
# line 2314 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 485:
# line 2323 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 486:
# line 2332 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		if (yypvt[-0].ptr == xx) {
		    yyval.ptr[i] = g[yypvt[-4].pset].p[yypvt[-2].pset].ex[0][i];
		} else {
		    yyval.ptr[i] = g[yypvt[-4].pset].p[yypvt[-2].pset].ex[1][i];
		}
	    }
	} /*NOTREACHED*/ break;
case 487:
# line 2345 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		if (yypvt[-0].ptr == xx) {
		    yyval.ptr[i] = g[cg].p[yypvt[-2].pset].ex[0][i];
		} else {
		    yyval.ptr[i] = g[cg].p[yypvt[-2].pset].ex[1][i];
		}
	    }
	} /*NOTREACHED*/ break;
case 488:
# line 2358 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 489:
# line 2367 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val + yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 490:
# line 2376 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] + yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 491:
# line 2385 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val + yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 492:
# line 2394 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] + yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 493:
# line 2403 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val - yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 494:
# line 2412 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] - yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 495:
# line 2421 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val - yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 496:
# line 2430 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] - yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 497:
# line 2439 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val * yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 498:
# line 2448 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] * yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 499:
# line 2457 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val * yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 500:
# line 2466 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] * yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 501:
# line 2475 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    if (yypvt[-0].val == 0.0) {
		yyerror("Divide by Zero");
		return 1;
	    }
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val / yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 502:
# line 2488 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		if (yypvt[-0].ptr[i] == 0.0) {
		    yyerror("Divide by Zero");
		    return 1;
		}
	    }
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] / yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 503:
# line 2503 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		if (yypvt[-0].ptr[i] == 0.0) {
		    yyerror("Divide by Zero");
		    return 1;
		}
	    }
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].val / yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 504:
# line 2518 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    if (yypvt[-0].val == 0.0) {
		yyerror("Divide by Zero");
		return 1;
	    }
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] / yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 505:
# line 2531 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = pow(yypvt[-2].val, yypvt[-0].val);
	    }
	} /*NOTREACHED*/ break;
case 506:
# line 2540 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = pow(yypvt[-2].val, yypvt[-0].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 507:
# line 2549 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = pow(yypvt[-2].ptr[i], yypvt[-0].val);
	    }
	} /*NOTREACHED*/ break;
case 508:
# line 2558 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = pow(yypvt[-2].ptr[i], yypvt[-0].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 509:
# line 2567 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = fabs(yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 510:
# line 2576 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = fabs(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 511:
# line 2585 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = acos(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 512:
# line 2594 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = asin(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 513:
# line 2603 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = atan(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 514:
# line 2612 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = atan2(yypvt[-3].ptr[i], yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 515:
# line 2621 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = ceil(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 516:
# line 2630 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = cos(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 517:
# line 2639 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] *= M_PI / 180.0;
	    }
	} /*NOTREACHED*/ break;
case 518:
# line 2648 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = xx[i];
	    }
	} /*NOTREACHED*/ break;
case 519:
# line 2657 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yy[i];
	    }
	} /*NOTREACHED*/ break;
case 520:
# line 2666 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = erf(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 521:
# line 2675 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = erfc(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 522:
# line 2684 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = exp(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 523:
# line 2693 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = floor(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 524:
# line 2702 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = hypot(yypvt[-3].ptr[i], yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 525:
# line 2711 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = hypot(yypvt[-3].val, yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 526:
# line 2720 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = hypot(yypvt[-3].ptr[i], yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 527:
# line 2729 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = hypot(yypvt[-3].val, yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 528:
# line 2738 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = i + 1;
	    }
	} /*NOTREACHED*/ break;
case 529:
# line 2747 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-0].func;
	    }
	} /*NOTREACHED*/ break;
case 530:
# line 2756 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = (int) yypvt[-1].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 531:
# line 2765 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = invnorm(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 532:
# line 2774 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = invt(yypvt[-3].val, (int) yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 533:
# line 2783 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = invt(yypvt[-3].ptr[i], (int) yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 534:
# line 2792 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = lrand48() % (long) (yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 535:
# line 2801 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = lgamma(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 536:
# line 2810 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = log(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 537:
# line 2819 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = log10(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 538:
# line 2828 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = 1.0 / (1.0 + exp(-(yypvt[-5].ptr[i] - yypvt[-3].val)/ yypvt[-1].val));
	    }
	} /*NOTREACHED*/ break;
case 539:
# line 2837 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-3].ptr[i] >= yypvt[-1].ptr[i] ? yypvt[-3].ptr[i] : yypvt[-1].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 540:
# line 2846 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-3].ptr[i] <= yypvt[-1].ptr[i] ? yypvt[-3].ptr[i] : yypvt[-1].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 541:
# line 2855 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = fmod(yypvt[-3].ptr[i], yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 542:
# line 2864 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = fx(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 543:
# line 2873 "pars.yacc"
{
	    int i;
	    double tmp;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = normp(yypvt[-1].ptr[i], &tmp);
	    }
	} /*NOTREACHED*/ break;
case 544:
# line 2883 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = M_PI;
	    }
	} /*NOTREACHED*/ break;
case 545:
# line 2892 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = M_PI / 180.0;
	    }
	} /*NOTREACHED*/ break;
case 546:
# line 2901 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = (double) drand48();
	    }
	} /*NOTREACHED*/ break;
case 547:
# line 2910 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = rnorm(yypvt[-3].ptr[i], yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 548:
# line 2919 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = rnorm(yypvt[-3].val, yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 549:
# line 2928 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = rnorm(yypvt[-3].ptr[i], yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 550:
# line 2937 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = rnorm(yypvt[-3].val, yypvt[-1].val);
	    }
	} /*NOTREACHED*/ break;
case 551:
# line 2946 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = sin(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 552:
# line 2955 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-1].ptr[i] * yypvt[-1].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 553:
# line 2964 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = sqrt(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 554:
# line 2973 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = tan(yypvt[-1].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 555:
# line 2981 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
	        if ((int) yypvt[-4].ptr[i]) {
		    yyval.ptr[i] = yypvt[-2].ptr[i];
	        } else {
		    yyval.ptr[i] = yypvt[-0].ptr[i];
	        }
	    }
	} /*NOTREACHED*/ break;
case 556:
# line 2994 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] > yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 557:
# line 3003 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] < yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 558:
# line 3012 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] <= yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 559:
# line 3021 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] >= yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 560:
# line 3030 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] == yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 561:
# line 3039 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] != yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 562:
# line 3048 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] && yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 563:
# line 3057 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-2].ptr[i] || yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 564:
# line 3066 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = !(yypvt[-0].ptr[i]);
	    }
	} /*NOTREACHED*/ break;
case 565:
# line 3075 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = yypvt[-1].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 566:
# line 3083 "pars.yacc"
{
	    int i;
	    yyval.ptr = (double *) calloc(lxy, sizeof(double));
	    freelist[fcnt++] = yyval.ptr;
	    for (i = 0; i < lxy; i++) {
		yyval.ptr[i] = -yypvt[-0].ptr[i];
	    }
	} /*NOTREACHED*/ break;
case 568:
# line 3094 "pars.yacc"
{
	    yyval.val = yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 569:
# line 3097 "pars.yacc"
{
	    yyval.val = yypvt[-3].ptr[(int) yypvt[-1].val];
	} /*NOTREACHED*/ break;
case 570:
# line 3100 "pars.yacc"
{
	    yyval.val = yypvt[-3].ptr[(int) yypvt[-1].val - 1];
	} /*NOTREACHED*/ break;
case 571:
# line 3103 "pars.yacc"
{
	    yyval.val = (yypvt[-0].ptr == xx) ? *xx : *yy;
	} /*NOTREACHED*/ break;
case 572:
# line 3106 "pars.yacc"
{
	    if (yypvt[-3].ptr == xx) {
		yyval.val = g[cg].p[yypvt[-5].pset].ex[0][(int) yypvt[-1].val - 1];
	    } else if (yypvt[-3].ptr == yy) {
		yyval.val = g[cg].p[yypvt[-5].pset].ex[1][(int) yypvt[-1].val - 1];
	    }
	} /*NOTREACHED*/ break;
case 573:
# line 3113 "pars.yacc"
{
	    switch (yypvt[-0].pset) {
	    case XMIN:
		yyval.val = g[cg].p[yypvt[-2].pset].xmin;
		break;
	    case YMIN:
		yyval.val = g[cg].p[yypvt[-2].pset].ymin;
		break;
	    case XMAX:
		yyval.val = g[cg].p[yypvt[-2].pset].xmax;
		break;
	    case YMAX:
		yyval.val = g[cg].p[yypvt[-2].pset].ymax;
		break;
	    }
	} /*NOTREACHED*/ break;
case 574:
# line 3129 "pars.yacc"
{
	    yyval.val = g[cg].p[yypvt[-2].pset].len;
	} /*NOTREACHED*/ break;
case 575:
# line 3133 "pars.yacc"
{
	    double bar, sd;
	    if (yypvt[-1].ptr == xx) {
		stasum(getx(cg, yypvt[-3].pset), getsetlength(cg, yypvt[-3].pset), &bar, &sd, 0);
	    } else if (yypvt[-1].ptr == yy) {
		stasum(gety(cg, yypvt[-3].pset), getsetlength(cg, yypvt[-3].pset), &bar, &sd, 0);
	    }
	    yyval.val = bar;
	} /*NOTREACHED*/ break;
case 576:
# line 3142 "pars.yacc"
{
	    if (yypvt[-3].ptr == xx) {
		yyval.val = g[yypvt[-7].pset].p[yypvt[-5].pset].ex[0][(int) yypvt[-1].val - 1];
	    } else if (yypvt[-3].ptr == yy) {
		yyval.val = g[yypvt[-7].pset].p[yypvt[-5].pset].ex[1][(int) yypvt[-1].val - 1];
	    }
	} /*NOTREACHED*/ break;
case 577:
# line 3149 "pars.yacc"
{
	    yyval.val = yypvt[-2].val + yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 578:
# line 3152 "pars.yacc"
{
	    yyval.val = yypvt[-2].val - yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 579:
# line 3155 "pars.yacc"
{
	    yyval.val = yypvt[-2].val * yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 580:
# line 3159 "pars.yacc"
{
	    if (yypvt[-0].val != 0.0) {
		yyval.val = yypvt[-2].val / yypvt[-0].val;
	    } else {
		yyerror("Divide by Zero");
		return 1;
	    }
	} /*NOTREACHED*/ break;
case 581:
# line 3167 "pars.yacc"
{
	    yyval.val = fmod(yypvt[-2].val, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 582:
# line 3170 "pars.yacc"
{
	    yyval.val = pow(yypvt[-2].val, yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 583:
# line 3173 "pars.yacc"
{
	    yyval.val = fabs(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 584:
# line 3176 "pars.yacc"
{
	    yyval.val = acos(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 585:
# line 3179 "pars.yacc"
{
	    yyval.val = asin(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 586:
# line 3182 "pars.yacc"
{
	    yyval.val = atan(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 587:
# line 3185 "pars.yacc"
{
	    yyval.val = atan2(yypvt[-3].val, yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 588:
# line 3188 "pars.yacc"
{
	    yyval.val = ceil(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 589:
# line 3191 "pars.yacc"
{
	    yyval.val = cos(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 590:
# line 3194 "pars.yacc"
{
	    yyval.val = 180.0 / M_PI;
	} /*NOTREACHED*/ break;
case 591:
# line 3197 "pars.yacc"
{
	    yyval.val = *xx;
	} /*NOTREACHED*/ break;
case 592:
# line 3200 "pars.yacc"
{
	    yyval.val = *yy;
	} /*NOTREACHED*/ break;
case 593:
# line 3203 "pars.yacc"
{
	    yyval.val = erf(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 594:
# line 3206 "pars.yacc"
{
	    yyval.val = erfc(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 595:
# line 3209 "pars.yacc"
{
	    yyval.val = exp(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 596:
# line 3212 "pars.yacc"
{
	    yyval.val = floor(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 597:
# line 3215 "pars.yacc"
{
	    yyval.val = hypot(yypvt[-3].val, yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 598:
# line 3218 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].v.xv1;
	} /*NOTREACHED*/ break;
case 599:
# line 3221 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].v.xv2;
	} /*NOTREACHED*/ break;
case 600:
# line 3224 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].v.yv1;
	} /*NOTREACHED*/ break;
case 601:
# line 3227 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].v.yv2;
	} /*NOTREACHED*/ break;
case 602:
# line 3230 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].w.xg1;
	} /*NOTREACHED*/ break;
case 603:
# line 3233 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].w.xg2;
	} /*NOTREACHED*/ break;
case 604:
# line 3236 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].w.yg1;
	} /*NOTREACHED*/ break;
case 605:
# line 3239 "pars.yacc"
{
	    yyval.val = g[yypvt[-2].pset].w.yg2;
	} /*NOTREACHED*/ break;
case 606:
# line 3242 "pars.yacc"
{
	    yyval.val = g[cg].v.xv1;
	} /*NOTREACHED*/ break;
case 607:
# line 3245 "pars.yacc"
{
	    yyval.val = g[cg].v.xv2;
	} /*NOTREACHED*/ break;
case 608:
# line 3248 "pars.yacc"
{
	    yyval.val = g[cg].v.yv1;
	} /*NOTREACHED*/ break;
case 609:
# line 3251 "pars.yacc"
{
	    yyval.val = g[cg].v.yv2;
	} /*NOTREACHED*/ break;
case 610:
# line 3254 "pars.yacc"
{
	    yyval.val = g[cg].w.xg1;
	} /*NOTREACHED*/ break;
case 611:
# line 3257 "pars.yacc"
{
	    yyval.val = g[cg].w.xg2;
	} /*NOTREACHED*/ break;
case 612:
# line 3260 "pars.yacc"
{
	    yyval.val = g[cg].w.yg1;
	} /*NOTREACHED*/ break;
case 613:
# line 3263 "pars.yacc"
{
	    yyval.val = g[cg].w.yg2;
	} /*NOTREACHED*/ break;
case 614:
# line 3266 "pars.yacc"
{
	    yyval.val = setindex;
	} /*NOTREACHED*/ break;
case 615:
# line 3269 "pars.yacc"
{
	    yyval.val = setsetno;
	} /*NOTREACHED*/ break;
case 616:
# line 3272 "pars.yacc"
{
	    yyval.val = (long) yypvt[-1].val;
	} /*NOTREACHED*/ break;
case 617:
# line 3275 "pars.yacc"
{
	    yyval.val = invnorm(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 618:
# line 3278 "pars.yacc"
{
	    yyval.val = invt(yypvt[-3].val, (int) yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 619:
# line 3281 "pars.yacc"
{
	    yyval.val = lrand48() % (long) (yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 620:
# line 3284 "pars.yacc"
{
	    yyval.val = lgamma(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 621:
# line 3287 "pars.yacc"
{
	    yyval.val = log(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 622:
# line 3290 "pars.yacc"
{
	    yyval.val = log10(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 623:
# line 3294 "pars.yacc"
{
	    yyval.val = 1.0 / (1.0 + exp(-(yypvt[-5].val - yypvt[-3].val)/ yypvt[-1].val));
	} /*NOTREACHED*/ break;
case 624:
# line 3297 "pars.yacc"
{
	    yyval.val = yypvt[-3].val >= yypvt[-1].val ? yypvt[-3].val : yypvt[-1].val;
	} /*NOTREACHED*/ break;
case 625:
# line 3300 "pars.yacc"
{
	    yyval.val = yypvt[-3].val <= yypvt[-1].val ? yypvt[-3].val : yypvt[-1].val;
	} /*NOTREACHED*/ break;
case 626:
# line 3303 "pars.yacc"
{
	    yyval.val = fmod(yypvt[-3].val, yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 627:
# line 3306 "pars.yacc"
{
	    yyval.val = fx(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 628:
# line 3309 "pars.yacc"
{
	    double tmp;
	    yyval.val = normp(yypvt[-1].val, &tmp);
	} /*NOTREACHED*/ break;
case 629:
# line 3313 "pars.yacc"
{
	    yyval.val = M_PI;
	} /*NOTREACHED*/ break;
case 630:
# line 3316 "pars.yacc"
{
	    yyval.val = M_PI / 180.0;
	} /*NOTREACHED*/ break;
case 631:
# line 3319 "pars.yacc"
{
	    yyval.val = (double) drand48();
	} /*NOTREACHED*/ break;
case 632:
# line 3322 "pars.yacc"
{
	    yyval.val = rnorm(yypvt[-3].val, yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 633:
# line 3325 "pars.yacc"
{
	    yyval.val = sin(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 634:
# line 3328 "pars.yacc"
{
	    yyval.val = pow(yypvt[-1].val, 2.0);
	} /*NOTREACHED*/ break;
case 635:
# line 3331 "pars.yacc"
{
	    yyval.val = sqrt(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 636:
# line 3334 "pars.yacc"
{
	    yyval.val = tan(yypvt[-1].val);
	} /*NOTREACHED*/ break;
case 637:
# line 3337 "pars.yacc"
{
	    if ((int) yypvt[-4].val) {
		yyval.val = yypvt[-2].val;
	    } else {
		yyval.val = yypvt[-0].val;
	    }
	} /*NOTREACHED*/ break;
case 638:
# line 3344 "pars.yacc"
{
	    yyval.val = yypvt[-2].val > yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 639:
# line 3347 "pars.yacc"
{
	    yyval.val = yypvt[-2].val < yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 640:
# line 3350 "pars.yacc"
{
	    yyval.val = yypvt[-2].val <= yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 641:
# line 3353 "pars.yacc"
{
	    yyval.val = yypvt[-2].val >= yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 642:
# line 3356 "pars.yacc"
{
	    yyval.val = yypvt[-2].val == yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 643:
# line 3359 "pars.yacc"
{
	    yyval.val = yypvt[-2].val != yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 644:
# line 3362 "pars.yacc"
{
	    yyval.val = yypvt[-2].val && yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 645:
# line 3365 "pars.yacc"
{
	    yyval.val = yypvt[-2].val || yypvt[-0].val;
	} /*NOTREACHED*/ break;
case 646:
# line 3368 "pars.yacc"
{
	    yyval.val = !(yypvt[-0].val);
	} /*NOTREACHED*/ break;
case 647:
# line 3371 "pars.yacc"
{
	    yyval.val = yypvt[-1].val;
	} /*NOTREACHED*/ break;
case 648:
# line 3374 "pars.yacc"
{
	    yyval.val = -yypvt[-0].val;
	} /*NOTREACHED*/ break;
}


        goto yystack;           /* reset registers in driver code */
}
